@@ -540,15 +540,28 @@ print STDERR "\n";
 my $title = "";
 $title .= ($opt{title} ? $opt{title} : "Words Reference");
 
+$opt{reference} = 1 if not $opt{reference} and not $opt{wordsets};
+
 $n = "\n";
-print 
-    '<!DOCTYPE reference PUBLIC "-//OASIS//DTD DocBook XML V4.1.2//EN"',$n,
-    '   "http://www.oasis-open.org/docbook/xml/4.1.2/docbookx.dtd">',$n,$n
-    unless $opt{nodoctype};
-print $T if $opt{nodoctype};
-print "<reference id=\"reference\"><title>$title</title>",
+if ($opt{wordsets})
+{
+    print 
+	'<!DOCTYPE chapter PUBLIC "-//OASIS//DTD DocBook XML V4.1.2//EN"',$n,
+	'   "http://www.oasis-open.org/docbook/xml/4.1.2/docbookx.dtd">',$n,$n
+	unless $opt{nodoctype};
+    print $T;
+}    
+
+if ($opt{reference})
+{
+    print 
+       '<!DOCTYPE reference PUBLIC "-//OASIS//DTD DocBook XML V4.1.2//EN"',$n,
+       '   "http://www.oasis-open.org/docbook/xml/4.1.2/docbookx.dtd">',$n,$n
+	unless $opt{nodoctype};
+    print "<reference id=\"reference\"><title>$title</title>",
     "  <!-- -*- xml -*- -->",$n;
-for $T (sort keys %V) { print $V{$T},$n; }
-print "</reference>",$n;
+    for $T (sort keys %V) { print $V{$T},$n; }
+    print "</reference>",$n;
+}
 exit 0;
 
