@@ -7,7 +7,9 @@ my $pfe = $ARGV[0]; $pfe =~ s{^(.*)/[^/]*$}{$1};
 $_ = $ARGV[0] ;
 my $inc = "" ;                               
 /-(\w\w\w).c$/   and -s "$pfe/incl-$1.h" and $inc = "<pfe/incl-$1.h>" ;
+/-(\w\w\w).c$/   and -s "$pfe/pfe-$1.h"  and $inc = "<pfe/pfe-$1.h>" ;
 /-(\w\w\w\w).c$/ and -s "$pfe/def-$1.h"  and $inc = "<pfe/def-$1.h>" ;
+/-(\w\w\w\w).c$/ and -s "$pfe/pfe-$1.h"  and $inc = "<pfe/pfe-$1.h>" ;
 if (not length $inc) { print STDERR $_," skipped";  exit; }
 my $O = $ARGV[0]; $O =~ s/\.c/\.h/ ;
 my $once = $O ; $once =~ tr:a-z./-:A-Z___: ; $once =~ s:_+:_:g ;
