@@ -1,5 +1,5 @@
 #ifndef __PFE__MISSING_H
-#define __PFE__MISSING_H "%full_filespec: _missing.h~bln_mpt1!5.9:incl:bln_12xx!1 %"
+#define __PFE__MISSING_H "%full_filespec: _missing.h~bln_mpt1!33.13:incl:bln_12xx!1 %"
 /** 
  * -- declarations sometimes missing.
  * 
@@ -7,8 +7,8 @@
  *
  *  @see     GNU LGPL
  *  @author  Tektronix CTE            @(#) %derived_by: guidod %
- *  @version %version: bln_mpt1!5.9 %
- *    (%date_modified: Tue Sep 10 13:24:51 2002 %)
+ *  @version %version: bln_mpt1!33.13 %
+ *    (%date_modified: Tue Mar 18 15:19:24 2003 %)
  *
  *  @description
  *		This file is included after all system includes.
@@ -20,7 +20,7 @@
 #if defined _P4_SOURCE 
 
 /* we are local... really */
-#include "pfe-config.h"
+#include "pfe/_config.h"
 
 #if defined HAVE_SYS_STAT_H || defined PFE_HAVE_SYS_STAT_H
 #include <sys/stat.h>
@@ -94,10 +94,6 @@
 /* void memmove (char*, const char*, unsigned); */
 #endif
 
-#if !defined PFE_HAVE_STRDUP
-char* strdup (const char* s);
-#endif
-
 #if !defined PFE_HAVE_STRERROR && !defined HAVE_SYS_ERRLIST
    /* well if it doesn't exist, you'll have to write it yourself */
    extern char* sys_errlist [];
@@ -120,17 +116,16 @@ int _p4_rename (const char*, const char*);
 #endif
 
 #ifndef PFE_HAVE_ACCESS
-int access (const char* fn, int how);
+int _p4_access (const char* fn, int how);
+#define _P4_access _p4_access
+#else
+#define _P4_access(_A_,_B_) access(_A_,_B_)
 #endif
 
 #ifndef PFE_HAVE_GETCWD
 #define getcwd(P,L) getwd(P)
 #endif
 
-#ifndef PFE_HAVE_TRUNCATE
-int truncate (const char* path, long length);
-#endif
-
 #ifndef _pfe_raise
 # if defined HAVE_RAISE || defined PFE_HAVE_RAISE
 # define _pfe_raise raise
