@@ -5,13 +5,13 @@
  *
  *  @see     GNU LGPL
  *  @author  Tektronix CTE            @(#) %derived_by: guidod %
- *  @version %version: bln_mpt1!1.16 %
- *    (%date_modified: Tue Jun 04 17:09:09 2002 %)
+ *  @version %version: bln_mpt1!33.21 %
+ *    (%date_modified: Tue Mar 18 18:27:12 2003 %)
  */
 /*@{*/
 #if defined(__version_control__) && defined(__GNUC__)
 static char* id __attribute__((unused)) = 
-"@(#) $Id: %full_filespec:  block-sub.c~bln_mpt1!1.16:csrc:bln_12xx!1 % $";
+"@(#) $Id: %full_filespec:  block-sub.c~bln_mpt1!33.21:csrc:bln_12xx!1 % $";
 #endif
 
 #define _P4_SOURCE 1
@@ -21,6 +21,7 @@ static char* id __attribute__((unused)) =
 
 #include <errno.h>
 #include <string.h>
+#include <stdio.h>
 
 #include <pfe/file-sub.h>
 #include <pfe/logging.h>
@@ -44,6 +45,7 @@ p4_free_file_slot (void)
             memset (f, 0, sizeof *f);
             return f;
         }
+    P4_warn ("not enough file slots in pfe io subsystem");
     return NULL;
 }
 
@@ -57,13 +59,13 @@ p4_file_access (const char *fn, int len)
     char* buf;
 
     buf = p4_pocket_filename (fn, len);
-    if (access (buf, F_OK) != 0)
+    if (_P4_access (buf, F_OK) != 0)
         return -1;
-    if (access (buf, R_OK | W_OK) == 0)
+    if (_P4_access (buf, R_OK | W_OK) == 0)
         return FMODE_RW;
-    if (access (buf, R_OK) == 0)
+    if (_P4_access (buf, R_OK) == 0)
         return FMODE_RO;
-    if (access (buf, W_OK) == 0)
+    if (_P4_access (buf, W_OK) == 0)
         return FMODE_WO;
     return 0;
 }
@@ -84,7 +86,7 @@ p4_open_file (const char *name, int len, int mode)
     mode &= 7;
 
     fid = p4_free_file_slot ();
-    if (fid == NULL)
+    if (fid == NULL) 
         return NULL;
     p4_store_filename (name, len, fid->name, sizeof fid->name);
     fid->mode = mode;
@@ -92,7 +94,7 @@ p4_open_file (const char *name, int len, int mode)
     strcpy (fid->mdstr, open_mode[mode - FMODE_RO]);
     if ((fid->f = fopen (fid->name, fid->mdstr)) == NULL)
         return NULL;
-    fid->size = (p4ucell) (fsize (fid->f) / BPBUF);
+    fid->size = (p4ucell) (p4_file_size (fid->f) / BPBUF);
     fid->n = (unsigned) -1;
     return fid;
 }
@@ -120,7 +122,9 @@ p4_create_file (const char *name, int len, int mode)
     }
 #   undef null_AT_fclose
  _null:
-    if (mode > 256) { P4_fail2 ("%s : %s", fn, strerror(errno)); } /* updec! */
+    
+    if (mode > 256) /* updec! */
+    {   P4_fail2 ("%s : %s", fn, strerror(PFE_io_errno));   } 
     return NULL; 
 }
 
@@ -144,10 +148,10 @@ p4_close_file (p4_File *fid)
  * seek file
  */
 _export int
-p4_reposition_file (p4_File *fid, long pos)
+p4_reposition_file (p4_File *fid, _p4_off_t pos)
 {
     fid->last_op = 0;
-    return fseek (fid->f, pos, SEEK_SET) ? errno : 0;
+    return _p4_fseeko (fid->f, pos, SEEK_SET) ? PFE_io_errno : 0;
 }
 
 /*
@@ -164,7 +168,7 @@ p4_can_read (p4_File *fid)
          return 0;
     }
     if (fid->last_op < 0)		/* last operation was write? */
-        fseek (fid->f, 0, SEEK_CUR); /* then seek to this position */
+        _p4_fseeko (fid->f, 0, SEEK_CUR); /* then seek to this position */
     fid->last_op = 1;
     return 1;
 }
@@ -183,7 +187,7 @@ p4_can_write (p4_File *fid)
          return 0;
     }
     if (fid->last_op > 0)		/* last operation was read? */
-        fseek (fid->f, 0, SEEK_CUR); /* then seek to this position */
+        _p4_fseeko (fid->f, 0, SEEK_CUR); /* then seek to this position */
     fid->last_op = -1;
     return 1;
 }
@@ -203,7 +207,7 @@ p4_read_file (void *p, p4ucell *n, p4_File *fid)
     if (m != (int) *n)
     {
         *n = m;
-        return errno;
+        return PFE_io_errno;
     }
     else
         return 0;
@@ -218,33 +222,33 @@ p4_write_file (void *p, p4ucell n, p4_File *fid)
     if (!p4_can_write (fid))
         return EPERM;
     errno = 0;
-    return (p4ucell) fwrite (p, 1, n, fid->f) != n ? errno : 0;
+    return (p4ucell) fwrite (p, 1, n, fid->f) != n ? PFE_io_errno : 0;
 }
 
 /**
  * resize file
  */
 _export int
-p4_resize_file (p4_File *fid, long size)
+p4_resize_file (p4_File *fid, _p4_off_t size)
 {
-    long pos;
+    _p4_off_t pos;
     int r;
 
     if (fid == NULL || fid->f == NULL)
         p4_throw (P4_ON_FILE_NEX);
 
-    pos = ftell (fid->f);
+    pos = _p4_ftello (fid->f);
     if (pos == -1)
         return -1;
     
     fclose (fid->f);
-    r = fn_resize (fid->name, size);
+    r = p4_file_resize (fid->name, size);
     fid->f = fopen (fid->name, fid->mdstr);
     
     if (pos < size)
-        fseek (fid->f, pos, SEEK_SET);
+        _p4_fseeko (fid->f, pos, SEEK_SET);
     else
-        fseek (fid->f, 0, SEEK_END);
+        _p4_fseeko (fid->f, 0, SEEK_END);
     return r;
 }
 
@@ -258,7 +262,7 @@ p4_read_line (char *p, p4ucell *u, p4_File *fid, p4cell *ior)
     
     if (!p4_can_read (fid))
         return EPERM;
-    fid->pos = ftell (fid->f);
+    fid->line.pos = _p4_ftello (fid->f); /* fixme: the only reference to it!*/
     for (n = 0; (p4ucell) n < *u; n++)
     {
         switch (c = getc (fid->f))
@@ -269,7 +273,7 @@ p4_read_line (char *p, p4ucell *u, p4_File *fid, p4cell *ior)
          case EOF:
              *u = n;
              if (ferror (fid->f))
-                 *ior = errno;
+                 *ior = PFE_io_errno;
              else
                  *ior = 0;
              return P4_FLAG (n > 0);
@@ -303,7 +307,7 @@ p4_open_blockfile (const char *name, int len)
     int mode;
 
     fn = p4_pocket_expanded_filename (name, len, 
-				      P4_opt.blkpaths, P4_opt.blkext);
+				      *P4_opt.blk_paths, *P4_opt.blk_ext);
     mode = p4_file_access (fn, strlen (fn));
     if (mode <= 0)
         return NULL;
@@ -343,7 +347,7 @@ p4_read_write (p4_File *fid, char *p, p4ucell n, int readflag)
         memset (p, ' ', BPBUF);
         return;
     }
-    if (fseek (fid->f, n * BPBUF, SEEK_SET) != 0)
+    if (_p4_fseeko (fid->f, (_p4_off_t)n * BPBUF, SEEK_SET) != 0)
         p4_throws (FX_IOR, fid->name, 0);
     if (readflag)
     {
@@ -509,3 +513,8 @@ p4_thru (p4_File *fid, int lo, int hi)
 
 /*@}*/
 
+/* 
+ * Local variables:
+ * c-file-style: "stroustrup"
+ * End:
+ */
