@@ -5,8 +5,8 @@
  *
  *  @see     GNU LGPL
  *  @author  Tektronix CTE              @(#) %derived_by: guidod %
- *  @version %version: bln_mpt1!5.65 %
- *    (%date_modified: Fri Feb 28 12:39:04 2003 %)
+ *  @version %version: bln_mpt1!33.71 %
+ *    (%date_modified: Wed Mar 19 16:03:59 2003 %)
  *
  *  @description
  *      The Core Wordset contains the most of the essential words
@@ -15,7 +15,7 @@
 /*@{*/
 #if defined(__version_control__) && defined(__GNUC__)
 static char* id __attribute__((unused)) = 
-      "@(#) $Id: %full_filespec:  core-ext.c~bln_mpt1!5.65:csrc:bln_12xx!1 % $";
+      "@(#) $Id: %full_filespec:  core-ext.c~bln_mpt1!33.71:csrc:bln_12xx!1 % $";
 #endif
 
 #define _P4_SOURCE 1
@@ -813,6 +813,14 @@ FCode (p4_chars)
     *SP *= sizeof (char);
 }
 
+static P4_CODE_RUN(p4_constant_RT_SEE)
+{
+    strcat (p, p4_str_dot (*P4_TO_BODY (xt), p+200, BASE));
+    strcat (p, "CONSTANT ");
+    strncat (p, nfa+1, NFACNT(*nfa));
+    return 0;
+}
+
 /** "((CONSTANT))" ( -- )
  * runtime compiled by => CONSTANT
  */ 
@@ -837,7 +845,7 @@ FCode (p4_constant)
     FX_RUNTIME1 (p4_constant);
     FX_VCOMMA (*SP++);
 }
-P4RUNTIME1(p4_constant, p4_constant_RT);
+P4RUNTIMES1_(p4_constant, p4_constant_RT, 0,p4_constant_RT_SEE);
 
 
 /** COUNT ( counted-string -- string-pointer string-length )
@@ -965,6 +973,13 @@ FCode_RT (p4_variable_RT)
     FX_PUSH_SP = (p4cell) FX_POP_BODY_ADDR;
 }
 
+static P4_CODE_RUN(p4_builds_RT_SEE)
+{
+    strcat (p, "CREATE ");
+    strncat (p, nfa+1, NFACNT(*nfa));
+    return 0;
+}
+
 /** "((BUILDS))" ( -- pfa )
  * the runtime compiled by => CREATE which
  * is not much unlike a => VARIABLE 
@@ -994,7 +1009,7 @@ FCode_RT (p4_does_RT)
     ((p4code)(*P4_TO_DOES_CODE(xt)))(); /* from CFA[1] */
 #  endif
 }}
-P4RUNTIME1 (p4_does, p4_does_RT);
+P4RUNTIME1(p4_does, p4_does_RT);
 
 /** "(DOES>)" ( -- pfa )
  * execution compiled by => DOES>
@@ -1092,7 +1107,7 @@ FCode (p4_builds)
     FX_RUNTIME1 (p4_builds);
     FX_RCOMMA (0);
 }
-P4RUNTIME1(p4_builds, p4_builds_RT);
+P4RUNTIMES1_(p4_builds, p4_builds_RT, 0, p4_builds_RT_SEE);
 
 
 /** DROP ( a -- )
@@ -1270,7 +1285,7 @@ FCode (p4_find)
     if (p)
     {
         *SP = (p4cell) p4_name_from (p);
-        FX_PUSH_SP = *_FFA(p) & P4xIMMEDIATE ? P4_POSITIVE : P4_NEGATIVE;
+        FX_PUSH_SP = P4_NFA_xIMMEDIATE(p) ? P4_POSITIVE : P4_NEGATIVE;
     }
     else
         FX_PUSH_SP = 0;
@@ -1354,7 +1369,7 @@ P4COMPILES (p4_if, p4_if_execution,
 FCode (p4_immediate)
 {
     if (LAST)
-        *_FFA(LAST) |= P4xIMMEDIATE;
+        P4_NFA_FLAGS(LAST) |= P4xIMMEDIATE;
     else
         p4_throw (P4_ON_ARG_TYPE);
 }
@@ -1607,11 +1622,11 @@ FCode (p4_postpone)
     FX (p4_Q_comp);
     nfa = p4_tick_nfa (FX_VOID);
 # ifndef PFE_CALL_THREADING
-    if (!( *_FFA (nfa) & P4xIMMEDIATE))
+    if (! P4_NFA_xIMMEDIATE (nfa))
         FX_COMPILE (p4_postpone);
     FX_XCOMMA (p4_name_from (nfa)); /* a.k.a. FX_COMPILE_COMMA */
 # else
-    if (!( *_FFA (nfa) & P4xIMMEDIATE))
+    if (! P4_NFA_xIMMEDIATE (nfa))
     {
 	FX_COMPILE (p4_postpone);
 	FX_XCOMMA (p4_name_from(nfa));
@@ -2355,6 +2370,12 @@ FCode (p4_c_quote)
 P4COMPILES (p4_c_quote, p4_c_quote_execution,
   P4_SKIPS_STRING, P4_DEFAULT_STYLE);
 
+#ifndef PFE_CALL_THREADING
+#define p4_case_RT p4_noop
+#else
+static FCode_RT(p4_case_RT) { /*nothing*/ }
+#endif
+
 /** CASE ( comp-value -- comp-value )
  * start a CASE construct that ends at => ENDCASE
  * and compares the value on stack at each => OF place
@@ -2366,7 +2387,7 @@ FCode (p4_case)
     CSP = SP;
     FX_PUSH (P4_CASE_MAGIC);
 }
-P4COMPILES (p4_case, p4_noop, P4_SKIPS_NOTHING, P4_CASE_STYLE);
+P4COMPILES (p4_case, p4_case_RT, P4_SKIPS_NOTHING, P4_CASE_STYLE);
 
 /** "COMPILE," ( xt -- )
  * place the execution-token on stack into the dictionary - in
@@ -2393,6 +2414,12 @@ FCode (p4_convert)
           (p4udcell *) &SP[1], BASE);
 }
 
+#ifndef PFE_CALL_THREADING
+#define p4_endcase_RT p4_drop
+#else
+static FCode_RT(p4_endcase_RT) { FX (p4_drop); }
+#endif
+
 /** ENDCASE ( comp-value -- )
  * ends a => CASE construct that may surround multiple sections of
  * => OF ... => ENDOF code-portions. The => ENDCASE has to resolve the
@@ -2407,7 +2434,7 @@ FCode (p4_endcase)
         FX (p4_forward_resolve);
     CSP = (p4cell *) FX_POP;
 }
-P4COMPILES (p4_endcase, p4_drop,
+P4COMPILES (p4_endcase, p4_endcase_RT,
   P4_SKIPS_NOTHING, P4_ENDCASE_STYLE);
 
 /** ENDOF ( -- ) 
@@ -2456,78 +2483,6 @@ FCode (p4_hex)
     BASE = 16;
 }
 
-/** "((MARKER))" ( -- )
- * runtime compiled by => MARKER
- */ 
-FCode_RT (p4_marker_RT)
-{   FX_USE_BODY_ADDR {
-    int i;
-    void** RT = (void*) FX_POP_BODY_ADDR;
-    void* forget_address;
-    /* assert (sizeof(void*) == sizeof(p4cell)) */
-
-    forget_address =       (*RT++); 
-    p4_FENCE =   (p4char*) (*RT++);
-    p4_LAST =      (char*) (*RT++);
-    p4_VOC_LINK = (Wordl*) (*RT++);
-    p4_ONLY =     (Wordl*) (*RT++);
-    p4_CURRENT =  (Wordl*) (*RT++);
-    for (i=0; i < PFE_set.wordlists ; i++)
-    {
-        if (! *RT) break;
-        p4_CONTEXT[i] = (Wordl*) (*RT++);
-    }
-    RT++; /* skip null */
-    for (i=0; i < PFE_set.wordlists ; i++)
-    {
-        if (! *RT) break;
-        p4_DFORDER[i] = (Wordl*) (*RT++);
-    }
-    p4_forget (forget_address); /* will set the PFE.dp */
-}}
-
-/** "(MARKER)" ( str-ptr str-len -- )
- * create a named marker that you can use to => FORGET ,
- * running the created word will reset the dict/order variables
- * to the state at the creation of this name.
- : (MARKER) (CREATE) HERE , 
-         GET-ORDER DUP , 0 DO ?DUP IF , THEN LOOP 0 , 
-         ...
-   DOES> DUP @ (FORGET) 
-         ...
- ; 
- */
-FCode (p4_paren_marker)
-{
-    int i;
-    char* forget_address = PFE.dp;
-
-    p4_header_comma ((p4char*)SP[1], (unsigned)SP[0], CURRENT);
-    FX_RUNTIME1 (p4_marker);
-
-    FX_PCOMMA (forget_address); /* PFE.dp restore */
-    FX_PCOMMA (p4_FENCE);
-    FX_PCOMMA (p4_LAST);
-    FX_PCOMMA (p4_VOC_LINK);
-    FX_PCOMMA (p4_ONLY);
-    FX_PCOMMA (p4_CURRENT);
-
-    /* we do not need to memorize null-ptrs in the search-order,
-     * and we use a nullptr to flag the end of the saved ptrlist
-     */
-
-    for (i=0; i < PFE_set.wordlists ; i++)
-        if (p4_CONTEXT[i]) 
-            FX_PCOMMA (p4_CONTEXT[i]); 
-    FX_UCOMMA (0);
-
-    for (i=0; i < PFE_set.wordlists ; i++)
-        if (p4_DFORDER[i]) 
-            FX_PCOMMA (p4_DFORDER[i]); 
-    FX_UCOMMA (0);
-    FX_2DROP; 
-}
-
 /** MARKER ( 'name' -- )
  * create a named marker that you can use to => FORGET ,
  * running the created word will reset the dict/order variables
@@ -2535,35 +2490,16 @@ FCode (p4_paren_marker)
  : MARKER PARSE-WORD (MARKER) ;
  * see also => ANEW which is not defined in ans-forth but which uses
  * the => MARKER functionality in the way it should have been defined.
+ : MARKER PARSE-WORD (MARKER) ;
  */
 FCode (p4_marker)
 {
+    extern FCode (p4_paren_marker);
     FX (p4_parse_word);
     FX (p4_paren_marker);
 }
 P4RUNTIME1(p4_marker, p4_marker_RT);
 
-/** ANEW ( 'name' -- )
- * creates a => MARKER if it doesn't exist,
- * or forgets everything after it if it does. (it just gets executed).
- : ANEW BL WORD   DUP FIND NIP IF EXECUTE THEN   (MARKER) ;
- */
-FCode (p4_anew)
-{
-    register p4char* p;
-    FX (p4_parse_word);
-    if (SP[0] && (p= p4_find ((p4char*)(SP[1]), (p4ucell)(SP[0])) ))
-    {
-        register p4xt xt = p4_name_from (p);
-        if (*P4_TO_CODE(xt) != PFX(p4_marker_RT))
-            P4_fail2 ("ANEW did find non-MARKER name"
-                      " called '%.*s' as its argument, still executing...",  
-                      (int)(SP[0]), (p4char*)(SP[1]));
-        p4_call (xt);
-    }
-    FX (p4_paren_marker);
-}
-
 /** NIP ( a b -- b )
  * drop the value under the top of stack, inverse of => TUCK
  simulate:        : NIP SWAP DROP ;
@@ -2805,6 +2741,14 @@ FCode (p4_unused)
     FX_PUSH (PFE.dictlimit - DP);
 }
 
+static P4_CODE_RUN(p4_value_RT_SEE)
+{
+    strcat (p, p4_str_dot (*P4_TO_BODY (xt), p+200, BASE));
+    strcat (p, "VALUE ");
+    strncat (p, nfa+1, NFACNT(*nfa));
+    return 0;
+}
+
 /** "((VALUE))" ( -- value )
  * runtime compiled by => VALUE
  */ 
@@ -2826,7 +2770,7 @@ FCode (p4_value)
     FX_RUNTIME1 (p4_value);
     FX_VCOMMA (*SP++);
 }
-P4RUNTIME1 (p4_value, p4_value_RT);
+P4RUNTIMES1_ (p4_value, p4_value_RT, 0,p4_value_RT_SEE);
 
 /** WITHIN ( a b c -- cond )
  * a widely used word, returns ( b <= a && a < c ) so
@@ -3198,7 +3142,7 @@ P4_LISTWORDS (core) =
     P4_FXco ("EXPECT",       p4_expect),
     P4_OCoN ("FALSE",        P4_FALSE),
     P4_FXco ("HEX",          p4_hex),
-    P4_FXco ("MARKER",       p4_marker),
+    P4_RTco ("MARKER",       p4_marker),
     P4_FXco ("NIP",          p4_nip),
     P4_SXco ("OF",           p4_of),
     P4_FXco ("PAD",          p4_pad),
@@ -3233,10 +3177,6 @@ P4_LISTWORDS (core) =
     P4_FNYM ("CREATE",       "<BUILDS"),
     P4_FNYM ("'",            "CFA'"),
 
-    P4_INTO ("EXTENSIONS", "FORTH"),
-    P4_FXco ("(MARKER)",     p4_paren_marker),
-    P4_FXco ("ANEW",         p4_anew),
-
     P4_INTO ("ENVIRONMENT", 0),
     /* enviroment hints (testing for -EXT will mark this wordset as present) */
     P4_OCoN ("CORE-EXT",                1994 ),
