@@ -1,8 +1,8 @@
 #ifndef _PFE_CORE_EXT_H
-#define _PFE_CORE_EXT_H 1002653673
-/* generated 2001-1009-2054 ../../../pfe/../mk/Make-H.pl ../../../pfe/core-ext.c */
+#define _PFE_CORE_EXT_H 1063198926
+/* generated 2003-0910-1502 ../../../pfe/../mk/Make-H.pl ../../../pfe/core-ext.c */
 
-#include <pfe/incl-ext.h>
+#include <pfe/pfe-ext.h>
 
 /**
  *  CORE-EXT -- The standard CORE and CORE-EXT wordset
@@ -11,8 +11,8 @@
  *
  *  @see     GNU LGPL
  *  @author  Tektronix CTE              @(#) %derived_by: guidod %
- *  @version %version: bln_mpt1!5.33 %
- *    (%date_modified: Mon Oct 08 19:18:14 2001 %)
+ *  @version %version: bln_mpt1!33.71 %
+ *    (%date_modified: Wed Mar 19 16:03:59 2003 %)
  *
  *  @description
  *      The Core Wordset contains the most of the essential words
@@ -27,6 +27,7 @@ extern "C" {
 
 
 /** ! ( val addr -- )
+ * store value at addr (sizeof =>"CELL")
  */
 extern P4_CODE (p4_store);
 
@@ -66,13 +67,13 @@ extern P4_CODE (p4_sh_s);
  */
 extern P4_CODE (p4_tick);
 
-/** (  ( 'comment<closeparen>' -- ) 
+/** "("  ( 'comment<closeparen>' -- ) 
  * eat everything up to the next closing paren - treat it
  * as a comment.
  */
 extern P4_CODE (p4_paren);
 
-/** * ( a b -- a*b ) 
+/** "*" ( a b -- a*b ) 
  * return the multiply of the two args
  */
 extern P4_CODE (p4_star);
@@ -104,7 +105,7 @@ extern P4_CODE (p4_plus);
  */
 extern P4_CODE (p4_plus_store);
 
-/** ((+LOOP)) ( increment -- ) 
+/** "((+LOOP))" ( increment -- ) 
  * compiled by => +LOOP
  */
 extern P4_CODE (p4_plus_loop_execution);
@@ -116,39 +117,39 @@ extern P4_CODE (p4_plus_loop_execution);
  */
 extern P4_CODE (p4_plus_loop);
 
-/** , ( val -- ) 
+/** "," ( val -- ) 
  * store the value in the dictionary
  simulate:
    : , DP  1 CELLS DP +!  ! ;
  */
 extern P4_CODE (p4_comma);
 
-/** - ( a b -- a-b ) 
+/** "-" ( a b -- a-b ) 
  * return the difference of the two arguments
  */
 extern P4_CODE (p4_minus);
 
-/** . ( val -- ) 
+/** "." ( val -- ) 
  * print the numerical value to stdout - uses => BASE
  */
 extern P4_CODE (p4_dot);
 
-/** ((.")) ( -- ) _skip_string_
+/** '((.\"))' ( -- ) _skip_string_
  * compiled by => ." string"
  */
 extern P4_CODE (p4_dot_quote_execution);
 
-/** ." ( [string<">] -- ) 
+/** '.\"' ( [string<">] -- ) 
  * print the string to stdout
  */
 extern P4_CODE (p4_dot_quote);
 
-/** / ( a b  -- a/b ) 
+/** "/" ( a b  -- a/b ) 
  * return the quotient of the two arguments
  */
 extern P4_CODE (p4_slash);
 
-/** /MOD ( a b -- m n ) 
+/** "/MOD" ( a b -- m n ) 
  * divide a and b and return both
  * quotient n and remainder m
  */
@@ -235,7 +236,7 @@ extern P4_CODE (p4_two_over);
  */
 extern P4_CODE (p4_two_swap);
 
-/** (NEST) ( -- ) 
+/** "(NEST)" ( -- ) 
  * compiled by => :
  * (see also => (NONAME) compiled by => :NONAME )
  */
@@ -243,7 +244,7 @@ extern P4_CODE (p4_colon_RT);
 
 extern P4_CODE (p4_colon_EXIT);
 
-/** : ( 'name' -- ) 
+/** ":" ( 'name' -- ) 
  * create a header for a nesting word and go to compiling
  * mode then. This word is usually ended with => ; but
  * the execution of the resulting colon-word can also 
@@ -251,13 +252,13 @@ extern P4_CODE (p4_colon_EXIT);
  */
 extern P4_CODE (p4_colon);
 
-/** ((;)) ( -- ) 
+/** "((;))" ( -- ) 
  * compiled by => ; and maybe => ;AND --
  * it will perform an => EXIT
  */
 extern P4_CODE (p4_semicolon_execution);
 
-/** ; ( -- ) 
+/** ";" ( -- ) 
  * compiles => ((;)) which does => EXIT the current
  * colon-definition. It does then end compile-mode
  * and returns to execute-mode. See => : and => :NONAME
@@ -312,6 +313,8 @@ extern P4_CODE (p4_to_number);
  */
 extern P4_CODE (p4_to_r);
 
+extern P4_CODE (p4_to_r_execution);
+
 /** ?DUP ( value -- value|[nothing] )
  * one of the rare words whose stack-change is 
  * condition-dependet. This word will duplicate
@@ -429,7 +432,7 @@ extern P4_CODE (p4_char_plus);
  */
 extern P4_CODE (p4_chars);
 
-/** ((CONSTANT)) ( -- )
+/** "((CONSTANT))" ( -- )
  * runtime compiled by => CONSTANT
  */
 extern P4_CODE (p4_constant_RT);
@@ -447,6 +450,8 @@ extern P4_CODE (p4_constant);
 
 /** COUNT ( counted-string -- string-pointer string-length )
  * usually before calling => TYPE
+ *
+ * (as an unwarranted extension, this word does try to be idempotent).
  */
 extern P4_CODE (p4_count);
 
@@ -468,7 +473,7 @@ extern P4_CODE (p4_decimal);
  */
 extern P4_CODE (p4_depth);
 
-/** ((DO)) ( end start -- )
+/** "((DO))" ( end start -- )
  * compiled by => DO
  */
 extern P4_CODE (p4_do_execution);
@@ -481,29 +486,29 @@ extern P4_CODE (p4_do_execution);
  */
 extern P4_CODE (p4_do);
 
-/** ((VAR)) ( -- pfa )
+/** "((VAR))" ( -- pfa )
  * the runtime compiled by => VARIABLE
  */
-extern P4_CODE (p4_var_RT);
+extern P4_CODE (p4_variable_RT);
 
-/** ((BUILDS)) ( -- pfa )
+/** "((BUILDS))" ( -- pfa )
  * the runtime compiled by => CREATE which
  * is not much unlike a => VARIABLE 
  * (in ANS Forth Mode we reserve an additional DOES-field)
  */
 extern P4_CODE (p4_builds_RT);
 
-/** ((DOES>)) ( -- pfa )
+/** "((DOES>))" ( -- pfa )
  * runtime compiled by DOES>
  */
-extern P4_CODE (p4_does_defined_RT);
+extern P4_CODE (p4_does_RT);
 
-/** (DOES>) ( -- pfa )
+/** "(DOES>)" ( -- pfa )
  * execution compiled by => DOES>
  */
 extern P4_CODE (p4_does_execution);
 
-/** DOES> ( -- pfa )
+/** "DOES>" ( -- pfa )
  * does twist the last => CREATE word to carry
  * the => (DOES>) runtime. That way, using the
  * word will execute the code-piece following => DOES>
@@ -522,7 +527,7 @@ extern P4_CODE (p4_does);
  *  the ans-forth => CREATE is the same as =>"<BUILDS"
  : <BUILDS BL WORD HEADER DOCREATE A, 0 A, ;
  */
-extern P4_CODE (p4_create_does);
+extern P4_CODE (p4_builds);
 
 /** DROP ( a -- )
  * just drop the word on the top of stack, see => DUP
@@ -536,7 +541,7 @@ extern P4_CODE (p4_drop);
  */
 extern P4_CODE (p4_dup);
 
-/** ((ELSE)) ( -- )
+/** "((ELSE))" ( -- )
  * execution compiled by => ELSE - just a simple
  * => BRANCH
  */
@@ -602,12 +607,13 @@ extern P4_CODE (p4_fill);
  * the name string as the name of a word. Returns its
  * execution-token or the original-bstring if not found,
  * along with a flag-like value that is zero if nothing
- * could be found. Otherwise it will be 1 if the word had
- * been immediate, -1 otherwise.
+ * could be found. Otherwise it will be 1 (a positive value)
+ * if the word had been immediate, -1 otherwise (a negative
+ * value).
  */
 extern P4_CODE (p4_find);
 
-/** FM/MOD ( n1.n1 n2 -- m n )
+/** "FM/MOD" ( n1.n1 n2 -- m n )
  * divide the double-cell value n1 by n2 and return
  * both (floored) quotient n and remainder m 
  */
@@ -630,7 +636,9 @@ extern P4_CODE (p4_hold);
  */
 extern P4_CODE (p4_i);
 
-/** ((IF)) ( -- )
+extern P4_CODE (p4_i_execution);
+
+/** "((IF))" ( -- )
  * execution word compiled by => IF - just some simple => ?BRANCH
  */
 extern P4_CODE (p4_if_execution);
@@ -662,6 +670,8 @@ extern P4_CODE (p4_invert);
  */
 extern P4_CODE (p4_j);
 
+extern P4_CODE (p4_j_execution);
+
 /** KEY ( -- char ) 
  * return a single character from the keyboard - the
  * key is not echoed.
@@ -675,7 +685,9 @@ extern P4_CODE (p4_key);
  */
 extern P4_CODE (p4_leave);
 
-/** ((LIT)) ( -- value )
+extern P4_CODE (p4_leave_execution);
+
+/** "((LIT))" ( -- value )
  * execution compiled by => LITERAL
  */
 extern P4_CODE (p4_literal_execution);
@@ -692,7 +704,7 @@ extern P4_CODE (p4_literal_execution);
  */
 extern P4_CODE (p4_literal);
 
-/** ((LOOP)) ( -- )
+/** "((LOOP))" ( -- )
  * execution compiled by => LOOP
  */
 extern P4_CODE (p4_loop_execution);
@@ -752,7 +764,7 @@ extern P4_CODE (p4_or);
  */
 extern P4_CODE (p4_over);
 
-/** ((POSTPONE)) ( -- )
+/** "((POSTPONE))" ( -- )
  * execution compiled by => POSTPONE
  */
 extern P4_CODE (p4_postpone_execution);
@@ -791,15 +803,19 @@ extern P4_CODE (p4_quit);
  */
 extern P4_CODE (p4_r_from);
 
+extern P4_CODE (p4_r_from_execution);
+
 /** R@ ( R: a -- a R: a )
  * fetch the (upper-most) value from the return-stack that had
- * been saved there using => >R - This is the traditional form of a local
+ * been saved there using =>">R" - This is the traditional form of a local
  * var space. If you need more local variables you should have a 
- * look at => LOCALS| , see also => >R and => R> . Without LOCALS-EXT
- * there are useful words like => 2R@ => R'@ => R"@ => R! 
+ * look at => LOCALS| , see also =>">R" and =>"R>" . Without LOCALS-EXT
+ * there are useful words like =>"2R@" =>"R'@" =>'R"@' =>'R!' 
  */
 extern P4_CODE (p4_r_fetch);
 
+extern P4_CODE (p4_r_fetch_execution);
+
 /** RECURSE ( ? -- ? )
  * when creating a colon word the name of the currently-created
  * word is smudged, so that you can redefine a previous word
@@ -833,7 +849,7 @@ extern P4_CODE (p4_rot);
  */
 extern P4_CODE (p4_r_shift);
 
-/** ((S")) ( -- string-address string-length )
+/** '((S"))' ( -- string-address string-length )
  * execution compiled by => S"
  */
 extern P4_CODE (p4_s_quote_execution);
@@ -917,7 +933,7 @@ extern P4_CODE (p4_u_less_than);
  */
 extern P4_CODE (p4_u_m_star);
 
-/** UM/MOD ( a b -- c,c )
+/** "UM/MOD" ( a b -- c,c )
  * see => /MOD and => SM/REM
  */
 extern P4_CODE (p4_u_m_slash_mod);
@@ -929,6 +945,8 @@ extern P4_CODE (p4_u_m_slash_mod);
  */
 extern P4_CODE (p4_unloop);
 
+extern P4_CODE (p4_unloop_execution);
+
 /** UNTIL ( cond -- )
  * ends an control-loop, see => BEGIN and compare with => WHILE
  */
@@ -994,7 +1012,7 @@ extern P4_CODE (p4_bracket_char);
  */
 extern P4_CODE (p4_right_bracket);
 
-/** .( ( [message<closeparen>] -- )
+/** ".(" ( [message<closeparen>] -- )
  * print the message to the screen while reading a file. This works
  * too while compiling, so you can whatch the interpretation/compilation
  * to go on. Some Forth-implementations won't even accept a => ." message"
@@ -1009,7 +1027,7 @@ extern P4_CODE (p4_dot_paren);
  */
 extern P4_CODE (p4_dot_r);
 
-/** '0<>' ( value -- cond )
+/** "0<>" ( value -- cond )
  * returns a logical-value saying if the value was not-zero.
  * This is most useful in turning a numerical value into a 
  * boolean value that can be fed into bitwise words like
@@ -1029,21 +1047,27 @@ extern P4_CODE (p4_zero_greater);
  */
 extern P4_CODE (p4_two_to_r);
 
+extern P4_CODE (p4_two_to_r_execution);
+
 /** 2R> ( R: a,a -- a,a R: )
  * pop back a double-cell value from the return-stack, see => R>
  * and the earlier used => 2>R
  */
 extern P4_CODE (p4_two_r_from);
 
+extern P4_CODE (p4_two_r_from_execution);
+
 /** 2R@ ( R: a,a -- a,a R: a,a )
  * fetch a double-cell value from the return-stack, that had been
- * previously been put there with => 2>R - see => R@ for single value.
+ * previously been put there with =>"2>R" - see =>"R@" for single value.
  * This can partly be a two-cell => LOCALS| value,  without LOCALS-EXT
- * there are alos other useful words like => 2R! => R'@ => R"@
+ * there are alos other useful words like =>"2R!" =>"R'@" =>'R"@'
  */
 extern P4_CODE (p4_two_r_fetch);
 
-/** (NONAME) ( -- ) 
+extern P4_CODE (p4_two_r_fetch_execution);
+
+/** "(NONAME)" ( -- ) 
  * compiled by => :NONAME
  * (see also => (NEST) compiled by => : (execution is identical))
  */
@@ -1060,12 +1084,12 @@ extern P4_CODE (p4_colon_noname_EXIT);
  */
 extern P4_CODE (p4_colon_noname);
 
-/** '<>' ( a b -- cond )
+/** "<>" ( a b -- cond )
  * return true if a and b are not equal, see => = 
  */
 extern P4_CODE (p4_not_equals);
 
-/** ((?DO)) ( a b -- )
+/** "((?DO))" ( a b -- )
  * execution compiled by => ?DO
  */
 extern P4_CODE (p4_Q_do_execution);
@@ -1083,7 +1107,7 @@ extern P4_CODE (p4_Q_do);
  */
 extern P4_CODE (p4_again);
 
-/** ((C")) ( -- bstring )
+/** '((C"))' ( -- bstring )
  * execution compiled by => C" string"
  */
 extern P4_CODE (p4_c_quote_execution);
@@ -1102,7 +1126,7 @@ extern P4_CODE (p4_c_quote);
  */
 extern P4_CODE (p4_case);
 
-/** COMPILE, ( xt -- )
+/** "COMPILE," ( xt -- )
  * place the execution-token on stack into the dictionary - in
  * traditional forth this is not even the least different than
  * a simple => , but in call-threaded code there's a big 
@@ -1151,21 +1175,6 @@ extern P4_CODE (p4_expect);
  */
 extern P4_CODE (p4_hex);
 
-/** ((MARKER)) ( -- )
- * runtime compiled by => MARKER
- */
-extern P4_CODE (p4_marker_RT);
-
-/** "(MARKER)" ( str-ptr str-len -- )
- * create a named marker that you can use to => FORGET ,
- * running the created word will reset the dict/order variables
- * to the state at the creation of this name.
- : (MARKER) (CREATE) HERE , GET-ORDER DUP , 0 DO , LOOP  etc...
-   DOES> DUP @ (FORGET) CELL+ DUP CELL+ SWAP @ SET-ORDER etc...
- ; 
- */
-extern P4_CODE (p4_paren_marker);
-
 /** MARKER ( 'name' -- )
  * create a named marker that you can use to => FORGET ,
  * running the created word will reset the dict/order variables
@@ -1173,23 +1182,17 @@ extern P4_CODE (p4_paren_marker);
  : MARKER PARSE-WORD (MARKER) ;
  * see also => ANEW which is not defined in ans-forth but which uses
  * the => MARKER functionality in the way it should have been defined.
+ : MARKER PARSE-WORD (MARKER) ;
  */
 extern P4_CODE (p4_marker);
 
-/** ANEW ( 'name' -- )
- * creates a => MARKER if it doesn't exist,
- * or forgets everything after it if it does. (it just gets executed).
- : ANEW BL WORD   DUP FIND NIP IF EXECUTE THEN   (MARKER) ;
- */
-extern P4_CODE (p4_anew);
-
 /** NIP ( a b -- b )
  * drop the value under the top of stack, inverse of => TUCK
  simulate:        : NIP SWAP DROP ;
  */
 extern P4_CODE (p4_nip);
 
-/** ((OF)) ( check val -- check )
+/** "((OF))" ( check val -- check )
  * execution compiled by => OF
  */
 extern P4_CODE (p4_of_execution);
@@ -1207,11 +1210,13 @@ extern P4_CODE (p4_of);
  */
 extern P4_CODE (p4_pad);
 
-/** PARSE ( buffer-start buffer-count delim-char -- )
+/** PARSE ( delim-char -- buffer-start buffer-count )
  * parse a piece of input (not much unlike WORD) and place
  * it into the given buffer. The difference with word is
- * also that WORD would first skip any delim-char while
- * PARSE does not and thus may yield that one.
+ * also that => WORD would first skip any delim-char while
+ * => PARSE does not and thus may yield that one. In a newer
+ * version, => PARSE will not copy but just return the word-span
+ * being seen in the input-buffer - therefore a transient space.
  */
 extern P4_CODE (p4_parse);
 
@@ -1263,7 +1268,7 @@ extern P4_CODE (p4_roll);
  */
 extern P4_CODE (p4_save_input);
 
-/** ((TO)) ( value -- )
+/** "((TO))" ( value -- )
  * execution compiled by => TO
  */
 extern P4_CODE (p4_to_execution);
@@ -1299,7 +1304,7 @@ extern P4_CODE (p4_u_greater_than);
  */
 extern P4_CODE (p4_unused);
 
-/** ((VALUE)) ( -- value )
+/** "((VALUE))" ( -- value )
  * runtime compiled by => VALUE
  */
 extern P4_CODE (p4_value_RT);
