@@ -5,8 +5,8 @@
  *
  *  @see     GNU LGPL
  *  @author  Tektronix CTE            @(#) %derived_by: guidod %
- *  @version %version: bln_mpt1!5.36 %
- *    (%date_modified: Wed Jul 17 18:02:23 2002 %)
+ *  @version %version: bln_mpt1!5.42 %
+ *    (%date_modified: Tue Mar 18 16:16:55 2003 %)
  *  @description
  *         Subroutines for the Forth Core System - especially the
  *         general input/output routines like ACCEPT/QUERY/WORD/PARSE 
@@ -15,7 +15,7 @@
 /*@{*/
 #if defined(__version_control__) && defined(__GNUC__)
 static char* id __attribute__((unused)) = 
-"@(#) $Id: %full_filespec:  core-sub.c~bln_mpt1!5.36:csrc:bln_12xx!1 % $";
+"@(#) $Id: %full_filespec:  core-sub.c~bln_mpt1!5.42:csrc:bln_12xx!1 % $";
 #endif
 
 #define _P4_SOURCE 1
@@ -93,9 +93,8 @@ p4_strpush (const char *s)
 _export char *
 p4_pocket (void)
 {
-    register char *p = PFE.pockets[PFE.pocket];
-
-    PFE.pocket = (PFE.pocket + 1) % P4_opt.pockets;
+    register char *p = PFE.pocket->buffer;
+    if (++ PFE.pocket >= PFE.pockets_top) PFE.pocket = PFE.pockets_ptr;
     return p;
 }
 
@@ -127,15 +126,16 @@ p4_dash_trailing (char *s, int n)
 /*  cygwin32 and borland and probably other win32 platforms */
 #   define p4_strncmpi strncmpi
 #  else
+#   define p4_strncmpi_RT p4_strncmpi
     extern int p4_strncmpi ( const char *s1, const char* s2, int n); 
 #  endif
 # endif
 #endif
 
-#ifndef p4_strncmpi 
+#ifdef p4_strncmpi_RT
 /* _strncmpi_ ( str1* str2* max# -- cmp? ) */
 int
-p4_strncmpi (const char* p, const char* q, int n)
+p4_strncmpi_RT (const char* p, const char* q, int n)
 {
 #if defined PFE_HAVE_STRNCASECMP
     return strncasecmp (p, q, n);
@@ -284,16 +284,16 @@ p4_pocket_filename (const char* src, int n)
  */
 
 /* <try-extensions> ( zstr* zext* -- ?ok )
- * Append all extensions from ext to nm.
+ * Append all extensions from ext to nm (which is assumed to be like a POCKET)
  * Check if file exists, if so return true, else false.
- * the nm-string is expected to max. pocket_size.
+ * The nm-string is expected to be writeable up to max. pocket_size.
  */
 static int
 try_extensions (char *nm, const char *ext)
 {
     int vv,v;
 
-    if (access (nm, F_OK) == 0)
+    if (_P4_access (nm, F_OK) == 0)
 	return 1;
 
     vv = strlen (nm);
@@ -307,7 +307,7 @@ try_extensions (char *nm, const char *ext)
 	{ ext++; }
 	do { nm[v++] = *ext++; }
 	while (*ext && *ext != PFE_PATH_DELIMITER && v < P4_POCKET_SIZE-1);
-	if (access (nm, F_OK) == 0)
+	if (_P4_access (nm, F_OK) == 0)
 	    return 1;
     }
     nm[vv] = '\0';
@@ -1193,6 +1193,18 @@ p4_size_saved_input (void)
     return sizeof (Iframe);
 }
 
+/*NOTE: the (void* p) is often the RP being aligned to 32bit on most
+ * platforms but an Iframe contains an .input.off possibly being 64bit
+ * wide when off_t=64bit. This creates an alignment problem. We fix it
+ * here with a CP operation. A better variant would be align the input
+ * pointer magically in p4_save_input, until someone calls p4_link_s..
+ */
+
+/* I hate compiler bugs, especially this one for solaris gcc 2.95 : */
+/* #define CP(X,I,Y) memcpy ((char*)&(X), (char*)&(Y), (int)sizeof(X)) */
+#define CP(X,I,Y) { register int i = sizeof((X)); \
+                    memcpy ((char*)&(X), (char*)&(Y), i); }
+
 /** _link_saved_input_ ( iframe* -- )
  * see => SAVE-INPUT
  */
@@ -1200,9 +1212,9 @@ _export void
 p4_link_saved_input (void *p)
 {
     Iframe *iframe = (Iframe *) p;
-    
+
     iframe->magic = P4_INPUT_MAGIC;
-    iframe->input = PFE.input;
+    CP(iframe->input, =, PFE.input);
     iframe->prev = PFE.saved_input;
     PFE.saved_input = iframe;
 }
@@ -1229,7 +1241,7 @@ p4_unlink_saved_input (void *p)
 
     if (iframe->magic != P4_INPUT_MAGIC)
         p4_throw (P4_ON_ARG_TYPE);
-    PFE.input = iframe->input;
+    CP(PFE.input, = ,iframe->input);
     PFE.saved_input = iframe->prev;
 }
 
@@ -1434,8 +1446,18 @@ p4_word (char del)
 _export int
 p4_word_parseword (char del)
 {
+    /* quick path for wordset-loader: */
+    if (SOURCE_ID == -1 && PFE.word.len == -1) goto tib_static_string;
     p4_skip_delimiter (del);
     return p4_word_parse (del);
+
+ tib_static_string:
+    PFE.word.len = strlen (PFE.word.ptr);
+    /* if (! FENCE) return; // libpfe.so is firing up */
+
+    /* assume: PFE.word.ptr points to the static_string we like to have */
+    TIB = PFE.word.ptr; NUMBER_TIB = PFE.word.len; TO_IN = 0;
+    return PFE.word.len;
 }
 
 #if 0
