@@ -5,8 +5,8 @@
  *
  *  @see     GNU LGPL
  *  @author  Tektronix CTE             @(#) %derived_by: guidod %
- *  @version %version: bln_mpt1!5.36 %
- *    (%date_modified: Tue Jun 18 14:49:54 2002 %)
+ *  @version %version: bln_mpt1!33.39 %
+ *    (%date_modified: Wed Mar 19 16:52:22 2003 %)
  *
  *  @description
  *	The Portable Forth Environment provides a decompiler for
@@ -97,6 +97,70 @@ static char* id __attribute__((unused)) =
 #include <string.h>
 
 #include <pfe/_missing.h>
+
+#define ___ {
+#define ____ }
+
+/* ----------------------------------------------------------------------- */
+
+const char*
+p4_loader_next_wordset (p4_Decompile* decomp)
+{
+    p4xt xt;
+    do {
+	if (! decomp->next) return decomp->next;
+	xt = p4_name_from (decomp->next);
+	decomp->next = *P4_TO_LINK(xt);
+    } while (*P4_TO_CODE(xt) != p4_forget_wordset_RT_);
+    /* assert xt is wordset_RT */
+    /* FIXME: forget-layout? BODY[0] has the value? */
+    ___ p4Words* ws = *(p4Words**) P4_TO_BODY(xt); 
+    decomp->left = ws->n;
+    decomp->word = (void*) ws->w;
+    decomp->wordset = ws->name;
+    ____;
+    return decomp->wordset;
+}
+    
+p4char p4_loader_next (p4_Decompile* decomp)
+{
+
+    if (! decomp->word) /* after first initializing a decomp-struct */
+	goto nothing_left;
+    decomp->word ++;
+    if (! -- decomp->left)
+	goto nothing_left;
+ next_loader:
+    if (! *(void**) decomp->word->loader)
+	goto nothing_left;
+    return decomp->word->loader->type;
+ nothing_left:
+    if (! p4_loader_next_wordset (decomp))
+	return '\0';
+    if (! decomp->left) 
+	goto nothing_left;
+    goto next_loader;
+}
+
+#ifndef PFE_CALL_THREADING
+#define p4_code_to_semant p4_to_semant
+#else
+p4_Seman2 const * p4_code_to_semant (p4xcode code)
+{
+    auto p4_Decompile decomp = { PFE.atexit_wl->thread[0] };
+    while (p4_loader_next (&decomp))
+    {
+	if (decomp.word->loader->type != p4_SXCO) continue;
+	if (decomp.word->value.semant->exec[0] == code)
+	    return decomp.word->value.semant;
+	if (decomp.word->value.semant->exec[1] == code)
+	    return decomp.word->value.semant;
+    }
+    return 0;
+}
+#endif
+
+
 /************************************************************************/
 /* decompiler                                                           */
 /************************************************************************/
@@ -113,10 +177,10 @@ static char* id __attribute__((unused)) =
 
 /* ----------------------------------------------------------------------- */
 
-typedef p4xt* (*func_SEE) (p4xt* , char*, p4_Semant*);
+typedef p4xcode* (*func_SEE) (p4xcode* , char*, p4_Semant*);
 
-_export p4xt*
-p4_locals_bar_SEE (p4xt* ip, char* p, p4_Semant* s)
+_export p4xcode*
+p4_locals_bar_SEE (p4xcode* ip, char* p, p4_Semant* s)
 {
     int i;
         
@@ -129,15 +193,15 @@ p4_locals_bar_SEE (p4xt* ip, char* p, p4_Semant* s)
     return (ip+=2);
 }
 
-_export p4xt* 
-p4_local_SEE (p4xt* ip, char* p, p4_Semant* s)
+_export p4xcode* 
+p4_local_SEE (p4xcode* ip, char* p, p4_Semant* s)
 {
     sprintf (p, "<%c> ", 'A' - 1 +  (int) *(p4cell *) ip);
     return ++ip;
 }
 
-_export p4xt*
-p4_literal_SEE (p4xt* ip, char* p, p4_Semant* s)
+_export p4xcode*
+p4_literal_SEE (p4xcode* ip, char* p, p4_Semant* s)
 {
     char buf[80];
     if (s) 
@@ -153,18 +217,22 @@ p4_literal_SEE (p4xt* ip, char* p, p4_Semant* s)
     return ++ip;
 }
 
-_export p4xt* /* P4_SKIPS_TO_TOKEN */
-p4_lit_to_token_SEE (p4xt* ip, char* p, p4_Semant* s)
+_export p4xcode* /* P4_SKIPS_TO_TOKEN */
+p4_lit_to_token_SEE (p4xcode* ip, char* p, p4_Semant* s)
 {
-    register p4char* nfa;
-    register p4xt xt = ip[-1];
-    if (*P4_TO_CODE(xt) == s->exec[0])
+    register p4xcode xt = ip[-1];
+    if (*xt == s->exec[0])
     {
+	register p4char* itemnfa;
         xt = *ip++;
-        nfa = p4_to_name (xt);
+#     ifndef PFE_CALL_THREADING
+        itemnfa = p4_to_name (xt);
+#     else
+        itemnfa = p4_to_name (P4_BODY_FROM(*ip)); ip++;
+#     endif
         sprintf (p, "%.*s %.*s ", 
           NFACNT(*s->name), s->name+1,
-          NFACNT(*nfa), nfa + 1);
+          NFACNT(*itemnfa), itemnfa+1);
         { /* make-recognition, from yours.c */
             if (s->decomp.space > 1) ip++;
             if (s->decomp.space > 2) ip++;
@@ -182,8 +250,8 @@ p4_lit_to_token_SEE (p4xt* ip, char* p, p4_Semant* s)
     }
 }
 
-_export p4xt* /* P4_SKIPS_STRING */
-p4_lit_string_SEE (p4xt* ip, char* p, p4_Semant* s)
+_export p4xcode* /* P4_SKIPS_STRING */
+p4_lit_string_SEE (p4xcode* ip, char* p, p4_Semant* s)
 {
     sprintf (p, "%.*s %.*s\" ",
       NFACNT(*s->name), s->name + 1,
@@ -192,8 +260,8 @@ p4_lit_string_SEE (p4xt* ip, char* p, p4_Semant* s)
     return ip;
 }
 
-_export p4xt* /* P4_SKIPS_2STRINGS */
-p4_lit_2strings_SEE (p4xt* ip, char* p, p4_Semant* s)
+_export p4xcode* /* P4_SKIPS_2STRINGS */
+p4_lit_2strings_SEE (p4xcode* ip, char* p, p4_Semant* s)
 {
     p4char *s1 = (p4char *) ip;
         
@@ -205,8 +273,8 @@ p4_lit_2strings_SEE (p4xt* ip, char* p, p4_Semant* s)
     return ip;
 }
 
-_export p4xt* /* P4_SKIPS_DCELL */
-p4_lit_dcell_SEE (p4xt* ip, char* p, p4_Semant* s)
+_export p4xcode* /* P4_SKIPS_DCELL */
+p4_lit_dcell_SEE (p4xcode* ip, char* p, p4_Semant* s)
 {
     char buf[80];
     sprintf (p, "%s. ",
@@ -216,23 +284,23 @@ p4_lit_dcell_SEE (p4xt* ip, char* p, p4_Semant* s)
     return ip;
 }
 
-static p4xt *
-p4_decompile_word (p4xt* ip, char *p, p4_Decomp *d)
+static p4xcode *
+p4_decompile_word (p4xcode* ip, char *p, p4_Decomp *d)
 {
     static const p4_Decomp default_style = {P4_SKIPS_NOTHING, 0, 0, 0, 0, 0};
     /* assert SKIPS_NOTHING == 0 */
-    register p4xt xt = *ip++;
+    register p4xcode xt = *ip++;
     register p4_Semant *s;
 
-    s = p4_to_semant (xt);
+    s = (p4_Semant*) p4_code_to_semant (xt);
     memcpy (d, ((s) ? (& s->decomp) : (& default_style)), sizeof(*d));
 
     /* some tokens are (still) compiled without a semant-definition */
-    if (*P4_TO_CODE(xt) == PFX (p4_literal_execution))
+    if (*xt == PFX (p4_literal_execution))
         return p4_literal_SEE (ip, p, s);
-    if (*P4_TO_CODE(xt) == PFX (p4_locals_bar_execution))
+    if (*xt == PFX (p4_locals_bar_execution))
         return p4_locals_bar_SEE (ip, p, s);
-    if (*P4_TO_CODE(xt) == PFX (p4_local_execution))
+    if (*xt == PFX (p4_local_execution))
         return p4_local_SEE (ip, p, s);
 
     if (d->skips == P4_SKIPS_CELL 
@@ -256,22 +324,66 @@ p4_decompile_word (p4xt* ip, char *p, p4_Decomp *d)
     if (d->skips) /* SKIPS_NOTHING would be NULL */
 	return (*d->skips)(ip, p, s);
 
-    if (s == NULL)
+    if (s != NULL)
     {
-        /* use the prim-name (or colon-name) */
-        register p4char* nfa = p4_to_name (xt);
-        sprintf (p, *_FFA(nfa) & P4xIMMEDIATE ? "POSTPONE %.*s " : "%.*s ",
-          NFACNT(*nfa), nfa + 1);
-        return ip;
-    }else{
         /* use the semant-name (or compiled-by name) */
         sprintf (p, "%.*s ", NFACNT(*s->name), s->name + 1);
         return ip;
+    }else{
+	/* the prim-name (or colon-name) */
+#      ifndef PFE_CALL_THREADING
+        register p4char* nfa = p4_to_name (xt);
+        sprintf (p, P4_NFA_xIMMEDIATE(nfa) ? "POSTPONE %.*s " : "%.*s ",
+		 NFACNT(*nfa), nfa + 1);
+        return ip;
+#      else
+	/* actually, we need to find the item. In other words, we need to
+	 * find the NFA with the given CODE execution - and if it is not a
+	 * primitive then it must also match the body code. When it is a
+	 * non-primitive, then the decompiler must also skip the next 
+	 * cell (the body-reference) in the decompiled sequence.
+	 */
+	auto p4_Decompile decomp = { PFE.atexit_wl->thread[0] };
+	while (p4_loader_next (&decomp))
+	{
+	    switch (decomp.word->loader->type)
+	    {
+	    case p4_FXCO:
+	    case p4_IXCO:
+		if (decomp.word->value.ptr != xt) continue;
+		sprintf (p, decomp.word->loader->lencode & P4xIMMEDIATE 
+			 ? "POSTPONE %s " : "%s ", decomp.word->loader->name);
+		return ip;
+	    case p4_SXCO:
+		if (decomp.word->value.semant->exec[0] != xt &&
+		    decomp.word->value.semant->exec[1] != xt) continue;
+		/* FIXME: fetch the SEE routine and decompile */
+		sprintf (p, "PoSTPoNe %s ",        decomp.word->loader->name);
+		return ip;
+	    case p4_RTCO:
+		if (decomp.word->value.runtime->exec[0] != xt) continue;
+		if (decomp.word->value.runtime->flag & P4_ONLY_CODE1)
+		    goto ouch;
+		/* we assume the next cell is the pointer to BODY: */
+		___ p4char* nfa = p4_to_name (P4_BODY_FROM(*ip)); ip++; 
+		sprintf (p, P4_NFA_xIMMEDIATE(nfa)
+			 ? "POSTPONE %.*s " : "%.*s ",
+			 NFACNT(*nfa), nfa + 1); ____;
+		return ip;
+	    ouch:
+		/* OUCH! There is no body, so the real name is lost */
+		sprintf (p, "POSTPONe %s ",        decomp.word->loader->name);
+		return ip;
+	    }
+	}
+	strcpy (p, "?""?""?"" ");
+        return ip;
+#      endif
     }
 }
 
 _export void
-p4_decompile_rest (p4xt *ip, int nl, int indent)
+p4_decompile_rest (p4xcode *ip, int nl, int indent)
 {
     p4char* buf = p4_pocket ();
     p4_Seman2 *s;
@@ -282,7 +394,7 @@ p4_decompile_rest (p4xt *ip, int nl, int indent)
     for (;;)
     {
         if (!*ip) break;
-        s = (p4_Seman2 *) p4_to_semant (*ip);
+        s = (p4_Seman2 *) p4_code_to_semant (*ip);
         ip = p4_decompile_word (ip, buf, &d);
         indent += d.ind_bef;
         if ((!nl && d.cr_bef) || p4_OUT + strlen (buf) >= (size_t) p4_COLS)
@@ -310,79 +422,12 @@ p4_decompile_rest (p4xt *ip, int nl, int indent)
     }
 }
 
-static P4_CODE_RUN(p4_variable_RT_SEE)
-{
-    strcat (p, "VARIABLE ");
-    strncat (p, nfa+1, NFACNT(*nfa));
-    return 0;
-}
-
-static P4_CODE_RUN(p4_builds_RT_SEE)
-{
-    strcat (p, "CREATE ");
-    strncat (p, nfa+1, NFACNT(*nfa));
-    return 0;
-}
-
-static P4_CODE_RUN(p4_constant_RT_SEE)
-{
-    strcat (p, p4_str_dot (*P4_TO_BODY (xt), p+200, BASE));
-    strcat (p, "CONSTANT ");
-    strncat (p, nfa+1, NFACNT(*nfa));
-    return 0;
-}
-
-static P4_CODE_RUN(p4_value_RT_SEE)
-{
-    strcat (p, p4_str_dot (*P4_TO_BODY (xt), p+200, BASE));
-    strcat (p, "VALUE ");
-    strncat (p, nfa+1, NFACNT(*nfa));
-    return 0;
-}
-
-static P4_CODE_RUN(p4_two_constant_RT_SEE)
-{
-    strcat (p, p4_str_d_dot_r (*(p4dcell*) P4_TO_BODY (xt), p+200, 0, BASE));
-    strcat (p, ". 2CONSTANT ");
-    strncat (p, nfa+1, NFACNT(*nfa));
-    return 0;
-}
-
-static P4_CODE_RUN(p4_marker_RT_SEE)
-{
-    strcat (p, "MARKER ");
-    strncat (p, nfa+1, NFACNT(*nfa));
-    return 0;
-}
-
-static P4_CODE_RUN(p4_defer_RT_SEE)
-{
-    strcat (p, "DEFER ");
-    strncat (p, nfa+1, NFACNT(*nfa));
-    return 0;
-}
-
-static P4_CODE_RUN(p4_vocabulary_RT_SEE)
-{
-    strcat (p, "VOCABULARY ");
-    strncat (p, nfa+1, NFACNT(*nfa));
-    return 0;
-}
-
-static P4_CODE_RUN(p4_offset_RT_SEE)
-{
-    strcat (p, p4_str_dot (*P4_TO_BODY (xt), p+200, BASE));
-    strcat (p, "OFFSET: ");
-    strncat (p, nfa+1, NFACNT(*nfa));
-    return 0;
-}
-
 static P4_CODE_RUN(p4_colon_RT_SEE)
 {
     strcat (p, ": ");
     strncat (p, nfa+1, NFACNT(*nfa));
     strcat (p, "\n");
-    return (p4xt*) p4_to_body (xt);
+    return (p4xcode*) p4_to_body (xt);
 }
 
 static P4_CODE_RUN(p4_does_RT_SEE)
@@ -393,67 +438,113 @@ static P4_CODE_RUN(p4_does_RT_SEE)
     return (*P4_TO_DOES_CODE(xt))-1;
 }
 
+static void print_comment (const char* prefix, const char* wordset)
+{
+    char* end = strchr (wordset, ' ');
+    p4_outs ("  ( ");
+    if (! prefix) prefix = "";
+
+    if (! end) { 
+	p4_outf ("%s%s", prefix, wordset); }
+    else { 
+	p4_outf ("%s%.*s", prefix, end - wordset, wordset); }
+    p4_outs (" Word ) ");
+}
+
 _export void
 p4_decompile (char *nfa, p4xt xt)
 {
     register p4char* buf = p4_pocket ();
-    register p4xt* rest = 0;
+    register p4xcode* rest = 0;
     *buf = '\0';
 
     FX (p4_cr);
-    if (*P4_TO_CODE(xt) == p4_variable_RT_) 
-	p4_variable_RT_SEE (buf, xt, nfa);
-    else if (*P4_TO_CODE(xt) == p4_builds_RT_) 
-	p4_builds_RT_SEE (buf, xt, nfa);
-    else if (*P4_TO_CODE(xt) == p4_constant_RT_) 
-	p4_constant_RT_SEE (buf, xt, nfa);
-    else if (*P4_TO_CODE(xt) == p4_value_RT_) 
-	p4_value_RT_SEE (buf, xt, nfa);
-    else if (*P4_TO_CODE(xt) == p4_two_constant_RT_) 
-	p4_two_constant_RT_SEE (buf, xt, nfa);
-    else if (PFE.decompile[0] && PFE.decompile[0](nfa,xt)) { /* (unused) */ }
-    else if (PFE.decompile[1] && PFE.decompile[1](nfa,xt)) { /* (unused) */ }
-    else if (PFE.decompile[2] && PFE.decompile[2](nfa,xt)) { /* floating */ }
-    else if (*P4_TO_CODE(xt) == p4_marker_RT_) 
-	p4_marker_RT_SEE (buf, xt, nfa);
-    else if (*P4_TO_CODE(xt) == p4_defer_RT_ ) 
-	p4_defer_RT_SEE (buf, xt, nfa);
-    else if (*P4_TO_CODE(xt) == p4_offset_RT_) 
-	p4_offset_RT_SEE (buf, xt, nfa);
-    else if (*P4_TO_CODE(xt) == p4_vocabulary_RT_) 
-	p4_vocabulary_RT_SEE (buf, xt, nfa);
-    else if (*P4_TO_CODE(xt) == p4_colon_RT_ || 
+    if (     *P4_TO_CODE(xt) == p4_colon_RT_ || 
 	     *P4_TO_CODE(xt) == p4_debug_colon_RT_)
-	rest = p4_colon_RT_SEE(buf,xt,nfa);
+    { rest = p4_colon_RT_SEE(buf,xt,nfa); goto decompile; }
     else if (*P4_TO_CODE(xt) == p4_does_RT_ || 
 	     *P4_TO_CODE(xt) == p4_debug_does_RT_)
-        rest = p4_does_RT_SEE(buf,xt,nfa);
+    { rest = p4_does_RT_SEE(buf,xt,nfa); goto decompile; }
 
-    if (*buf)
+    /* new variant: we walk the atexit-list looking for WORDSET 
+     * registerations. We walk each entry in the wordset looking for
+     * RTco items and comparing their values with what we have as CODE(xt).
+     * When there is a SEE decompile-routine registered, then we use it.
+     */
+    ___ auto p4_Decompile decomp = { PFE.atexit_wl->thread[0] };
+    while (p4_loader_next (&decomp))
     {
+	switch (decomp.word->loader->type)
+	{
+	case p4_RTCO:
+	    if (*P4_TO_CODE(xt) != decomp.word->value.runtime->exec[0])
+		continue;
+	    /* we have it! */
+	    if (decomp.word->value.runtime->run.see)
+	    {
+		rest = decomp.word->value.runtime->run.see (buf,xt,nfa);
+		if (rest) goto decompile;
+		p4_outs (buf); p4_outs (" ");
+	    }else
+	    {
+		p4_outf (buf, "%s %.*s ", decomp.word->loader->name,
+			 (int) NFACNT(*nfa), nfa+1);
+	    }
+	    p4_outs (P4_NFA_xIMMEDIATE (nfa) ? " IMMEDIATE " : "        ");
+	    print_comment ("From ", decomp.wordset);
+	    return;
+	case p4_FXCO:
+	case p4_IXCO:
+	case p4_XXCO:
+	    if (*P4_TO_CODE(xt) != (p4code) decomp.word->value.ptr)
+		continue;
+	    p4_dot_name (nfa);
+	    p4_outs (P4_NFA_xIMMEDIATE (nfa) ? " IMMEDIATE " : "        ");
+	    print_comment ("A Prim ", decomp.wordset);
+	    goto primitive;
+	case p4_SXCO:
+	    if (*P4_TO_CODE(xt) != (p4code) decomp.word->value.semant->comp)
+		continue;
+	    p4_dot_name (nfa);
+	    p4_outs (" ..."); 
+	    if (strchr (decomp.word->loader->name, '"'))
+		p4_outc ('"');
+	    p4_outs (P4_NFA_xIMMEDIATE (nfa) ? " IMMEDIATE " : "        ");
+	    print_comment ("A Smart ", decomp.wordset);
+	    goto primitive;
+	default:
+	    continue;
+	} /* switch */
 	p4_outs (buf); p4_outs (" ");
-	if (rest) 
-	    p4_decompile_rest (rest , 1, 4);
-	if (*_FFA(nfa) & P4xIMMEDIATE)
-	    p4_outs (" IMMEDIATE ");
-    }else{
-        p4_dot_name (nfa);
-	if (*_FFA(nfa) & P4xIMMEDIATE)
-	    p4_outs ("is IMMEDIATE ");
-	else
-	    p4_outs ("is prim CODE ");
-	if (P4xISxRUNTIME)
-	    if (*_FFA(nfa) & P4xISxRUNTIME)
-		p4_outs ("RUNTIME ");
-#     ifdef PFE_HAVE_GNU_DLADDR
-	{ 
-	    extern char* p4_dladdr (void*, int*);
-	    register char* name = p4_dladdr (*P4_TO_CODE(xt), 0); 
-	    if (name) p4_outs(name); else p4_outc('.');
-	    p4_outc(' ');
-	}
-#     endif
-    }
+	return;
+    };____; /* nothing found */
+
+/* else: */
+    p4_dot_name (nfa);
+    if (P4_NFA_xIMMEDIATE(nfa))
+	p4_outs ("is IMMEDIATE ");
+    else
+	p4_outs ("is prim CODE ");
+    if (P4xISxRUNTIME)
+	if (P4_NFA_xISxRUNTIME(nfa))
+	    p4_outs ("RUNTIME ");
+ primitive:
+#  ifdef PFE_HAVE_GNU_DLADDR
+    ___ extern char* p4_dladdr (void*, int*);
+    register char* name = p4_dladdr (*P4_TO_CODE(xt), 0); 
+    if (name) p4_outs(name); else p4_outc('.');
+    p4_outc(' ');
+    ____;
+#  endif
+    return;
+
+ decompile:
+    /* assert (*buf) */
+    p4_outs (buf); p4_outs (" ");
+    if (rest) 
+	p4_decompile_rest (rest , 1, 4);
+    if (P4_NFA_xIMMEDIATE (nfa))
+	p4_outs (" IMMEDIATE ");
 }
 
 /************************************************************************/
@@ -489,7 +580,7 @@ prompt_col (void)
 }
 
 static void
-display (p4xt *ip)
+display (p4xcode *ip)
 {
     p4_Decomp style;
     char buf[80];
@@ -505,13 +596,15 @@ display (p4xt *ip)
     }
     FX (p4_cr);
     p4_decompile_word (ip, buf, &style);
-# ifndef PFE_CALL_THREADING /* FIXME */
+# ifndef PFE_CALL_THREADING 
     p4_outf ("%*s%c %s", indent, "", p4_category (**ip), buf);
+# else
+    p4_outf ("%*s%c %s", indent, "", ' ',buf);
 # endif
 }
 
 static void
-interaction (p4xt *ip)
+interaction (p4xcode *ip)
 {
     int c;
 
@@ -597,22 +690,22 @@ interaction (p4xt *ip)
 }
 
 static void
-do_adjust_level (p4xt xt)
+do_adjust_level (p4xcode xt)
 {
-    if (*P4_TO_CODE(xt) == p4_colon_RT_ 
-      || *P4_TO_CODE(xt) == p4_debug_colon_RT_ 
-      || *P4_TO_CODE(xt) == p4_does_RT_ 
-      || *P4_TO_CODE(xt) == p4_debug_does_RT_)
+    if (*xt == p4_colon_RT_ ||
+	*xt == p4_debug_colon_RT_ ||
+	*xt == p4_does_RT_ ||
+	*xt == p4_debug_does_RT_)
         PFE.level++;
-    else if (*P4_TO_CODE(xt) == PFX (p4_semicolon_execution) 
-      || *P4_TO_CODE(xt) == PFX (p4_locals_exit_execution))
+    else if (*xt == PFX (p4_semicolon_execution) ||
+	     *xt == PFX (p4_locals_exit_execution))
         PFE.level--;
 }
 
 static void
 p4_debug_execute (p4xt xt)
 {
-    do_adjust_level (xt);
+    do_adjust_level (xt); /* FIXME: */
     p4_normal_execute (xt);
 }
 
@@ -806,7 +899,7 @@ FCode (p4_come_back)
             p4_outf ("[at] %08p ' %.*s (%+d) \n", *rp, NFACNT(*nfa), nfa+1,
               ((p4xt) *rp) - (p4_name_from(nfa)));
         }else{
-            p4_outf ("[at] %08p (???) \n", *rp);
+            p4_outf ("[at] %08p (?""?""?) \n", *rp);
         }
 
         while (rp < RP)
