@@ -1,15 +1,15 @@
 #ifndef __PFE_DEF_TYPES_H
-#define __PFE_DEF_TYPES_H "%full_filespec: def-types.h~bln_mpt1!5.26:incl:bln_12xx!1 %"
+#define __PFE_DEF_TYPES_H "%full_filespec: def-types.h~bln_mpt1!33.57:incl:bln_12xx!1 %"
 
 /** 
  * -- pfe's data structures
  *
- *  Copyright (C) Tektronix, Inc. 1998 - 2001. All rights reserved.
+ *  Copyright (C) Tektronix, Inc. 1998 - 2003. All rights reserved.
  *
  *  @see     GNU LGPL
  *  @author  Tektronix CTE              @(#) %derived_by: guidod %
- *  @version %version: bln_mpt1!5.26 %
- *    (%date_modified: Tue Oct 02 22:06:41 2001 %)
+ *  @version %version: bln_mpt1!33.57 %
+ *    (%date_modified: Tue Mar 18 18:14:46 2003 %)
  *
  *  @description
  *     p4th's forth data structures definitions, types and sys.names
@@ -17,7 +17,7 @@
  */
 /*@{*/
 
-#include <pfe/incl-ext.h>
+#include <pfe/pfe-ext.h>
 
 #include <setjmp.h>
 #include <stdio.h>
@@ -32,9 +32,6 @@
 
 /* options section */
 
-#ifndef P4_ORDER_LEN     /* maximum word lists in search order */
-#define P4_ORDER_LEN 16
-#endif
 #ifndef P4_THREADS_SHIFT /* 2^n number of threads in a word list */
 #define P4_THREADS_SHIFT 5
 #endif
@@ -57,9 +54,6 @@
 #ifndef P4_MIN_PAD	/* minimum free space in PAD */
 #define P4_MIN_PAD	0x400	
 #endif
-#ifndef P4_HISTORY_SIZE	/* size of command line history buffer */
-#define P4_HISTORY_SIZE	0x1000
-#endif
 
 #ifndef P4_MP		 /* how many machines by default */
 #define P4_MP 		1
@@ -97,7 +91,6 @@
 #ifdef _P4_SOURCE
 /* heritage compatibility, to be removed in next version */
 
-# define ORDER_LEN     	P4_ORDER_LEN
 # define LD_THREADS    	P4_THREADS_SHIFT
 # define LD_LOCALS     	P4_LOCALS_SHIFT
   
@@ -107,7 +100,6 @@
 
 # define MIN_HOLD	P4_MIN_HOLD
 # define MIN_PAD	P4_MIN_PAD
-# define HISTORY_SIZE	P4_HISTORY_SIZE
 
 # define MAX_LOCALS	P4_LOCALS
 # define THREADS	P4_THREADS
@@ -132,6 +124,8 @@ typedef p4char* pfe_lfa_t;
 typedef p4code  pfe_cfa_t;
 typedef int (*p4_decompile_func_t)(char* nfa, p4xt xt);
 
+typedef struct { p4char buffer[P4_POCKET_SIZE]; } p4_pocket_t;
+
 struct p4_Wordl			/* a word list */
 {				/* a word list identifier is a (Wordl *) */
     p4char* thread[P4_THREADS]; /* field of pointers to first NFA of chain */
@@ -139,9 +133,11 @@ struct p4_Wordl			/* a word list */
     p4_Wordl *also;		/* search also this dictionary, kinda FIG*/
     p4char* nfa;                /* corresponding vocabulary NFA */
     p4cell  flag;		/* do to_upper, a copy of sys.world_flag */
-#define WORDL_NOCASE (1<<0)
-#define WORDL_NOHASH (1<<1)
-#define WORDL_CURRENT (1<<2)
+#define WORDL_NOCASE     (1<<0) /* FIND will match any case with any case */
+#define WORDL_NOHASH     (1<<1) /* WORDLIST not hashed into multiple buckets */
+#define WORDL_CURRENT    (1<<2) /* on new WORDLIST, make it chain to CURRENT */
+#define WORDL_UPPER_CASE (1<<3) /* FIND will match uppercased entries too */
+#define WORDL_UPPER_DEFS (1<<4) /* new definitions are placed uppercase */
     p4ucell id;                 /* used to speed up order search (p4_find) */
 };
 
@@ -153,9 +149,10 @@ struct p4_File			/* describes a file */
     signed char last_op;	/* -1 write, 0 none, 1 read */
     p4word len;			/* if stream: length of input line */
     p4ucell size;		/* if block file: size of file in blocks */
-    long pos;			/* a saved position, e.g. beginning of line */
     p4ucell n;			/* block in buffer or source line */
     p4cell updated;		/* if block file: block updated? */
+    union { _p4_off_t pos;	/* a saved position, e.g. beginning of line */
+        char compat[8]; } line;
     char name[PATH_LENGTH];	/* file name */
     char buffer[P4_BLK_SIZE];	/* buffer for block or input line */
 };
@@ -165,7 +162,8 @@ struct p4_Input			/* an input source specification */
     p4cell source_id;		/* SOURCE-ID */
     p4_File *block_file;	/* which file is active? */
     p4ucell blk;		/* currently loaded block */
-    long pos;			/* stream file: beginning of line in file */
+    union { _p4_off_t pos;	/* stream file: beginning of line in file */
+        char compat[8]; } line;
     char *tib;			/* points to TIB or to EVALUATED string */
     p4ucell number_tib;		/* #TIB, length of string in TIB */
     p4ucell to_in;		/* input parsing position */
@@ -181,10 +179,11 @@ struct p4_Iframe		/* a frame to save an input specification */
 struct p4_Except
 {
     p4cell magic;
-    p4xt *ipp;
-    p4cell *spp;
-    p4cell *lpp;
-    double *fpp;
+    p4xcode** rpp;              /* P4_REGRP_T */
+    p4xcode *ipp;               /* P4_REGIP_T */
+    p4cell *spp;                /* P4_REGSP_T */
+    p4cell *lpp;                /* P4_REGLP_T */
+    double *fpp;                /* P4_REGFP_T */
     p4_Iframe *iframe;
     jmp_buf jmp;
     p4_Except *prev;
@@ -230,11 +229,11 @@ struct p4_Dictionary
 struct p4_Session
 {				
     int argc;
-    char** argv;
+    char const ** argv;
     unsigned    isnotatty:2,	/* running in canonical mode */
 	        stdio:1,	/* standard input isn't-tty: work as filter */
 	        caps_on:1,	/* exchange lower and upper case chars */
-	        lower_case_on:1,/* make lower case words find upper case */
+	        find_any_case:1,/* make case-insensitive find default */
 	        lower_case_fn:1,/* convert file names to lower case? */
 	        float_input:1,	/* disables floating point input when false */
 		license:1,	/* show license string at startup */
@@ -243,40 +242,36 @@ struct p4_Session
 		verbose:1,	/* more messages */
 		debug:1,	/* enable a few more outputs */
                 bye:1,          /* don't enter the mainloop (non-interact..) */
+                upper_case_on:1,/* make lower case words find upper case */
                 lastbit:1;      /* last bit */
     int	cols, rows;	/* size of screen */
     p4ucell	total_size;
     p4ucell	stack_size;
     p4ucell	ret_stack_size;
-    p4ucell	max_files;
-    p4ucell	pockets;
-    char const*	include_file;	/* file to include after boot */
-    char const*	incpaths;
-    char const*	incext;
-    char const*	blkpaths;
-    char const*	blkext;
-    char const*	editor;		/* preferred ASCII text file editor */
+    p4ucell	unused_max_files; /* use option_value "#files" */
+    p4ucell	unused_pockets;   /* use option_value "#pockets" */
+    /* quick access to option-ext variables... (if any) */
+    char**      unused_boot_include; /* use option_string "SCRIPT-FILE" */
+    /* we keep the following entries only to speed up runtime processing: */
+    char const** inc_paths;     /* usually points to "INC-PATH" */
+    char const** inc_ext;       /* usually points to "INC-EXT" */
+    char const** blk_paths;     /* usually points to "BLK-PATH" */
+    char const** blk_ext;       /* usually points to "BLK-EXT" */
+    char const** unused_editor; /* use option_string("$EDITOR") */
         
     /* for VMs */
     int     cpus;          /* how many cpus do we have in this tread */
 
-    char const* prefix;
-    char const* bootname;
-    char *      bootcommand;
-    char **	optv;
-    struct { 
-	unsigned include_file	: 1;
-	unsigned incpaths	: 1;
-	unsigned incext		: 1;
-	unsigned blkpaths	: 1;
-	unsigned blkext		: 1;
-	unsigned editor		: 1;
-	unsigned prefix         : 1;
-	unsigned bootcommand    : 1;
-	unsigned optv		: 1;
-    } heap;
+    char const** unused_prefix;      /* use option_string("PREFIX-DIR") */
+    char const** boot_name;          /* points to argv[0] usually... */
+    char const** unused_bootcommand; /* use option_string("BOOT-INIT") */
+    char const** optv;        
+    p4cell       unused_heap;        /* obsoleted bitfield */
 
-    p4ucell     padding[7];      /* padding cells for binary compatibility */
+    p4ucell     optc;
+    p4ucell     wordlists;
+    void*       modules;         /* p4Words* : dl-internal / dl-ext */
+    p4ucell     padding[4];      /* padding cells for binary compatibility */
     
     /* additional loadlists for p4_initialize_system */
     void * loadlist[4];   
@@ -288,12 +283,17 @@ struct p4_Session
         p4char* dp;
         p4char* dict;
         p4char* dictlimit;
-        p4char* link;
-        p4char  space[280]; /* atleast one string */
+        p4char  space[284]; /* atleast a few headers... */
     } opt; /* must be last in this structure !! */
 };
 
+/* actually, the following two defines are the same when p4TH == &p4_reg */
+/* but for debugging, the .c -> .i precompiler output is better readable */
+#ifdef PFE_WITH_STATIC_REGS
+#define PFE p4_reg
+#else  
 #define PFE (*p4TH)
+#endif
 
 #ifndef P4_MOPTRS
 #define P4_MOPTRS 128
@@ -320,9 +320,9 @@ struct p4_Thread
     p4cell* s0;
     double *fstack;		/*  floating point stack */
     double* f0;
-    p4xt** rstack;		/*  return stack */
-    p4xt**  r0;
-    char (*pockets)[P4_POCKET_SIZE];	/*  POCKET for interactive S" */
+    p4xcode** rstack;		/*  return stack */
+    p4xcode**  r0;
+    p4_pocket_t* pockets_ptr;	/*  POCKET for interactive S" */
     char *tib;			/*  TIB */
     char* tib_end;
     char* history;		/*  command line history buffer */
@@ -331,12 +331,12 @@ struct p4_Thread
     p4_File* files_top;
 
 /* VM */
-    p4xt* ip; /* the intruction pointer */
-    p4xt  wp; /* speed up the inner interpreter */
-    p4cell* sp; /* the stack pointer */
-    p4xt**  rp; /* the return stack pointer */
-    p4cell* lp; /* the pointer to local variables */
-    double* fp; /* the floating point stack pointer */
+    p4xcode*  ip; /* the intruction pointer */
+    p4xt      wp;    /* speed up the inner interpreter */
+    p4cell*   sp; /* the stack pointer */
+    p4xcode** rp; /* the return stack pointer */
+    p4cell*   lp; /* the pointer to local variables */
+    double*   fp; /* the floating point stack pointer */
 
 /* jmp_buf */
     jmp_buf loop;          /* QUIT and ABORT do a THROW which longjmp() */
@@ -352,18 +352,18 @@ struct p4_Thread
     char *last;			/* NFA of most recently CREATEd header */
 
     p4_Wordl *voc_link;		/* link to chained word lists */
-    p4_Wordl *context[P4_ORDER_LEN];	/* dictionary search order */
-    p4_Wordl *only;		/* ONLY is always searched */
+    p4_Wordl **context;	        /* dictionary search order */
+    p4_Wordl *only__;		/* ONLY is always searched OBSOLETE */
     p4_Wordl *current;		/* points to vocabulary in extension */
-    p4_Wordl *dforder[P4_ORDER_LEN];	/* default dictionary search order */
-    p4xt application;		/* word to run initially or 0 */
+    p4_Wordl **dforder;	        /* default dictionary search order */
+    p4_Wordl *dfcurrent;        /* default definition wordlist */
     char *hld;			/* auxiliary pointer for number output */
     p4cell dpl;			/* position of input decimal point */
 
     p4_Input input;		/* active input source, full specification */
     p4_Input input_err;		/* input specification when error occurred */
     p4_Iframe *saved_input;	/* links to chain of saved input specs */
-    p4_Except *cAtch;		/* links to chain of CATCHed words */
+    p4_Except *catchframe;	/* links to chain of CATCHed words */
     p4ucell span;		/* char count of last EXPECT */
     p4ucell scr;		/* latest LISTed block number */
     p4cell out;			/* current output column on screen */
@@ -392,7 +392,7 @@ struct p4_Thread
     p4cell redefined_msg;	/* no `"xxx" is redefined' msg if false */
     p4cell float_input;		/* don't try floating pt input when false */
     p4cell reset_order;		/* if true: reset search order on ABORT */
-    p4cell pocket;		/* which pocket to use next */
+    p4_pocket_t* pocket;	/* which pocket to use next */
 
     p4_File *stdIn;		/* C-library standard files */
     p4_File *stdOut;		/* mapped to Forth-files */
@@ -451,7 +451,7 @@ struct p4_Thread
     int    mapfile_fd;
 
 /* p4_query hook */
-    int (*query_hook)(int);
+/*  int (*query_hook)(int); // please use lined.h:lined->intercept */
     
 /* main-mmap -> main-sub */
     int moptrs;
@@ -460,7 +460,7 @@ struct p4_Thread
     p4_Wordl* forth_wl;
 
 /* spy_on/spy_off callback mechanism */
-    p4code spy_nest;
+    void (*spy_nest)(int);
 
 /* dstrings suppport (ifdef WITH_DSTRINGS): */
     char* dstrings;
@@ -491,8 +491,27 @@ struct p4_Thread
 	p4ucell len;
     } word;
 
+    p4xt application;		/* word to run initially or 0 */
+
+    p4char* last_here;         /* set in interpret and used in abort */
+
+    p4xt spy_enter;            /* see with-spy.c */
+    p4xt spy_leave;            /* see with-spy.c */
+
+    void* chain_link;          /* see chain-ext.c */
+    p4_Wordl* abort_wl;        /* see engine-sub/chainlist-ext REDO-WL */
+    p4_Wordl* prompt_wl;       /* see engine-sub/chainlist-ext DO-WL */
+
+    double asinh_MAX_over_4;          /* see complex-ext.c */
+    double sqrt_MAX_over_4;           /* see complex-ext.c */
+
+    p4_pocket_t* pockets_top;  /* fixme: should be moved to above... */
+
+/* stackhelp-ext.c */
+    p4_Wordl* stackhelp_wl;
+
 /* make updates safer with additional padding space, use it! */
-    p4cell padding[8];
+    p4cell padding[11];
 };
 
 # define p4_S0 PFE.s0
@@ -508,7 +527,8 @@ struct p4_Thread
 # define p4_VOC_LINK	(PFE.voc_link)
 # define p4_CONTEXT	(PFE.context)
 # define p4_DFORDER     (PFE.dforder)
-# define p4_ONLY	(PFE.only)
+# define p4_DFCURRENT   (PFE.dfcurrent)
+# define p4_ONLY	(PFE.context[PFE_set.wordlists])
 # define p4_CURRENT	(PFE.current)
 # define p4_APPLICATION	(PFE.application)
 
@@ -527,6 +547,10 @@ struct p4_Thread
 # define APPLICATION	p4_APPLICATION
 #endif
 
+# define p4_DP_CHAR     ((p4char*)(p4_DP))
+# define p4_DP_CELL     ((p4cell*)(p4_DP))
+# define p4_DP_CODE     ((p4xcode*)(p4_DP))
+
 # define p4_SOURCE_ID	(PFE.input.source_id)
 # define p4_SOURCE_FILE	((p4_File*) SOURCE_ID)
 # define p4_BLOCK_FILE	(PFE.input.block_file)
@@ -545,6 +569,8 @@ struct p4_Thread
 # define TO_IN		p4_TO_IN
 #endif
 
+# define P4_UPPER_CASE_FLAGS (WORDL_NOCASE|WORDL_UPPER_CASE|WORDL_UPPER_DEFS)
+
 # define p4_OUT			(PFE.out)
 # define p4_COLS                (PFE.cols)
 # define p4_SPAN		(PFE.span)
@@ -555,7 +581,8 @@ struct p4_Thread
 # define p4_BASE		(PFE.base)
 # define p4_PRECISION		(PFE.precision)
 # define p4_WORDL_FLAG		(PFE.wordl_flag)
-# define p4_LOWER_CASE		(PFE.wordl_flag & WORDL_NOCASE)
+# define p4_UPPER_CASE		(PFE.wordl_flag & P4_UPPER_CASE_FLAGS)
+# define p4_LOWER_CASE		(PFE.wordl_flag & WORDL_NOCASE) /*depracated*/
 # define p4_LOWER_CASE_FN	(PFE.lower_case_fn)
 # define p4_REDEFINED_MSG	(PFE.redefined_msg)
 # define p4_FLOAT_INPUT		(PFE.float_input)
@@ -574,6 +601,7 @@ struct p4_Thread
 # define BASE		p4_BASE
 # define PRECISION	p4_PRECISION
 # define WORDL_FLAG	p4_WORDL_FLAG
+# define UPPER_CASE	p4_UPPER_CASE
 # define LOWER_CASE	p4_LOWER_CASE
 # define LOWER_CASE_FN	p4_LOWER_CASE_FN
 # define REDEFINED_MSG	p4_REDEFINED_MSG
@@ -600,5 +628,9 @@ enum
 # define FMODE_BIN (FMODE_ROB - FMODE_RO)
 #endif
 
+#ifndef PFE_MINIMAL_UNUSED
+#define PFE_MINIMAL_UNUSED 256
+#endif
+
 /*@}*/
 #endif
