@@ -1,21 +1,21 @@
 #ifndef __PFE_DEF_XTRA_H
-#define __PFE_DEF_XTRA_H "%full_filespec: def-xtra.h~1.7:incl:bln_12xx!1 %"
+#define __PFE_DEF_XTRA_H "%full_filespec: def-xtra.h~bln_mpt1!33.19:incl:bln_12xx!1 %"
 
 /** 
  * -- declare extras for specific environments
  * 
- *  Copyright (C) Tektronix, Inc. 1998 - 2001. All rights reserved.
+ *  Copyright (C) Tektronix, Inc. 1998 - 2003. All rights reserved.
  *
  *  @see     GNU LGPL
  *  @author  Tektronix CTE             @(#) %derived_by: guidod %
- *  @version %version: 1.7 %
- *    (%date_modified: Mon Jun 25 13:22:34 2001 %)
+ *  @version %version: bln_mpt1!33.19 %
+ *    (%date_modified: Tue Sep 10 12:30:04 2002 %)
  *  @description
  *            
  */
 /*@{*/
 
-#include <pfe/incl-sub.h>
+#include <pfe/pfe-sub.h>
 
 #ifndef FILE
 #include <stdio.h>
@@ -23,6 +23,7 @@
 
 #ifdef _P4_SOURCE
 # if defined VxWorks || defined HOST_OS_VXWORKS || defined __target_os_vxworks
+
 # ifndef PFE_HAVE_STRDUP
   extern char *strdup (const char *s);
 # endif
@@ -33,13 +34,10 @@
   extern int close (int);
   /* extern int rmdir (const char *); */
 
-# ifndef PFE_HAVE_FCNTL
-  extern int fcntl (int, int, ...);
-# endif
-
 # include <fcntl.h>
 # include <timers.h>
 # endif /* VxWorks */
+
 #endif
 
 /*@}*/
