@@ -5,13 +5,13 @@
  *
  *  @see     GNU LGPL
  *  @author  Tektronix CTE              @(#) %derived_by: guidod %
- *  @version %version: 1.21 %
+ *  @version %version: 33.30 %
  *    (%date_modified: Tue Jul 23 18:18:51 2002 %)
  */
 /*@{*/
 #if defined(__version_control__) && defined(__GNUC__)
 static char* id __attribute__((unused)) = 
-"@(#) $Id: %full_filespec:  dict-comp.c~1.21:csrc:bln_mpt1!1 % $";
+"@(#) $Id: %full_filespec:  dict-comp.c~33.30:csrc:bln_mpt1!1 % $";
 #endif
 
 #define _P4_SOURCE 1
@@ -21,9 +21,13 @@ static char* id __attribute__((unused)) =
 #include <string.h>
 
 #include <pfe/def-comp.h>
+#include <pfe/option-ext.h>
 #include <pfe/_missing.h>
 #include <pfe/logging.h>
 
+#define ___ {
+#define ____ }
+
 /* ---------------------------------------------------------------------- *
  * initial dictionary setup                                             
  */
@@ -86,29 +90,26 @@ p4_load_slot_init (int* slot, p4ucell size)
 static void
 p4_load_into (const char* vocname)
 {
-    Wordl* voc;
     if (! vocname) return;
 
-    voc = p4_find_wordlist (vocname, strlen(vocname));
-    if (voc) 
+    ___ Wordl* voc = p4_find_wordlist (vocname, strlen(vocname));
+    if (! voc) goto search_failed;
+    ___ register int i;
+    for (i=PFE_set.wordlists; --i > 0; )
     {
-        {    
-            register int i;
-            for (i=PFE_set.wordlists; --i > 0; )
-                if (CONTEXT[i] == voc) 
-                {
-                    P4_info1 ("search also '%s' : already there", 
-                              vocname);
-                    return;
-                }
-        }
-        FX (p4_also);    /* the top-of-order (CONTEXT) isn't changed */
-        CONTEXT [1] = voc; /* instead we place it under-the-top */
-        P4_info1 ("search also '%s' : done", vocname);
-    }else{
-        P4_warn2 ("search also failed: no '%s' vocabulary (%lu)", 
+	if (CONTEXT[i] == voc) 
+	{
+	    P4_info1 ("search also '%s' : already there", vocname);
+	    return;
+	}
+    }; ____;
+    FX (p4_also);    /* the top-of-order (CONTEXT) isn't changed */
+    CONTEXT [1] = voc; /* instead we place it under-the-top */
+    P4_info1 ("search also '%s' : done", vocname);
+    return; ____;
+ search_failed:
+    P4_warn2 ("search also failed: no '%s' vocabulary (%lu)", 
                   vocname, (unsigned long) strlen(vocname));
-    }
 } 
 
 static void p4_exception_string (const char* name, p4cell id)
@@ -129,6 +130,96 @@ static void FXCode(illegal_RT)
 }
 P4RUNTIMES1_RT(illegal, P4_ONLY_CODE1);
 
+/* ................................................................... */
+/* for the new_implementation: */
+
+static inline void* p4_save_input_tib (void* stack)
+{
+    void* R = p4_save_input (stack);
+    SOURCE_ID = -1;
+    BLK = 0;
+#  if 0
+    TIB = tib;
+    NUMBER_TIB = len;
+    TO_IN = 0;
+#  endif
+    return R;
+}
+
+#define p4_uses_input_tib(P) { PFE.word.ptr = (P); PFE.word.len = -1; }
+
+
+static FCode (p4_exception_string)
+{
+    p4cell id = FX_POP;
+    /* FIXME: instead of compiling to the forth-dict we should better
+       create a way to let functions search the loaded wordset tables
+    */
+    p4_Exception* expt = (void*) DP; DP += sizeof(*expt);
+    if (id < PFE.next_exception) PFE.next_exception = id - 1;
+    expt->next = PFE.exception_link; PFE.exception_link = expt;
+    /* FIXME: this is wrong: we assume it is called from a wordset-loader */
+    expt->name = PFE.word.ptr; expt->id = id;
+}
+
+/* we choose compiler code removal here */
+#ifndef PFE_CALL_THREADING
+#define _ITC_ 1
+#else
+#define _ITC_ 0
+#endif
+
+#ifndef USE_NEW_LOADER            /* USER-CONFIG: */
+#define USE_NEW_LOADER 1          /* new FX implemenation of wordset-loader */
+#endif                            /* (--walk-on / --walk-off on commandline) */
+
+static FCode (p4_load_into)
+{
+    register char* vocname = (void*) FX_POP;
+
+    p4_word_parseword (' '); *DP=0; /* PARSE-WORD-NOHERE */
+    ___ register void* p = p4_find_wordlist (PFE.word.ptr, PFE.word.len);
+    if (p) 
+    {   
+	P4_debug1 (13, "load into old '%s'", PFE.word.ptr);
+	CURRENT = p;
+    }else{
+	Wordl* current = 0;
+	if (vocname) {
+	    current = p4_find_wordlist (vocname, strlen(vocname));
+	    if (! current) 
+		P4_warn1 ("could not find also-voc %s",  vocname);
+	}
+	if (! current) current = CURRENT;
+	P4_info2 ("load into new '%.*s'", (int) PFE.word.len, PFE.word.ptr);
+	p4_header_comma (PFE.word.ptr, PFE.word.len, current);
+	P4_info1 ("did comma '%p'", LAST);
+	FX_RUNTIME1 (p4_vocabulary);  FX_IMMEDIATE;
+	P4_info1 ("done runtime '%p'", LAST);
+	CURRENT = p4_make_wordlist (LAST);
+	P4_info1 ("load into current '%p'", CURRENT);
+    }; ____;
+    
+    if (vocname) 
+    {
+	if (! CURRENT->also)
+	    CURRENT->also = p4_find_wordlist (vocname, strlen(vocname));
+
+	/* FIXME: it does nest for INTO and ALSO ? */
+	p4_load_into (PFE.word.ptr); /* search-also */
+    }
+} 
+
+
+static FCode (p4_load_words)
+{
+    extern void /*forward*/
+	p4_load_words (const p4Words* ws, p4_Wordl* wid, int unused);
+
+    void* p = (void*) FX_POP;
+    if (p) p4_load_words (p, CURRENT, 0);
+}
+
 _export void
 p4_load_words (const p4Words* ws, p4_Wordl* wid, int unused)
 {
@@ -155,259 +246,382 @@ p4_load_words (const p4Words* ws, p4_Wordl* wid, int unused)
     p4_forget_word ("wordset:%s", (p4cell) dictname,
                     PFX (p4_forget_wordset_RT), 
                     (p4cell) (ws));
+
+    if (p4_search_option_value ("walk", 4, USE_NEW_LOADER, PFE.set)) 
+	goto new_implementation;
     
     for ( ; --k >= 0; w++)
     {
-        wid = CURRENT;
-        if (w)
-        {
-            /* the C-name is really type-byte + count-byte away */
-            char type = *w->name;
-            const char* name = w->name+2;
-            int len = strlen (w->name+2);
-            void* ptr = w->ptr;
-            Wordl* wid = CURRENT;
+	wid = CURRENT;
+        if (! w) continue;
+	/* the C-name is really type-byte + count-byte away */
+        ___  char type = *w->name;
+	const char* name = w->name+2;
+	int len = strlen (w->name+2);
+	void* ptr = w->ptr;
+	Wordl* wid = CURRENT;
 
-            /* and paste over make_word inherited from pre 0.30.28 times */
-            p4xt  cfa;
+	/* and paste over make_word inherited from pre 0.30.28 times */
+	p4xt  cfa;
+	
+	/* part 1: specials... */
 
-            /* part 1: specials... */
-
-            switch (type)
-            {
-            case p4_LOAD:
-                if (ptr)
-                    p4_load_words ((p4Words*) ptr, 0, 0); /* RECURSION !! */
-                continue;
-            case p4_INTO:
-            {
-                register void* p;
-                p = p4_find_wordlist (name, strlen (name));
-                if (p) 
-                {   
-                    P4_debug1 (13, "load into old '%s'", name);
-                    CURRENT = p;
-                }else{
-                    Wordl* current = 0;
-                    if (ptr) {
-                        current = p4_find_wordlist (ptr, strlen(ptr));
-                        if (! current) 
-                            P4_warn1 ("could not find also-voc %s", 
-				      (char*)(ptr));
-                    }
-                    if (! current) current = CURRENT;
-                    P4_info1 ("load into new '%s'", name);
-		    p4_header_comma (name, strlen(name), current);
-                    P4_info1 ("did comma '%p'", LAST);
-                    FX_RUNTIME1 (p4_vocabulary);  FX_IMMEDIATE;
-                    P4_info1 ("done runtime '%p'", LAST);
-                    CURRENT = p4_make_wordlist (LAST);
-                    P4_info1 ("load into current '%p'", CURRENT);
-                }
-
-                if (ptr) 
-                {
-                    if (! CURRENT->also)
-                        CURRENT->also = p4_find_wordlist (ptr, strlen(ptr));
-
-                    p4_load_into (name); /* search-also */
-                }
-            } continue;
-            case p4_SLOT:
-                slot = (int*) ptr;
-                p4_load_slot_open (slot);
-                continue;
-            case p4_SSIZ:
-                p4_load_slot_init (slot, (p4ucell)(ptr));
-                continue;
-            case p4_EXPT:
-                p4_exception_string(name, (p4cell)(ptr));
-                continue;
-            case p4_XXCO: /* constructors are registered in => LOADED */
-                wid = PFE.atexit_wl;
-                break;
-            case p4_DVAH:
-            {
-                register void* last = LAST;
-                register void* p = p4_find (name, strlen(name));
-                if (! p) /* need to create this chain */
-                {
-                    if (! ptr) { 
-                        P4_fail1 (
-                            "trying to append to non-existant chain %s",
-                                 name); 
-                        continue; 
-                    }
-                    p4_header_comma (name, len, wid); 
-                    FX_RUNTIME1_RT(p4_dictvar);
-                    FX_UCOMMA (ptr);
-                    FX_PCOMMA (0); 
-                    { /* FX_LINK_COMMA (PFE.chain_link); */
-                        register void* here = DP; 
-                        FX_PCOMMA(PFE.chain_link); PFE.chain_link = here;
-                    }
-                    p = LAST;
-                }
-                /* we know it is a threaded dictvar */
-                p = ((char *) p4TH + *P4_TO_BODY(p4_name_from(p)));
-                if (last)
-                {  /* chain the last word created just before this one*/
-                    register void* here = DP;
-                    FX_PCOMMA (*(void**)p); 
-                    *(void**)p = here;
-                    FX_PCOMMA (p4_name_from(last));
-                }
-            } continue;
-            } /*switch*/
-
-            /* part 2: general... CREATE a name and setup its CFA field */
-
-	    p4_header_comma (name, len, wid); FX_RUNTIME1_RT (illegal);
-            if ('A' <= type && type <= 'Z')
-                FX_IMMEDIATE;
-            cfa = P4_BODY_FROM(DP);
-#         ifndef PFE_CALL_THREADING
-            switch (type)
-            {
-            case p4_SXCO:
-#             ifndef HOST_WIN32
-                *cfa = ((p4_Semant *) ptr) ->comp;
-                if (! ((p4_Semant *)ptr) ->name)
-                    P4_VAR(char*, ((p4_Semant *)ptr) ->name) = name-1; 
-                /* discard const */
-                /* BEWARE: the arg' name must come from a wordset entry to
-                   be both static and have byte in front that could be 
-                   a maxlen
-                */
-#             else
-		/* on WIN32, the ptr is a function that returns a SemantP */
-		*cfa = ((p4_Semant*(*)())ptr) () -> comp;
-                if (! ((p4_Semant *(*)())ptr) () ->name)
-                    (char*) ((p4_Semant *(*)())ptr) () ->name = name-1; 
-#             endif
-                continue;
-            case p4_RTCO:
-#             ifndef HOST_WIN32
-                *cfa = ((p4_Runtime2 *) ptr) ->comp;
-		/* and start registering the runtimes centrally FIXME:
-		   FX_COMMA(PFE.runtime); PFE.runtime = p4_HERE;
-		   FX_COMMA(ptr);
-		   but that sys-link should be honoured in p4_forget too
-		*/
-#             else
-		/* on WIN32, the ptr is a function that returns a RuntimeP */
-		*cfa = ((p4_Runtime2*(*)())ptr) () -> comp;
-#             endif
-                continue;
-            case p4_IXCO:
-            case p4_FXCO:
-                *cfa = (p4code) ptr;
-                continue;
-            case p4_XXCO:
-                *cfa = (p4code) ptr;
-                ((p4code)ptr) ();     /* runs *now* !! no checks !! */
-                continue;
-            case p4_IVOC:
-            case p4_OVOC:
-                /* creating a VO before IN will make sure that the */
-                /* other words will go in there. Nice stuff, eh ;-) */
-                *cfa = p4_vocabulary_RT_ ;
-                /* (((WList*) ptr)->wid = p4_make_wordlist (nfa)); */
-                continue;
-            case p4_DVAH:
-            case p4_DVAR:
-                *cfa = p4_dictvar_RT_ ;
-                break;
-            case p4_DCON:
-                *cfa = p4_dictget_RT_ ;
-                break;
-            case p4_DSET:
-                *cfa = p4_dictset_RT_ ;
-                break;
-            case p4_OVAR:
-            case p4_IVAR:
-                *cfa = p4_variable_RT_ ;
-                break;
-            case p4_OVAL:
-            case p4_IVAL:
-                *cfa = p4_value_RT_ ;
-                break;
-            case p4_OCON:
-            case p4_ICON:
-                *cfa = p4_constant_RT_ ;
-                break;
-            case p4_OFFS:
-                *cfa = p4_offset_RT_ ;
-                break;
-	    case p4_iOLD:
-	    case p4_xOLD:
-		*cfa = p4_obsoleted_RT_;
-		if (p4_LogMask && p4_LogMask^P4_LOG_FATAL) goto synonym;
-            case p4_SNYM:
-            case p4_FNYM:
-                *cfa = p4_synonym_RT_ ;
-	    synonym:
-		ptr = p4_find (ptr, strlen(ptr));
-		if (ptr) ptr = p4_name_from (ptr);
-		else P4_fail3 ("could not resolve SYNONYM %.*s %s",
-			       NFACNT(*LAST), LAST+1, (char*)w->ptr);
-		break;
-            default:
-                P4_fail3 ("unknown typecode for loadlist entry: "
-                          "0x%x -> \"%.*s\"", 
-                          type, len, name);
-            }
-#         else
-            /* CALL_THREADING */
-            switch (type)
-            {
-            case p4_XXCO:
-# if 1
-                ((p4code)ptr) ();     /* runs *now* !! no checks !! */
-		/* fallthrough */
-# endif
-            case p4_IXCO:
-            case p4_FXCO:
-            case p4_IVOC:
-            case p4_OVOC:
-            case p4_DVAH:
-            case p4_DVAR:
-            case p4_DCON:
-            case p4_DSET:
-            case p4_OVAR:
-            case p4_IVAR:
-            case p4_OVAL:
-            case p4_IVAL:
-            case p4_OCON:
-            case p4_ICON:
-            case p4_OFFS:
-            case p4_SXCO:
-            case p4_RTCO:
-	    case p4_iOLD:
-	    case p4_xOLD:
-		cfa->word = (p4Word*)w; /* discard "const" here */
-                break;
-            case p4_SNYM:
-            case p4_FNYM:  { 
-		ptr = p4_find (ptr, strlen(ptr));
-		if (ptr) ptr = p4_name_from (ptr);
-		else P4_fail3 ("could not resolve SYNONYM %.*s %s",
-			       NFACNT(*LAST), LAST+1, (char*)w->ptr);
-		if (ptr) cfa->word = ((p4xt)ptr)->word;
-		continue;
+	switch (type)
+	{
+	case p4_LOAD: 
+	    if (ptr)
+		p4_load_words ((p4Words*) ptr, 0, 0); /* RECURSION !! */
+	    continue;
+	case p4_INTO:
+	{
+	    register void* p;
+	    p = p4_find_wordlist (name, strlen (name));
+	    if (p) 
+	    {   
+		P4_debug1 (13, "load into old '%s'", name);
+		CURRENT = p;
+	    }else{
+		Wordl* current = 0;
+		if (ptr) {
+		    current = p4_find_wordlist (ptr, strlen(ptr));
+		    if (! current) 
+			P4_warn1 ("could not find also-voc %s", 
+				  (char*)(ptr));
+		}
+		if (! current) current = CURRENT;
+		P4_info1 ("load into new '%s'", name);
+		p4_header_comma (name, strlen(name), current);
+		P4_info1 ("did comma '%p'", LAST);
+		FX_RUNTIME1 (p4_vocabulary);  FX_IMMEDIATE;
+		P4_info1 ("done runtime '%p'", LAST);
+		CURRENT = p4_make_wordlist (LAST);
+		P4_info1 ("load into current '%p'", CURRENT);
 	    }
-            default:
-                P4_fail3 ("unknown typecode for loadlist entry: "
-                          "0x%x -> \"%.*s\"", 
-                          type, len, name);
-            }
-#         endif /* not CALL_THREADING */
-            FX_VCOMMA (ptr);
-            continue;
-        } /* if(w) */
+	    
+	    if (ptr) 
+	    {
+		if (! CURRENT->also)
+		    CURRENT->also = p4_find_wordlist (ptr, strlen(ptr));
+		
+		p4_load_into (name); /* search-also */
+	    }
+	} continue;
+	case p4_SLOT:
+	    slot = (int*) ptr;
+	    p4_load_slot_open (slot);
+	    continue;
+	case p4_SSIZ:
+	    p4_load_slot_init (slot, (p4ucell)(ptr));
+	    continue;
+	case p4_EXPT:
+	    p4_exception_string(name, (p4cell)(ptr));
+	    continue;
+	case p4_XXCO: /* constructors are registered in => LOADED */
+	    wid = PFE.atexit_wl;
+	    break;
+	} /*switch*/
+	
+	/* part 2: general... CREATE a name and setup its CFA field */
+	
+	p4_header_comma (name, len, wid); FX_RUNTIME1_RT (illegal);
+	if ('A' <= type && type <= 'Z')
+	    FX_IMMEDIATE;
+	cfa = P4_BODY_FROM(DP);
+#      ifndef PFE_CALL_THREADING
+	switch (type)
+	{
+	case p4_SXCO:
+#          ifndef HOST_WIN32
+	    *cfa = ((p4_Semant *) ptr) ->comp;
+	    if (! ((p4_Semant *)ptr) ->name)
+		P4_VAR(char*, ((p4_Semant *)ptr) ->name) = name-1; 
+	    /* discard const */
+	    /* BEWARE: the arg' name must come from a wordset entry to
+	       be both static and have byte in front that could be 
+	       a maxlen
+	    */
+#          else
+	    /* on WIN32, the ptr is a function that returns a SemantP */
+	    *cfa = ((p4_Semant*(*)())ptr) () -> comp;
+	    if (! ((p4_Semant *(*)())ptr) () ->name)
+		(char*) ((p4_Semant *(*)())ptr) () ->name = name-1; 
+#          endif
+	    continue;
+	case p4_RTCO:
+#          ifndef HOST_WIN32
+	    *cfa = ((p4_Runtime2 *) ptr) ->comp;
+	    /* and start registering the runtimes centrally FIXME:
+	       FX_COMMA(PFE.runtime); PFE.runtime = p4_HERE;
+	       FX_COMMA(ptr);
+	       but that sys-link should be honoured in p4_forget too
+	    */
+#          else
+	    /* on WIN32, the ptr is a function that returns a RuntimeP */
+	    *cfa = ((p4_Runtime2*(*)())ptr) () -> comp;
+#          endif
+	    continue;
+	case p4_IXCO:
+	case p4_FXCO:
+	    *cfa = (p4code) ptr;
+	    continue;
+	case p4_XXCO:
+	    *cfa = (p4code) ptr;
+	    ((p4code)ptr) ();     /* runs *now* !! no checks !! */
+	    continue;
+	case p4_IVOC:
+	case p4_OVOC:
+	    /* creating a VO before IN will make sure that the */
+	    /* other words will go in there. Nice stuff, eh ;-) */
+	    *cfa = p4_vocabulary_RT_ ;
+	    /* (((WList*) ptr)->wid = p4_make_wordlist (nfa)); */
+	    continue;
+	case p4_DVAR:
+	    *cfa = p4_dictvar_RT_ ;
+	    break;
+	case p4_DCON:
+	    *cfa = p4_dictget_RT_ ;
+	    break;
+	case p4_OVAR:
+	case p4_IVAR:
+	    *cfa = p4_variable_RT_ ;
+	    break;
+	case p4_OVAL:
+	case p4_IVAL:
+	    *cfa = p4_value_RT_ ;
+                break;
+	case p4_OCON:
+	case p4_ICON:
+	    *cfa = p4_constant_RT_ ;
+	    break;
+	case p4_OFFS:
+	    *cfa = p4_offset_RT_ ;
+	    break;
+	case p4_iOLD:
+	case p4_xOLD:
+	    *cfa = p4_obsoleted_RT_;
+	    if (p4_LogMask && p4_LogMask^P4_LOG_FATAL) goto synonym;
+	case p4_SNYM:
+	case p4_FNYM:
+	    *cfa = p4_synonym_RT_ ;
+	synonym:
+	    ptr = p4_find (ptr, strlen(ptr));
+	    if (ptr) ptr = p4_name_from (ptr);
+	    else P4_fail3 ("could not resolve SYNONYM %.*s %s",
+			   NFACNT(*LAST), LAST+1, (char*)w->ptr);
+	    break;
+	default:
+	    P4_fail3 ("unknown typecode for loadlist entry: "
+		      "0x%x -> \"%.*s\"", 
+		      type, len, name);
+	}
+#      else
+	/* CALL_THREADING */
+	switch (type)
+	{
+	case p4_XXCO:
+#          if 1
+	    ((p4code)ptr) ();     /* runs *now* !! no checks !! */
+	    /* fallthrough */
+#          endif
+	case p4_IXCO:
+	case p4_FXCO:
+	case p4_IVOC:
+	case p4_OVOC:
+	case p4_DVAR:
+	case p4_DCON:
+	case p4_OVAR:
+	case p4_IVAR:
+	case p4_OVAL:
+	case p4_IVAL:
+	case p4_OCON:
+	case p4_ICON:
+	case p4_OFFS:
+	case p4_SXCO:
+	case p4_RTCO:
+	case p4_iOLD:
+	case p4_xOLD:
+	    cfa->word = (p4Word*)w; /* discard "const" here */
+	    break;
+	case p4_SNYM:
+	case p4_FNYM:   
+	    ptr = p4_find (ptr, strlen(ptr));
+	    if (ptr) ptr = p4_name_from (ptr);
+	    else P4_fail3 ("could not resolve SYNONYM %.*s %s",
+			   NFACNT(*LAST), LAST+1, (char*)w->ptr);
+	    if (ptr) cfa->word = ((p4xt)ptr)->word;
+	    continue;
+	default:
+	    P4_fail3 ("unknown typecode for loadlist entry: "
+		      "0x%x -> \"%.*s\"", 
+		      type, len, name);
+	}
+#      endif /* not CALL_THREADING */
+	FX_VCOMMA (ptr);
+	continue;
     } /* for w in ws->w */
 
     CURRENT = save_current; /* should save_current moved to the caller? */
+
+    return;
+    ____;
+    /* ............................................................. */
+ new_implementation: 
+    ___ extern FCode (p4_vocabulary); extern FCode (p4_offset_constant);
+    ___ void* saved_input = SP = p4_save_input_tib (SP);
+    
+    for ( ; --k >= 0; w++)
+    {
+        if (! w) continue;
+	/* the C-name is really type-byte + count-byte away */
+	___ char type = *w->name;
+	p4_uses_input_tib ((char*)(w->name+2));
+	
+	FX_PUSH (w->ptr);
+	//  const char* name = w->name+2;
+	// int len = strlen (w->name+2);
+	// void* ptr = w->ptr;
+
+	// if (PFE.word.ptr) p4_outs (PFE.word.ptr); p4_outs (" ");
+	
+	switch (type)
+	{
+	case p4_LOAD:
+	    FX (p4_load_words); /* RECURSION !! */
+	    continue;
+	case p4_INTO:
+	    FX (p4_load_into);
+	    continue;
+	case p4_SLOT:
+	    slot = (int*) FX_POP;    /* oops, needs a TH value */
+	    p4_load_slot_open (slot);
+	    continue;
+	case p4_SSIZ:
+	    p4_load_slot_init (slot, FX_POP);
+	    continue;
+	case p4_EXPT:
+	    FX (p4_exception_string);
+	    continue;
+	case p4_SXCO:
+#         ifndef HOST_WIN32
+	    ___ p4_Semant* semant = (p4_Semant*)(void*)(FX_POP);
+#          else  /* on WIN32, the ptr is a function that returns a SemantP */
+	    ___ p4_Semant* semant = ((p4_Semant*(*)()) (void*)(FX_POP)) ();
+#         endif
+
+	    FX_HEADER;
+	    FX_COMMA (( _ITC_ ? semant->comp : (p4code) w));
+	    if (! (semant ->name))
+		P4_VAR(char*, semant ->name) = PFE.word.ptr-1; 
+	    /* discard const */
+	    /* BEWARE: the arg' name must come from a wordset entry to
+	       be both static and have a byte in front that could be 
+	       a maxlen
+	    */
+	    break; ____;
+	case p4_RTCO:
+#          ifndef HOST_WIN32
+	    ___ p4_Runtime2* runtime  = ((p4_Runtime2 *) (FX_POP));
+	    /* and start registering the runtimes centrally FIXME:
+	       FX_COMMA(PFE.runtime); PFE.runtime = p4_HERE;
+	       FX_COMMA(ptr);
+	       but that sys-link should be honoured in p4_forget too
+	    */
+#          else
+	    /* on WIN32, the ptr is a function that returns a RuntimeP */
+	    ___ p4_Runtime2* runtime = ((p4_Runtime2*(*)()) (FX_POP)) ();
+#          endif
+
+	    FX_HEADER;
+	    FX_COMMA (( _ITC_ ? runtime->comp : (p4code) w ));
+	    break; ____;
+	case p4_IXCO:         /* these are real primitives which do */
+	case p4_FXCO:         /* not reference an info-block but just */
+	    FX_HEADER;        /* the p4code directly */
+	    FX_COMMA (( _ITC_ ? *SP : (p4cell) w )); 
+	    FX_DROP;
+	    break;
+	case p4_XXCO:
+	    FX_HEADER_(PFE.atexit_wl);
+	    FX_COMMA (( _ITC_ ? *SP : (p4cell) w )); 
+	    ((p4code)(FX_POP)) ();
+	    break;
+	case p4_STKx:
+            if (PFE.stackhelp_wl)
+            {
+                FX_HEADER_(PFE.stackhelp_wl);
+                FX_COMMA (( _ITC_ ? *SP : (p4cell) w )); 
+                FX_DROP;
+            } break;
+        case p4_STKi:
+            if (PFE.stackhelp_wl)
+            {
+                FX_HEADER_(PFE.stackhelp_wl);
+                FX_RUNTIME1(p4_two_constant);
+                FX_COMMA_ (strlen(*SP), 'V');
+                FX_COMMA_ (FX_POP,      'p');
+            } break;
+	case p4_IVOC:
+	case p4_OVOC:
+	    FX (p4_vocabulary);
+	    FX_DROP;
+	    break;
+	case p4_DVAR:
+	    FX_RUNTIME_HEADER;
+	    FX_RUNTIME1_RT (p4_dictvar);
+	    FX_COMMA (FX_POP);
+	    break;
+	case p4_DCON:
+	    FX_RUNTIME_HEADER;
+	    FX_RUNTIME1_RT (p4_dictget);
+	    FX_COMMA (FX_POP);
+	    break;
+	case p4_OVAR:
+	case p4_IVAR:
+	    FX (p4_variable);
+	    break;
+	case p4_OVAL:
+	case p4_IVAL:
+	    FX (p4_value);
+	    break;
+	case p4_OCON:
+	case p4_ICON:
+	    FX (p4_constant);
+	    break;
+	case p4_OFFS:
+	    FX (p4_offset_constant);
+	    break;
+	case p4_iOLD:
+	case p4_xOLD:
+	    FX_RUNTIME_HEADER;
+	    FX_RUNTIME1_RT (p4_obsoleted);
+	    if (p4_LogMask && p4_LogMask^P4_LOG_FATAL) goto synonyms;
+	case p4_SNYM:
+	case p4_FNYM:
+	    FX_RUNTIME_HEADER;
+	    FX_RUNTIME1_RT (p4_synonym);
+	synonyms:
+	    ___ void* use = (char*) FX_POP;
+	    use = p4_find (use, strlen(use));
+	    if (use) use = p4_name_from (use);
+	    else P4_fail3 ("could not resolve SYNONYM %.*s %s",
+			   NFACNT(*LAST), LAST+1, (char*)w->ptr);
+	    FX_COMMA (use);
+	    break; ____;
+	default:
+	    P4_fail2 ("unknown typecode for loadlist entry: "
+		      "0x%x -> \"%s\"", 
+		      type, PFE.word.ptr);
+	} /*switch*/
+	
+	/* implicit IMMEDIATE still around: */
+	if ('A' <= type && type <= 'Z')
+	    FX_IMMEDIATE;
+	____;
+    } /* for w in ws->w */
+
+    CURRENT = save_current; /* should save_current moved to the caller? */
+    SP = p4_restore_input (saved_input);
+    ____;____;
 }
 
 /* ------------------------------------------------------------------- */
@@ -431,7 +645,6 @@ static loader_t * loader (p4char c)
     static loader_t vocabulary = { "vocabulary", PFX (p4_vocabulary_RT) };
     static loader_t dictvar = { "system-variable", PFX(p4_dictvar_RT) };
     static loader_t dictget = { "system-constant", PFX(p4_dictget_RT) };
-    static loader_t dictset = { "system-set-value", PFX(p4_dictset_RT) };
     static loader_t variable = { "variable", PFX(p4_variable_RT) };
     static loader_t valuevar = { "valuevar", PFX(p4_value_RT) };
     static loader_t constant = { "constant", PFX(p4_constant_RT) };
@@ -452,7 +665,6 @@ static loader_t * loader (p4char c)
     case p4_OVOC: return & vocabulary;
     case p4_DVAR: return & dictvar;
     case p4_DCON: return & dictget;
-    case p4_DSET: return & dictset;
     case p4_OVAR: 
     case p4_IVAR: return & variable;
     case p4_OVAL: 
@@ -494,7 +706,6 @@ const p4xcode* p4_to_code(p4xt xt)
     static p4xcode vocabulary = PFX(p4_vocabulary_RT);
     static p4xcode dictvar =    PFX(p4_dictvar_RT);
     static p4xcode dictget =    PFX(p4_dictget_RT);
-    static p4xcode dictset =    PFX(p4_dictset_RT);
     static p4xcode variable =   PFX(p4_variable_RT);
     static p4xcode value =      PFX(p4_value_RT);
     static p4xcode constant =   PFX(p4_constant_RT);
@@ -504,6 +715,7 @@ const p4xcode* p4_to_code(p4xt xt)
     switch (*xt->type->def)
     {
     case 0: /* the "" string indicates a trampoline */
+    case '~': /* a destroyer */
     case p4_FXCO:
     case p4_IXCO:
     case p4_XXCO:	return & xt->word->ptr;
@@ -514,7 +726,6 @@ const p4xcode* p4_to_code(p4xt xt)
     case p4_OVOC:	return & vocabulary;
     case p4_DVAR:	return & dictvar ;
     case p4_DCON:	return & dictget ;
-    case p4_DSET:	return & dictset ;
     case p4_OVAR:
     case p4_IVAR:	return & variable ;
     case p4_OVAL:
@@ -561,8 +772,7 @@ p4xcode* p4_compile_comma(p4xcode* at, p4xt xt)
     case p4_IVOC:
     case p4_OVOC:	
     case p4_DVAR:      
-    case p4_DCON:     
-    case p4_DSET:               /* all these are not primitives */
+    case p4_DCON:               /* all these are not primitives */
     case p4_OVAR:               /* their runtimes will fetch the */
     case p4_IVAR:               /* body-ptr being compiled here */
     case p4_OVAL:
@@ -657,8 +867,7 @@ _export void p4_sbr_call (p4xt xt)
     case p4_IVOC:
     case p4_OVOC:	
     case p4_DVAR:      
-    case p4_DCON:     
-    case p4_DSET:               /* all these are not primitives */
+    case p4_DCON:               /* all these are not primitives */
     case p4_OVAR:               /* their runtimes will fetch the */
     case p4_IVAR:               /* body-ptr being compiled here */
     case p4_OVAL:
