@@ -5,13 +5,13 @@
  *
  *  @see     GNU LGPL
  *  @author  Tektronix CTE              @(#) %derived_by: guidod %
- *  @version %version: bln_mpt1!5.55 %
- *    (%date_modified: Wed Sep 11 13:17:53 2002 %)
+ *  @version %version: bln_mpt1!33.60 %
+ *    (%date_modified: Wed Mar 19 16:17:29 2003 %)
  */
 /*@{*/
 #if defined(__version_control__) && defined(__GNUC__)
 static char* id __attribute__((unused)) = 
-"@(#) $Id: %full_filespec:  dict-sub.c~bln_mpt1!5.55:csrc:bln_12xx!1 % $";
+"@(#) $Id: %full_filespec:  dict-sub.c~bln_mpt1!33.60:csrc:bln_12xx!1 % $";
 #endif
 
 #define _P4_SOURCE 1
@@ -147,7 +147,7 @@ p4_find_wordlist (const char* nm, int nmlen)
     {
         if (! wl->nfa) continue;
         nfa = wl->nfa;
-        if (NFACNT(*nfa) != nmlen) continue;
+        if (P4_NFACNT(*nfa) != nmlen) continue;
         if (!memcmp (nfa+1, nm, nmlen) || !memcmp (nfa+1, upper, nmlen))
             return wl;
     }
@@ -170,7 +170,7 @@ FCode (p4_forget_dp)
         int i;
        
 	if (0) if (wl->nfa) 
-	    fprintf(stderr,"\"%.*s\"", NFACNT(*wl->nfa), wl->nfa+1);
+	    fprintf(stderr,"\"%.*s\"", P4_NFACNT(*wl->nfa), wl->nfa+1);
 
         for (i = THREADS; --i >= 0; p++)
         {  /* unchain words in thread: */
@@ -178,7 +178,7 @@ FCode (p4_forget_dp)
             {
                 if (PFE_IS_DESTROYER(*p))
                 {
-                    P4_info2 (" destroy: \"%.*s\"", NFACNT(**p), *p+1);
+                    P4_info2 (" destroy: \"%.*s\"", P4_NFACNT(**p), *p+1);
                     p4_call (p4_name_from (*p));
                     new_dp = PFE.forget_dp; /* forget_dp is volatile */
                     /* and may have changed through recursive forget */
@@ -204,7 +204,7 @@ FCode (p4_forget_dp)
                             : (const p4char*) "\1?";
                         P4_note3 ("deleted '%.*s' "
                                   "from context search-order [%i]", 
-                                  NFACNT(*nfa), nfa+1, i);
+                                  P4_NFACNT(*nfa), nfa+1, i);
                     }
                 }
             
@@ -217,7 +217,7 @@ FCode (p4_forget_dp)
                             : (const p4char*) "\1?";
                         P4_note3 ("deleted '%.*s' "
                                   "from default search-order [%i]", 
-                                  NFACNT(*nfa), nfa+1, i);
+                                  P4_NFACNT(*nfa), nfa+1, i);
                     }
                 }
             }
@@ -309,25 +309,25 @@ p4_forget_word (const char *name, p4cell id, p4code ccode, p4cell what)
 #  if defined PFE_WITH_FFA  && ! defined PFE_CALL_THREADING
     {
 	p4_header_comma (nm, strlen(nm), PFE.atexit_wl);
-	*_FFA(LAST) |= (P4xIMMEDIATE|P4xONxDESTROY);
+	P4_NFA_FLAGS(LAST) |= (P4xIMMEDIATE|P4xONxDESTROY);
 	FX_RCOMMA (ccode); /*cfa*/
 	FX_VCOMMA (what);  /*pfa*/
     }
 #  elif ! defined PFE_CALL_THREADING
     {
 	p4_header_comma (nm, strlen(nm), PFE.atexit_wl);
-	*_FFA(LAST) |= (P4xIMMEDIATE|P4xONxDESTROY);
+	P4_NFA_FLAGS(LAST) |= (P4xIMMEDIATE|P4xONxDESTROY);
 	FX_RUNTIME1_RT (p4_destroyer);
 	FX_VCOMMA (what); /*pfa*/
 	FX_RCOMMA (ccode); /*pfa+1*/
     }
 #  else /* PFE_CALL_THREADING and up, p4_call uses INFO-block */
     {
-	p4Word* w = (p4xt) p4_DP;
+	p4Word* w = (p4Word*) p4_DP;
 	FX_RCOMMA ("~"); /* trampoline with body */
 	FX_RCOMMA (ccode);
 	p4_header_comma (nm, strlen(nm), PFE.atexit_wl);
-	*_FFA(LAST) |= (P4xIMMEDIATE|P4xONxDESTROY);
+	P4_NFA_FLAGS(LAST) |= (P4xIMMEDIATE|P4xONxDESTROY);
 	FX_PCOMMA (w);    /* cfa = word-comp-info */
 	FX_VCOMMA (what); /* pfa */
     }
@@ -341,10 +341,11 @@ p4_forget_word (const char *name, p4cell id, p4code ccode, p4cell what)
  */
 
 static char *
-search_thread (const char *nm, int l, char *t, p4cell wl_flag )
+search_thread (const char *nm, int l, char *t, const p4_Wordl* wl)
 {
     auto char upper[UPPERMAX];
-    if (l > NFACNTMAX)
+    register p4cell wl_flag = wl->flag;
+    if (l > P4_NFACNTMAX)
         return NULL;
 
 # if P4_LOG /* additional sanity check */
@@ -360,7 +361,7 @@ search_thread (const char *nm, int l, char *t, p4cell wl_flag )
     {   /* pfe 33.x will have this mode removed: */
         while (t)
         {
-            if ( !(*_FFA(t) & P4xSMUDGED) && NFACNT(*t) == l)
+            if (! P4_NFA_xSMUDGED(t) && P4_NFACNT(*t) == l)
             {
                 if (!p4_strncmpi (nm, t+1, l))  break;
             }
@@ -389,7 +390,7 @@ search_thread (const char *nm, int l, char *t, p4cell wl_flag )
            AND lower-case input shall match those definitions */
         while (t)
         {
-            if ( !(*_FFA(t) & P4xSMUDGED) && NFACNT(*t) == l)
+            if (! P4_NFA_xSMUDGED(t) && P4_NFACNT(*t) == l)
             {
                 if (!memcmp (nm, t+1, l))  break;
                 if (!memcmp (upper, t+1, l)) break;
@@ -400,7 +401,7 @@ search_thread (const char *nm, int l, char *t, p4cell wl_flag )
         /* input is case-sensitive OR vocabulary contains mixed-case defs */
         while (t)
         {
-            if ( !(*_FFA(t) & P4xSMUDGED) && NFACNT(*t) == l)
+            if (! P4_NFA_xSMUDGED(t) && P4_NFACNT(*t) == l)
             {
                 if (!memcmp (nm, t+1, l))  break;
             }
@@ -415,9 +416,16 @@ _export char *
 p4_search_wordlist (const char *nm, int l, const p4_Wordl *w)
 {
     if( w->flag & WORDL_NOHASH )
-    { return search_thread (nm, l, w->thread[0], w->flag ); }
+    { return search_thread (nm, l, w->thread[0], w ); }
     else
-    { return search_thread (nm, l, w->thread[p4_wl_hash (nm, l)], w->flag ); }
+    { return search_thread (nm, l, w->thread[p4_wl_hash (nm, l)], w ); }
+}
+
+_export char *
+p4_next_search_wordlist (char* last, const char* nm, int l, const p4_Wordl* w)
+{
+    if (! last) return last;
+    return search_thread (nm, l, *p4_name_to_link(last), w );
 }
 
 /* search all word lists in the search order for name, return NFA 
@@ -452,9 +460,9 @@ p4_find (const char *nm, int l)
 	    searched |= wordl->id;
 
             if( wordl->flag & WORDL_NOHASH )
-                w = search_thread (nm, l, wordl->thread[0], wordl->flag );
+                w = search_thread (nm, l, wordl->thread[0], wordl );
             else
-                w = search_thread (nm, l, wordl->thread[n], wordl->flag );
+                w = search_thread (nm, l, wordl->thread[n], wordl );
 
 	    if (w) return w;
         }
@@ -555,10 +563,10 @@ p4_wild_words (const p4_Wordl *wl, const char *pattern, const char *categories)
         categories = NULL;
     for (t = p4_topmost (&wcopy); *t; t = p4_topmost (&wcopy))
     {
-        char wbuf[NFACNTMAX+1];
+        char wbuf[P4_NFACNTMAX+1];
         p4char *w = *t;
         p4char **s = p4_name_to_link (w);
-        int l = NFACNT(*w++);
+        int l = P4_NFACNT(*w++);
         p4_store_c_string (w, l, wbuf, sizeof wbuf);
         if (p4_match (pattern, wbuf, wl->flag & P4_UPPER_CASE_FLAGS))
         {
@@ -604,9 +612,9 @@ search_incomplete (const char *nm, int l, Wordl *w)
         s = *t;
         *t = *p4_name_to_link (*t);
 
-        if ( !(*_FFA(t) & P4xSMUDGED) && NFACNT(*s) >= l)
+        if (! P4_NFA_xSMUDGED(t) && P4_NFACNT(*s) >= l)
         {
-            if (NFACNT(*s) <= UPPERMAX) 
+            if (P4_NFACNT(*s) <= UPPERMAX) 
             { if (!memcmp (upper, s+1, l)) return s; }
             if (! memcmp (nm, s+1, l))  return s;
         }
@@ -646,12 +654,12 @@ p4_complete_word (const char *in, int len, char *out, int display)
                 if (display && len) 
                 {
                     FX (p4_space);
-                    p4_type_on_line (t + 1, NFACNT(*t));
+                    p4_type_on_line (t + 1, P4_NFACNT(*t));
                 }
                 if (! s) 
                 {
                     s = t + 1;
-                    m = NFACNT(*t);
+                    m = P4_NFACNT(*t);
                 }else{
                     ++t;
                     for (n = 0; n < m; n++)
@@ -663,7 +671,7 @@ p4_complete_word (const char *in, int len, char *out, int display)
         }
     }
     if (cnt)
-        p4_store_c_string (s, m, out, NFACNTMAX+1);
+        p4_store_c_string (s, m, out, P4_NFACNTMAX+1);
     if (display && !len)
     { p4_outf (" %i words ", cnt); }
     return cnt;
@@ -672,10 +680,11 @@ p4_complete_word (const char *in, int len, char *out, int display)
 #else
 
 static char *
-search_thread_inco (const char *nm, int l, char *t, p4cell wl_flag )
+search_thread_startswith (const char *nm, int l, char *t, p4_Wordl* wl )
 {  /* compare with p4_search_thread */
     auto char upper[UPPERMAX];
-    if (l > NFACNTMAX)
+    p4cell wl_flag = wl->flag;
+    if (l > P4_NFACNTMAX)
         return NULL;
 
     if( UPPER_CASE && (wl_flag & WORDL_UPPER_CASE) )
@@ -686,7 +695,7 @@ search_thread_inco (const char *nm, int l, char *t, p4cell wl_flag )
            AND lower-case input shall match those definitions */
         while (t)
         {
-            if ( !(*_FFA(t) & P4xSMUDGED) && NFACNT(*t) >= l)
+            if (! P4_NFA_xSMUDGED(t) && P4_NFACNT(*t) >= l)
             {
                 if (!memcmp (nm, t+1, l))  break;
                 if (!memcmp (upper, t+1, l)) break;
@@ -697,7 +706,7 @@ search_thread_inco (const char *nm, int l, char *t, p4cell wl_flag )
         /* input is case-sensitive OR vocabulary contains mixed-case defs */
         while (t)
         {
-            if ( !(*_FFA(t) & P4xSMUDGED) && NFACNT(*t) >= l)
+            if (! P4_NFA_xSMUDGED(t) && P4_NFACNT(*t) >= l)
             {
                 if (!memcmp (nm, t+1, l))  break;
             }
@@ -741,16 +750,16 @@ find_next_incomplete (const char *nm, int l, char* old)
                 w = wordl->thread[n];
                 while (w)
                 {
-                    w = search_thread_inco (nm, l, w, wordl->flag );
+                    w = search_thread_startswith (nm, l, w, wordl );
 
                     if (w) 
                     {
-                        if (! old)               /* search all wordl-threads */
-                            return w;            /* until "old" is found     */
-                        if (old == w)            /* then return the next nfa */
-                            old = 0;             /* found after that one -   */
-                        w = *p4_name_to_link(w); /* and if old-arg was null  */
-                    }                            /* it returns the first w   */
+                        if (! old)              /* search all wordl-threads */
+                            return w;           /* until "old" is found     */
+                        if (old == w)           /* then return the next nfa */
+                            old = 0;            /* found after that one -   */
+                        w = *p4_name_to_link(w); /* and if old-arg was null */
+                    }                           /* it returns the first w   */
                 } /* while (w) */
             }
         }
@@ -778,12 +787,12 @@ p4_complete_word (const char *in, int len, char *out, int display)
         if (display && len) 
         {
             FX (p4_space);
-            p4_type_on_line (t + 1, NFACNT(*t));
+            p4_type_on_line (t + 1, P4_NFACNT(*t));
         }
         if (! s) 
         {
             s = t + 1;
-            m = NFACNT(*t);
+            m = P4_NFACNT(*t);
         }else{
             for (n = 0; n < m; n++)
                 if (s[n] != (t+1)[n])
@@ -792,7 +801,7 @@ p4_complete_word (const char *in, int len, char *out, int display)
         }
     }
     if (cnt)
-        p4_store_c_string (s, m, out, NFACNTMAX+1);
+        p4_store_c_string (s, m, out, P4_NFACNTMAX+1);
     if (display && !len)
     { p4_outf (" %i words ", cnt); }
     return cnt;
@@ -803,7 +812,7 @@ p4_complete_word (const char *in, int len, char *out, int display)
 _export int
 p4_complete_dictionary (char *in, char *out, int display)
 {
-    char *lw, buf[NFACNTMAX+1];
+    char *lw, buf[P4_NFACNTMAX+1];
     int n;
     
     lw = strrchr (in, ' ');
@@ -879,8 +888,8 @@ p4_preload_only (void)
     FX_IMMEDIATE;
     PFE.environ_wl = p4_make_wordlist (LAST);
     PFE.environ_wl->also = PFE.atexit_wl;
-    PFE.environ_wl->flag |= WORDL_NOHASH;          /* for option-ext */
-    PFE.environ_wl->thread[0] = PFE.set->opt.link; /* that goes here */
+    PFE.environ_wl->flag |= WORDL_NOHASH;          /* for option-ext that */
+    PFE.environ_wl->thread[0] = PFE.set->opt.last; /* goes here (fixme?)  */
 }
 
 /*@}*/
