@@ -5,7 +5,7 @@
  *
  *  @see     GNU LGPL
  *  @author  Tektronix CTE                %derived_by: guidod %
- *  @version %version: bln_mpt1!2.25 %
+ *  @version %version: bln_mpt1!2.29 %
  *    (%date_modified: Mon Apr 08 20:16:52 2002 %)
  *
  *  @description
@@ -15,7 +15,7 @@
 /*@{*/
 #if defined(__version_control__) && defined(__GNUC__)
 static char* id __attribute__((unused)) = 
-"@(#) $Id: %full_filespec:  dl-ext.c~bln_mpt1!2.25:csrc:bln_12xx!1 % $";
+"@(#) $Id: %full_filespec:  dl-ext.c~bln_mpt1!2.29:csrc:bln_12xx!1 % $";
 #endif
 
 #define _P4_SOURCE 1
@@ -29,6 +29,7 @@ static char* id __attribute__((unused)) =
 #include <string.h>
 #include <time.h>
 
+#include <pfe/option-ext.h>
 #include <pfe/_nonansi.h>
 #include <pfe/_missing.h>
 #include <pfe/logging.h>
@@ -51,6 +52,12 @@ static char* id __attribute__((unused)) =
 # endif
 #endif
 
+#ifndef VxWorks
+#define PFE_WARN_DLERROR (p4_search_option_value ("dlerror", 7, 0, PFE.set))
+#else
+#define PFE_WARN_DLERROR 0  /* let the compiler do some code removal */
+#endif
+
 #ifdef PFE_HAVE_USELIB
 FCode (p4_uselibrary)
 {
@@ -506,10 +513,8 @@ p4_dlslot_open (const char* nameptr, int namelen)
 	if (memchr (named, '\0', 255))
 	{
 	    dll = p4_dlopenext (named);
-#         ifdef _CHECKDLL
-	    if (! dll)
-		P4_warn1 ("%s", p4_dlerror ());
-#         endif
+	    if (! dll && PFE_WARN_DLERROR)
+	    {   P4_warn1 ("%s", p4_dlerror ()); }
 	    if (systemonly)
 		goto skipdirectpath;
 	}
@@ -519,19 +524,23 @@ p4_dlslot_open (const char* nameptr, int namelen)
  skipdirectpath:
     if (! dll) 
     { 
-#     ifdef _CHECKDLL
-        P4_warn1 ("%s", p4_dlerror ());
-#     else
-	p4_dlerror ();
-#     endif
+	if (PFE_WARN_DLERROR)
+	{   P4_warn1 ("%s", p4_dlerror ()); }
+	else /* whatever the system prints */
+	{   p4_dlerror (); }
         p4_dlslot_remove (slot);
         mutexGive ();
         return -ENOENT; 
     }
 
     p4_dlslot_table[slot].dlptr = dll;  
-    
-    p4_dlslot_table[slot].llist = p4_dlsym (dll, "p4_LTX_p4_MODULE");
+
+#  ifdef PFE_SUFFIX
+#  define PFE_MODULE_LOADLIST_SYMBOL P4STRING(P4SUFFIX(p4_LTX_,p4_MODULE))
+#  else
+#  define PFE_MODULE_LOADLIST_SYMBOL                   "p4_LTX_p4_MODULE"
+#  endif
+    p4_dlslot_table[slot].llist = p4_dlsym (dll, PFE_MODULE_LOADLIST_SYMBOL);
     if (p4_dlslot_isnt_unique_llist (slot)) 
         p4_dlslot_table[slot].llist = NULL;
     
