@@ -28,10 +28,19 @@ static char* id __attribute__((unused)) =
 #include <pfe/def-xtra.h>
 #include <pfe/def-comp.h>
 #include <pfe/double-sub.h>
+#include <string.h>
 
 #define DSP	((p4dcell *)SP)
 #define UDP	((p4udcell *)SP)
 
+static P4_CODE_RUN(p4_two_constant_RT_SEE)
+{
+    strcat (p, p4_str_d_dot_r (*(p4dcell*) P4_TO_BODY (xt), p+200, 0, BASE));
+    strcat (p, ". 2CONSTANT ");
+    strncat (p, nfa+1, NFACNT(*nfa));
+    return 0;
+}
+
 /** (2CONSTANT) ( -- x1 x2 )
  * runtime portion of => 2CONSTANT
  */
@@ -57,7 +66,7 @@ FCode (p4_two_constant)
     FX_COMMA_ (FX_POP,'V');
     FX_COMMA_ (FX_POP,'v');
 }
-P4RUNTIME1(p4_two_constant, p4_two_constant_RT);
+P4RUNTIMES1_(p4_two_constant, p4_two_constant_RT, 0,p4_two_constant_RT_SEE);
 
 /** (2LITERAL) ( -- x1 x2 )
  * runtime portion of => 2LITERAL
@@ -93,6 +102,12 @@ FCode (p4_two_literal)
 P4COMPILES (p4_two_literal, p4_two_literal_execution,
   P4_SKIPS_DCELL, P4_DEFAULT_STYLE);
 
+FCode_RT (p4_two_variable_RT) /* we need this for proper decompiling */
+{                             /* otherwise identical with p4_variable_RT */
+    FX_USE_BODY_ADDR;
+    FX_PUSH_SP = (p4cell) FX_POP_BODY_ADDR;
+}
+
 /** 2VARIABLE ( -- )
  * => CREATE a new variable definition. When executed leave
  * the =>">BODY" address on stack. In pfe, the data area
@@ -105,7 +120,7 @@ FCode (p4_two_variable)
     FX_COMMA_ (0,'V');
     FX_COMMA_ (0,'v');
 }
-P4RUNTIME1(p4_two_variable, p4_variable_RT); /* fixme? p4_two_variable_RT */
+P4RUNTIME1(p4_two_variable, p4_two_variable_RT);
 
 /** D+ ( d1.ud1 d2.ud2 -- d3.ud3 )
  * the double-cell sum operation ( => + )
