@@ -460,8 +460,8 @@ p4_compile_marg (char *name, int len)
   FX_UCOMMA (n);
   return 1;
 }
-static p4xt*
-p4_marg_SEE (p4xt* ip, char* p, p4_Semant* s)
+static p4xcode*
+p4_marg_SEE (p4xcode* ip, char* p, p4_Semant* s)
 {
     sprintf (p, "<%c> ", 'A' + frame_size - 1 - (p4cell ) *ip);
     return ++ip;
@@ -683,8 +683,8 @@ FCode_XE (p4_str_quote_execution)
   PUSH_STR ((MStr *) IP);
   FX_SKIP_MSTRING;
 }
-static p4xt* /* P4_SKIPS_MSTRING */
-p4_lit_mstring_SEE (p4xt* ip, char* p, p4_Semant* s)
+static p4xcode* /* P4_SKIPS_MSTRING */
+p4_lit_mstring_SEE (p4xcode* ip, char* p, p4_Semant* s)
 {
     sprintf (p, "%.*s %.*s\" ",
       NFACNT(*s->name), s->name + 1,
@@ -828,8 +828,8 @@ FCode_XE (p4_make_str_frame_execution)
   FX_USE_CODE_ADDR
   p4_make_str_frame ((p4ucell) *IP++);
 }
-static p4xt*
-p4_make_str_frame_SEE (p4xt* ip, char* p, p4_Semant* s)
+static p4xcode*
+p4_make_str_frame_SEE (p4xcode* ip, char* p, p4_Semant* s)
 {
     int i;
 /*    unsigned int frame_size; */
@@ -882,8 +882,8 @@ FCode (p4_cat_back_tick)
   FX_COMPILE (p4_cat_back_tick);
   p4_parse_mstring_comma ('`');
 }
-static p4xt* /* P4_SKIPS_MSTRING_BACK_TICK */
-p4_lit_mstring_back_tick_SEE (p4xt* ip, char* p, p4_Semant* s)
+static p4xcode* /* P4_SKIPS_MSTRING_BACK_TICK */
+p4_lit_mstring_back_tick_SEE (p4xcode* ip, char* p, p4_Semant* s)
 {
     sprintf (p, "%.*s %.*s` ",
       NFACNT(*s->name), s->name + 1,
