@@ -5,7 +5,7 @@
  *
  *  @see     GNU LGPL
  *  @author  Tektronix CTE            @(#) %derived_by: guidod %
- *  @version %version: bln_mpt1!5.22 %
+ *  @version %version: bln_mpt1!33.24 %
  *    (%date_modified: Mon Apr 08 20:17:44 2002 %)
  *
  *  @description
@@ -17,7 +17,7 @@
 /*@{*/
 #if defined(__version_control__) && defined(__GNUC__)
 static char* id __attribute__((unused)) = 
-"@(#) $Id: %full_filespec:  edit-ext.c~bln_mpt1!5.22:csrc:bln_12xx!1 % $";
+"@(#) $Id: %full_filespec:  edit-ext.c~bln_mpt1!33.24:csrc:bln_12xx!1 % $";
 #endif
 
 #define _P4_SOURCE 1
@@ -93,11 +93,7 @@ struct edit
 /*
  * options
  */
-    const char* editor;
-
-    struct {
-	int   editor : 1;
-    } heap;
+    char const ** editor;
 };
 
 #define setcursor(R,C)	p4_gotoxy ((C) + 16, (R))
@@ -135,26 +131,26 @@ static void edit_init (struct edit* set)
    set->replace_lined.complete = p4_complete_dictionary;
    set->replace_lined.executes = NULL;
 
-   set->editor = EDITOR;
    {   /* environment scanning */
        register const char* t;
 #  ifndef _K12_SOURCE
        if ((t = getenv ("FORTHEDITOR")) != NULL)
        {
-	   set->editor = strdup (t); set->heap.editor = 1;
+	   set->editor = p4_change_option_string ("$EDITOR",7, t, PFE.set);
        }
        else if ((t = getenv ("PFEEDITOR")) != NULL)
        {
-	   set->editor = strdup (t); set->heap.editor = 1;
+	   set->editor = p4_change_option_string ("$EDITOR",7, t, PFE.set);
        }
        else if ((t = getenv ("EDITOR")) != NULL)
        {
-	   set->editor = strdup (t); set->heap.editor = 1;
+	   set->editor = p4_change_option_string ("$EDITOR",7, t, PFE.set);
        }
+       else
 #  endif
-       if ((t=p4_search_option_string ("$editor", 7, 0, PFE.set)))
        {
-	   set->editor = t;
+           static char const * const editor = EDITOR;
+           set->editor = (char const * *) & editor;
        }
    }
 }
@@ -162,8 +158,7 @@ static void edit_init (struct edit* set)
 FCode_RT (p4_edit_forget)
 {   FX_USE_BODY_ADDR {
     register struct edit* set = (struct edit*) FX_POP_BODY_ADDR[0];
-    P4_note ("clean edit area");
-    if (set->heap.editor) { free ((char*) set->editor); set->heap.editor = 0; }
+    P4_note1 ("clean edit area %p", set);
 }}
 
 FCode (p4_edit_init)
@@ -223,7 +218,7 @@ truncate_file (void)
   for (n = BLOCK_FILE->size; n; n--)
     if (!scr_empty (n - 1))
       break;
-  p4_resize_file (BLOCK_FILE, n * BPBUF);
+  p4_resize_file (BLOCK_FILE, (_p4_off_t)n * BPBUF);
 }
 
 static void
@@ -1514,9 +1509,8 @@ FCode (p4_edit_text)
   if (*nm == '\0')
     p4_throw (P4_ON_FILE_NEX);
 
-  p4_systemf ("%s %s", ED.editor, 
-	      p4_pocket_expanded_filename (nm+1, *nm,
-					   P4_opt.incpaths, P4_opt.incext));
+  p4_systemf ("%s %s", ED.editor, p4_pocket_expanded_filename (
+                  nm+1, *nm, *P4_opt.inc_paths, *P4_opt.inc_ext));
 }
 
 /** EDIT-ERROR ( -- )
