@@ -1,8 +1,8 @@
 #ifndef _PFE_EDIT_EXT_H
-#define _PFE_EDIT_EXT_H 1002664054
-/* generated 2001-1009-2347 ../../../pfe/../mk/Make-H.pl ../../../pfe/edit-ext.c */
+#define _PFE_EDIT_EXT_H 1063198934
+/* generated 2003-0910-1502 ../../../pfe/../mk/Make-H.pl ../../../pfe/edit-ext.c */
 
-#include <pfe/incl-ext.h>
+#include <pfe/pfe-ext.h>
 
 /** 
  * -- simple FORTH-screenfile editor
@@ -11,8 +11,8 @@
  *
  *  @see     GNU LGPL
  *  @author  Tektronix CTE            @(#) %derived_by: guidod %
- *  @version %version: bln_mpt1!5.20 %
- *    (%date_modified: Tue Oct 09 20:29:19 2001 %)
+ *  @version %version: bln_mpt1!33.24 %
+ *    (%date_modified: Mon Apr 08 20:17:44 2002 %)
  *
  *  @description
  *       This is a simple fullscreen FORTH block editor.
