@@ -5,13 +5,13 @@
  *
  *  @see     GNU LGPL
  *  @author  Tektronix CTE            @(#) %derived_by: guidod %
- *  @version %version: bln_mpt1!1.48 %
- *    (%date_modified: Wed Jul 24 11:37:14 2002 %)
+ *  @version %version: bln_mpt1!33.52 %
+ *    (%date_modified: Wed Mar 19 16:24:41 2003 %)
  */
 /*@{*/
 #if defined(__version_control__) && defined(__GNUC__)
 static char* id __attribute__((unused)) = 
-"@(#) $Id: %full_filespec:  engine-sub.c~bln_mpt1!1.48:csrc:bln_12xx!1 % $";
+"@(#) $Id: %full_filespec:  engine-sub.c~bln_mpt1!33.52:csrc:bln_12xx!1 % $";
 #endif
 
 #define _P4_SOURCE 1
@@ -54,47 +54,26 @@ FCode(p4_noop)
 
 #ifndef PFE_SBR_CALL_THREADING
 
-/* jumpbuf is a jmp_buf enanced by space to preserve variables that
- * may be stored in cpu register, would be the Forth VM
- */
-typedef struct	
-{
-    jmp_buf jmp;
-# ifdef P4_REGRP
-    p4xcode **rp;
-# endif
-# ifdef P4_REGSP
-    p4cell *sp;
-# endif
-# ifdef P4_REGLP
-    p4cell *lp;
-# endif
-# ifdef P4_REGFP
-    double *fp;
-# endif
-}
-jumpbuf;
-
 /**
- * longjmp via (jumpbuf*) following inline
+ * longjmp via (Except->jmp) following inline
  * - purpose: stop the inner interpreter
  */
-FCode_XE (p4_jump)	
+FCode_XE (p4_call_stop)	
 {   FX_USE_CODE_ADDR {
-    jumpbuf *buf = (jumpbuf *) *IP;
+    p4_Except *buf = (p4_Except *) *IP;
 
 # ifdef P4_REGRP		/* save global register variables */
-    buf->rp = RP;
+    buf->rpp = RP;
 # endif
 # ifdef P4_REGSP
-    buf->sp = SP;
+    buf->spp = SP;
 # endif
 # ifdef P4_REGLP
-    buf->lp = LP;
+    buf->lpp = LP;
 # endif
 # ifndef P4_NO_FP
 # ifdef P4_REGFP
-    buf->fp = FP;
+    buf->fpp = FP;
 # endif
 # endif
     longjmp (buf->jmp, 1);
@@ -108,20 +87,20 @@ FCode_XE (p4_jump)
  * - this is the inner interpreter
  */
 _export void
-p4_run_forth (p4xt xt)
+p4_call_loop (p4xt xt)
 {
 #if defined PFE_SBR_CALL_THREADING
     p4_sbr_call (xt);
     return;
 #else
 
-    jumpbuf stop;
+    p4_Except stop;
 
 #  if ! defined PFE_CALL_THREADING
-    static p4code jump_p = PFX (p4_jump);
+    static p4code call_stop = PFX (p4_call_stop);
     p4xcode list[3];
     list[0] = xt;
-    list[1] = &jump_p;
+    list[1] = &call_stop;
     list[2] = (p4xcode) &stop;
 #  else
     /* sbr-stub, xt-code, xt-data, sbr-stub, jump-code, jump-data */
@@ -130,7 +109,7 @@ p4_run_forth (p4xt xt)
 	p4_compile_comma(
 	    list,
 	    xt),
-	PFX(p4_jump)) = (p4xcode) &stop;
+	PFX(p4_call_stop)) = (p4xcode) &stop;
 #  endif
 
     IP = list;
@@ -141,17 +120,17 @@ p4_run_forth (p4xt xt)
     if (setjmp (stop.jmp))
     {
 #     ifdef P4_REGRP		/* restore global register variables */
-        RP = stop.rp;		/* clobbered by longjmp() */
+        RP = stop.rpp;		/* clobbered by longjmp() */
 #     endif
 #     ifdef P4_REGSP
-        SP = stop.sp;
+        SP = stop.spp;
 #     endif
 #     ifdef P4_REGLP
-        LP = stop.lp;
+        LP = stop.lpp;
 #     endif
 #     ifndef P4_NO_FP
 #     ifdef P4_REGFP
-        FP = stop.fp;
+        FP = stop.fpp;
 #     endif
 #     endif
         return;
@@ -194,13 +173,13 @@ p4_call (p4xt xt)
 
     saved_ip = IP;
     printf ("%X/%X\n", IP, saved_ip);
-    p4_run_forth (xt);
+    p4_call_loop (xt);
     printf ("%X/%X\n", IP, saved_ip);
     IP = saved_ip;
     printf ("%X/%X\n\n", IP, saved_ip);
 # elif !defined PFE_SBR_CALL_THREADING
     p4xcode *saved_ip = IP;
-    p4_run_forth (xt);
+    p4_call_loop (xt);
     IP = saved_ip;
 # else
     p4_sbr_call (xt);
@@ -257,15 +236,15 @@ p4_simple_execute (p4xt xt)
 static p4ucell
 FXCode (p4_interpret_find) /* hereclean */
 {
-    register p4char *s;
+    register p4char *nfa;
     register p4xt xt;
 
     /* WORD-string is at HERE and at PFE.word.ptr / PFE.word.len */
-    s = p4_find (PFE.word.ptr, PFE.word.len);
-    if (! s) return (p4cell) s; /* quick path, even alias null returncode */
+    nfa = p4_find (PFE.word.ptr, PFE.word.len);
+    if (! nfa) return (p4cell) nfa; /* quick path, even alias null-return */
 
-    xt = p4_name_from (s);
-    if (! STATE || *_FFA(s) & P4xIMMEDIATE)
+    xt = p4_name_from (nfa);
+    if (! STATE || P4_NFA_xIMMEDIATE(nfa))
     {
 	p4_call (xt);           /* execute it now */
 	FX (p4_Q_stack);        /* check stack */
@@ -365,7 +344,7 @@ FCode (p4_interpret)
  * => INTERPRET buffer
  */
 _export void
-p4_evaluate (char *p, int n)
+p4_evaluate (const char *p, int n)
 {
 #  if !defined P4_RP_IN_VM
     Iframe saved;
@@ -375,7 +354,7 @@ p4_evaluate (char *p, int n)
 #  endif
     SOURCE_ID = -1;
     BLK = 0;
-    TIB = p;
+    TIB = p;                /* leave that warning for a while... */
     NUMBER_TIB = n;
     TO_IN = 0;
     FX (p4_interpret);
@@ -422,8 +401,8 @@ p4_included1 (const char *name, int len, int throws)
     File* f;
     char* fn;
     
-    fn = p4_pocket_expanded_filename (name, len, 
-				      P4_opt.incpaths, P4_opt.incext);
+    fn = p4_pocket_expanded_filename (
+        name, len, *P4_opt.inc_paths, *P4_opt.inc_ext);
     f = p4_open_file (fn, strlen (fn), FMODE_RO);
     if (!f)
     {  
@@ -432,7 +411,7 @@ p4_included1 (const char *name, int len, int throws)
             p4_throws (P4_ON_FILE_NEX, fn, 0); 
         }else{ 
             P4_fail2 ("- could not open '%s' (paths='%s')\n", 
-              fn, P4_opt.incpaths); 
+                      fn, *P4_opt.inc_paths); 
             return 0; 
         }
     }
@@ -467,11 +446,11 @@ p4_unnest_input (p4_Iframe *p)
     {
         switch (SOURCE_ID)
 	{
-         case -1:
-         case 0:
-             break;
-         default:
-             p4_close_file (SOURCE_FILE);
+        case -1:
+        case 0:
+            break;
+        default:
+            p4_close_file (SOURCE_FILE);
 	}
 #     if defined P4_RP_IN_VM
         RP = (p4xcode **) p4_restore_input (PFE.saved_input);
@@ -535,7 +514,7 @@ quit_system (P4_VOID)
 #  endif
     LP = NULL;			/* including all local variables */
     STATE = P4_FALSE;		/* interpreting now */
-    PFE.cAtch = NULL;		/* and no exceptions caught */
+    PFE.catchframe = NULL;	/* and no exceptions to be caught */
     p4_debug_off ();		/* turn off debugger */
 }
 
@@ -615,8 +594,7 @@ p4_interpret_loop (P4_VOID)
  * setup all system variables and initialize the dictionary
  * to reach a very clean status as if right after cold boot.
  */
-static void
-cold_system (void)
+FCode (p4_cold_system)
 {
     SP = p4_S0;
 #  ifndef P4_NO_FP
@@ -638,6 +616,7 @@ cold_system (void)
       PFE_set.lower_case_fn, PFE.set);
     FLOAT_INPUT = P4_opt.float_input;
     PFE.local = (char (*)[32]) PFE.stack;
+    PFE.pocket = PFE.pockets_ptr;
 
     memset (PFE.files_top - 3, 0, sizeof (File) * 3);
 
@@ -670,10 +649,33 @@ cold_system (void)
     {
         /* Defines the following default search order:
          * FORTH EXTENSIONS ONLY */
+        extern const p4Words P4WORDS (forth);
+        p4_load_words (&P4WORDS (forth), ONLY, 0);
+    }
+    /* last step of bootup default search-order is 
+       FORTH DEFINITIONS a.k.a.  FORTH-WORDLIST CONTEXT ! DEFINITIONS
+    */
+    CURRENT = CONTEXT[0] = PFE.forth_wl; /* points to FORTH vocabulary */
+    FX (p4_default_order);
+    
+    REDEFINED_MSG = P4_TRUE;
+}    
+
+/**
+ * setup all system variables and initialize the dictionary
+ */
+FCode (p4_boot_system)
+{
+    if (PFE.nr) { printf (" CPU%i ", PFE.nr); }
+
+    /* Action of COLD ABORT and QUIT, but don't enter the interactive QUIT */
+    RESET_ORDER = P4_TRUE;
+    /* FX (p4_cold_system); */
+    REDEFINED_MSG = P4_FALSE;
+    {
 #ifndef MODULE0
 #define MODULE0 extensions
 #endif
-        extern const p4Words P4WORDS (forth);
         extern const p4Words P4WORDS (MODULE0); 
         
 #ifdef MODULE1
@@ -686,7 +688,6 @@ cold_system (void)
         extern const p4Words P4WORDS (MODULE3);
 #endif
 
-        p4_load_words (&P4WORDS (forth), ONLY, 0);
         p4_load_words (&P4WORDS (MODULE0), ONLY, 0);
         
 #ifdef MODULE1
@@ -708,31 +709,11 @@ cold_system (void)
         if (PFE.set->loadlist[3]) 
             p4_load_words (PFE.set->loadlist[3], ONLY, 0);
     }
-    /* last step of bootup default search-order is 
-       FORTH DEFINITIONS a.k.a.  FORTH-WORDLIST CONTEXT ! DEFINITIONS
-    */
-    CURRENT = CONTEXT[0] = PFE.forth_wl; /* points to FORTH vocabulary */
-    FX (p4_default_order);
-    
-    REDEFINED_MSG = P4_TRUE;
-}    
 
-/**
- * setup all system variables and initialize the dictionary
- */
-_export void
-p4_boot_system (void)
-{
-    if (PFE.nr) { printf (" CPU%i ", PFE.nr); }
-
-    /* Action of COLD ABORT and QUIT, but don't enter the interactive QUIT */
-    RESET_ORDER = P4_TRUE;
-    cold_system ();
     abort_system ();
     quit_system ();
 
     REDEFINED_MSG = P4_FALSE;
-
     { 
 	register const char* file;
 #       ifndef PFE_BLOCK_FILE /* USER-CONFIG: --block-file=<mapped-file> */
@@ -786,10 +767,8 @@ p4_boot_system (void)
 
 /*@}*/
 
-
-
-
-
-
-
-
+/* 
+ * Local variables:
+ * c-file-style: "stroustrup"
+ * End:
+ */
