@@ -316,7 +316,7 @@ FCode (p4_needs_environment)
     p4_word_parseword (' '); *DP=0; /* PARSE-WORD-NOHERE */
     nfa = p4_environment_Q (PFE.word.ptr, PFE.word.len);
     if (nfa) return;
-    P4_note2 ("'%.*s' not found", PFE.word.len, PFE.word.ptr);
+    P4_note2 ("'%.*s' not found", (int) PFE.word.len, PFE.word.ptr);
     if (p4_OUT) FX (p4_cr); p4_outs (" .... "); /* like 'NEEDS ' */
     p4_type (PFE.word.ptr, PFE.word.len);
     p4_outs (" not available "); FX (p4_cr);
