@@ -222,30 +222,28 @@ _export int
 p4_catch (p4xt xt)
 {
     register int id;
-#  ifdef P4_RP_IN_VM
-    Except *x = P4_DEC (RP, Except);
-#  else
-    auto Except except;  register Except *x = & except;
-#  endif
+    auto p4_Except frame;
 
-    x->magic = P4_EXCEPTION_MAGIC;
+    frame.magic = P4_EXCEPTION_MAGIC;
 #  ifndef PFE_SBR_CALL_ARG_THREADING 
-    x->ipp = IP;
+    frame.ipp = IP;
 #  endif
-    x->spp = SP;
-    x->lpp = LP;
+    frame.spp = SP;
+    frame.lpp = LP;
 #  ifndef P4_NO_FP
-    x->fpp = FP;
+    frame.fpp = FP;
 #  endif
-    x->iframe = PFE.saved_input;
-    x->prev = PFE.cAtch;
-    PFE.cAtch = x;
-    id = setjmp (x->jmp);
+#  ifdef P4_RP_IN_VM
+    frame.rpp = RP;
+#  endif
+    frame.iframe = PFE.saved_input;
+    frame.prev = PFE.catchframe;  PFE.catchframe = &frame;
+    id = setjmp (frame.jmp);
     if (!id)
         p4_call (xt);
-    PFE.cAtch = x->prev;
+    PFE.catchframe = frame.prev;
 #  ifdef P4_RP_IN_VM
-    RP = (p4xcode **) &x[1]; /*fixme: need to enable that in sbr-threading??*/
+    RP = frame.rpp;
 #  endif
     return id;
 }
@@ -271,7 +269,7 @@ static int spawn_trcStack(int taskprio, int taskid)
 _export void
 p4_throws (int id, const char* addr, int len)
 {
-    Except *x = PFE.cAtch;
+    p4_Except *frame = PFE.catchframe;
     char msg[256];
 
     if (PFE.atexit_running) 
@@ -300,18 +298,21 @@ p4_throws (int id, const char* addr, int len)
         PFE.throw_cleanup = NULL;
     }
 
-    if (x && x->magic == P4_EXCEPTION_MAGIC)
+    if (frame && frame->magic == P4_EXCEPTION_MAGIC)
     {
 #    ifndef PFE_SBR_CALL_ARG_THREADING
-        IP = x->ipp;
+        IP = frame->ipp;
 #    endif
-        SP = x->spp;
-        LP = x->lpp;
+        SP = frame->spp;
+        LP = frame->lpp;
 #    ifndef P4_NO_FP
-        FP = x->fpp;
+        FP = frame->fpp;
 #     endif /*P4_NO_FP*/
-        p4_unnest_input (x->iframe);
-        longjmp (x->jmp, id);
+#  ifdef P4_RP_IN_VM
+	RP = frame->rpp;
+#  endif
+        p4_unnest_input (frame->iframe);
+        longjmp (frame->jmp, id);
     }
 
 #  ifdef P4_RP_IN_VM
