@@ -1,8 +1,8 @@
 #ifndef _PFE_EXCEPTION_SUB_H
-#define _PFE_EXCEPTION_SUB_H 1002653674
-/* generated 2001-1009-2054 ../../../pfe/../mk/Make-H.pl ../../../pfe/exception-sub.c */
+#define _PFE_EXCEPTION_SUB_H 1063198928
+/* generated 2003-0910-1502 ../../../pfe/../mk/Make-H.pl ../../../pfe/exception-sub.c */
 
-#include <pfe/incl-sub.h>
+#include <pfe/pfe-sub.h>
 
 /** 
  * --  Exception-oriented Subroutines.
@@ -11,8 +11,8 @@
  *
  *  @see     GNU LGPL
  *  @author  Tektronix CTE            @(#) %derived_by: guidod %
- *  @version %version: 1.9 %
- *    (%date_modified: Thu May 10 12:02:07 2001 %)
+ *  @version %version: bln_mpt1!1.22 %
+ *    (%date_modified: Tue Jun 04 16:34:59 2002 %)
  */
 
 #ifdef __cplusplus
