@@ -5,7 +5,7 @@
  *
  *  @see     GNU LGPL
  *  @author  Tektronix CTE              @(#) %derived_by: guidod %
- *  @version %version: bln_mpt1!5.8 %
+ *  @version %version: bln_mpt1!33.11 %
  *    (%date_modified: Tue Sep 10 13:28:57 2002 %)
  *
  *  @description
@@ -18,7 +18,7 @@
 /*@{*/
 #if defined(__version_control__) && defined(__GNUC__)
 static char* id __attribute__((unused)) = 
-"@(#) $Id: %full_filespec: file-ext.c~bln_mpt1!5.8:csrc:bln_12xx!1 % $";
+"@(#) $Id: %full_filespec: file-ext.c~bln_mpt1!33.11:csrc:bln_12xx!1 % $";
 #endif
 
 #define _P4_SOURCE 1
@@ -33,10 +33,6 @@ static char* id __attribute__((unused)) =
 #include <pfe/logging.h>
 #include <pfe/_missing.h>
 
-/* long <-> p4dcell conversion macros, won't work on 16 bit machines */
-#define UL2UDC(UL, UDC)	((UDC).hi = 0, (UDC).lo = (p4ucell)(UL))
-#define UDC2UL(HI, LO)	(LO)
-
 #ifndef _NULLFILE_ROBUST   /* USER-CONFIG */
 #ifdef  PFE_HAVE_WINBASE_H /* read/write check for NULL-file w/in pfe itself */
 #define _NULLFILE_ROBUST 1 /* win32 API will SIGBUS on NULL-file read/write */
@@ -45,6 +41,9 @@ static char* id __attribute__((unused)) =
 #endif
 #endif
 
+/* when no _NULLFILE_ROBUST is set, then let the compiler do some
+ * code removal of unreachable code - because of that if(0) part.
+ */
 #if _NULLFILE_ROBUST+0
 #define _is_nullfile(X) !(X)
 #else
@@ -74,10 +73,10 @@ FCode (p4_bin)
  */
 FCode (p4_close_file)
 {
-    File *fid = (File *) SP[0];
+    register File *fid = (File *) SP[0];
 
     if (_is_nullfile(fid)) goto nullfile;
-    SP[0] = p4_close_file (fid) ? errno : 0;
+    SP[0] = p4_close_file (fid) ? PFE_io_errno : 0;
     return;
  nullfile:
     SP[0] = EINVAL;
@@ -92,14 +91,14 @@ FCode (p4_close_file)
  */
 FCode (p4_create_file)
 {
-    char *fn = (char *) SP[2];	/* c-addr, name */
-    p4ucell u = SP[1];		/* length of name */
-    p4cell fam = SP[0];		/* file access mode */
+    register char *fn = (char *) SP[2];	/* c-addr, name */
+    register p4ucell u = SP[1];		/* length of name */
+    register p4cell fam = SP[0];	/* file access mode */
     File *fid = p4_create_file (fn, u, fam);
     
     SP += 1;
     SP[1] = (p4cell) fid;
-    SP[0] = fid ? 0 : errno;
+    SP[0] = fid ? 0 : PFE_io_errno;
 }
 
 /** DELETE-FILE ( str-adr str-len -- code )
@@ -107,9 +106,10 @@ FCode (p4_create_file)
  */
 FCode (p4_delete_file)
 {
-    char* fnz = p4_pocket_filename ((char*)SP[1], SP[0]) ; /* as asciiz */
+    register char* filename = 
+	p4_pocket_filename ((char*)SP[1], SP[0]) ; /* as asciiz */
     SP += 1;
-    SP[0] = _pfe_remove (fnz) ? errno : 0;
+    SP[0] = _pfe_remove (filename) ? PFE_io_errno : 0;
 }
 
 /** FILE-POSITION ( file -- p.pos code )
@@ -118,26 +118,29 @@ FCode (p4_delete_file)
  */
 FCode (p4_file_position)
 {
-    File *fid = (File *) SP[0];	/* file-id */
-    long pos;
-    p4udcell ud;
+    register File *fid = (File *) SP[0];	/* file-id */
+    register _p4_off_t pos;
 
-    if (_is_nullfile(fid)) goto nullfile;
-    pos = ftell (fid->f);
     SP -= 2;
+    if (_is_nullfile(fid)) goto nullfile;
+    pos = _p4_ftello (fid->f);
     if (pos != -1)
     {
-        UL2UDC (pos, ud);
+	SP[2] = (p4ucell)(pos);
+	if (sizeof (*SP) >= sizeof(pos)) /* compile-time decision !*/
+	    SP[1] = 0;
+	else                            /* assume: 1x or 2x sizeof(*SP) */
+	    SP[1] = (p4ucell)(pos >> 8*(sizeof(pos)-sizeof(*SP)));
         SP[0] = 0;		/* ior */
     }else{
-        ud.lo = ud.hi = UCELL_MAX;
-        SP[0] = errno;		/* ior */
+	SP[2] = UCELL_MAX;      /* set to -1 */
+	SP[1] = UCELL_MAX;
+        SP[0] = PFE_io_errno;	/* ior */
     }
-    *(p4udcell *) &SP[1] = ud;	/* ud */
     return;
  nullfile:
-    ud.lo = ud.hi = 0;
-    *(p4udcell *) &SP[1] = ud;
+    SP[2] = 0;
+    SP[1] = 0;
     SP[0] = EINVAL;
     P4_warn ("trying seek on NULL file");
 }
@@ -149,25 +152,28 @@ FCode (p4_file_position)
 FCode (p4_file_size)
 {
     File *fid = (File *) SP[0];	/* fileid */
-    long size;
-    p4udcell ud;
+    _p4_off_t size;
 
     if (_is_nullfile(fid)) goto nullfile;
-    size = fsize (fid->f);
+    size = p4_file_size (fid->f);
     SP -= 2;
     if (size != -1)
     {
-        UL2UDC (size, ud);
+	SP[2] = (p4ucell)(size);
+	if (sizeof (*SP) >= sizeof(size)) /* compile-time decision !*/
+	    SP[1] = 0;
+	else                            /* assume: 1x or 2x sizeof(*SP) */
+	    SP[1] = (p4ucell)(size >> 8*(sizeof(size)-sizeof(*SP)));
         SP[0] = 0;		/* ior */
     }else{
-        ud.lo = ud.hi = UCELL_MAX;
-        SP[0] = errno;		/* ior */
+	SP[2] = UCELL_MAX;      /* set to -1 */
+	SP[1] = UCELL_MAX;
+        SP[0] = PFE_io_errno;	/* ior */
     }
-    *(p4udcell *) &SP[1] = ud;	/* ud */
     return;
  nullfile:
-    ud.lo = ud.hi = 0;
-    *(p4udcell *) &SP[1] = ud;
+    SP[2] = 0;
+    SP[1] = 0;
     SP[0] = EINVAL;
     P4_warn ("trying seek on NULL file");
 }
@@ -186,8 +192,8 @@ FCode (p4_include_file)
  */
 FCode (p4_included)
 {
-    char *fn = (char *) SP[1];	/* c-addr, name */
-    p4ucell u = SP[0];		/* length of name */
+    register char *fn = (char *) SP[1];	/* c-addr, name */
+    register p4ucell u = SP[0];		/* length of name */
 
     SP += 2;
     p4_included (fn, u);
@@ -200,14 +206,14 @@ FCode (p4_included)
  */
 FCode (p4_open_file)
 {
-    char *fn = (char *) SP[2];	/* c-addr, name */
-    p4ucell u = SP[1];		/* length of name */
-    p4cell fam = SP[0];		/* file access mode */
-    File *fid = p4_open_file (fn, u, fam);
+    register char *fn = (char *) SP[2];	/* c-addr, name */
+    register p4ucell u = SP[1];		/* length of name */
+    register p4cell fam = SP[0];	/* file access mode */
+    register File *fid = p4_open_file (fn, u, fam);
 
     SP += 1;
     SP[1] = (p4cell) fid;
-    SP[0] = fid ? 0 : errno;
+    SP[0] = fid ? 0 : PFE_io_errno;
 }
 
 /** READ-FILE ( str-adr str-len file -- count code )
@@ -220,13 +226,13 @@ FCode (p4_open_file)
  */
 FCode (p4_read_file)
 {
-    char *c_addr = (char *) SP[2];
-    p4ucell u = SP[1];
-    File *fid = (File *) SP[0];
+    register char *  buf = (char *) SP[2];
+    register p4ucell len = SP[1];
+    register File *  fid = (File *) SP[0];
     SP += 1;
     if (_is_nullfile(fid)) goto nullfile;
-    SP[0] = p4_read_file (c_addr, &u, fid);
-    SP[1] = u;
+    SP[1] = len;
+    SP[0] = p4_read_file (buf, & SP[1], fid);
     return;
  nullfile:
     SP[0] = EINVAL;
@@ -244,14 +250,12 @@ FCode (p4_read_file)
  */
 FCode (p4_read_line)
 {
-    char *c_addr = (char *) SP[2];
-    p4ucell u = SP[1];
-    File *fid = (File *) SP[0];
-    p4cell ior;
+    register char *  buf = (char *) SP[2];
+    register p4ucell len = SP[1];
+    register File *  fid = (File *) SP[0];
     if (_is_nullfile(fid)) goto nullfile;
-    SP[1] = p4_read_line (c_addr, &u, fid, &ior);
-    SP[2] = u;
-    SP[0] = ior;
+    SP[2] = len;
+    SP[1] = p4_read_line (buf, & SP[2], fid, & SP[0]);
     return;
  nullfile:
     SP[0] = EINVAL;
@@ -266,11 +270,20 @@ FCode (p4_read_line)
  */
 FCode (p4_reposition_file)
 {
-    File *fid = (File *) SP[0];
-    long pos = UDC2UL (SP[1], SP[2]);
+    register File *fid = (File *) SP[0];
+    register _p4_off_t pos;
+    if (sizeof (*SP) >= sizeof(pos))  /* compile-time decision !*/
+    {
+	pos = SP[2];
+    } else
+    {
+	pos = (p4ucell) SP[1];
+	pos <<= 8*(sizeof(pos)-sizeof(*SP)); /* assume: 1x or 2x sizeof(*SP) */
+	pos |=  (p4ucell)(SP[2]);
+    }
 
-    if (_is_nullfile(fid)) goto nullfile;
     SP += 2;
+    if (_is_nullfile(fid)) goto nullfile;
     SP[0] = p4_reposition_file (fid, pos);
     return;
  nullfile:
@@ -283,13 +296,22 @@ FCode (p4_reposition_file)
  */
 FCode (p4_resize_file)
 {
-    File *fid = (File *) SP[0];
-    long size = UDC2UL (SP[1], SP[2]);
+    register File *fid = (File *) SP[0];
+    register _p4_off_t size;
+    if (sizeof (*SP) >= sizeof(size))  /* compile-time decision !*/
+    {
+	size = SP[2];
+    } else
+    {
+	size = (p4ucell) SP[1];
+	size <<= 8*(sizeof(size)-sizeof(*SP)); /* assume: 1x or 2x size(*SP) */
+	size |=  (p4ucell)(SP[2]);
+    }
 
-    if (_is_nullfile(fid)) goto nullfile;
     SP += 2;
+    if (_is_nullfile(fid)) goto nullfile;
     if (p4_resize_file (fid, size) != 0)
-        *SP = errno;
+        *SP = PFE_io_errno;
     else
         *SP = 0, fid->size = (p4ucell) (size / BPBUF);
     return;
@@ -304,13 +326,13 @@ FCode (p4_resize_file)
  */ 
 FCode (p4_write_file)
 {
-    char *c_addr = (char *) SP[2];
-    p4ucell u = SP[1];
-    File *fid = (File *) SP[0];
+    register char *  buf = (char *) SP[2];
+    register p4ucell len = SP[1];
+    register File *  fid = (File *) SP[0];
 
     SP += 2;
     if (_is_nullfile(fid)) goto nullfile;
-    SP[0] = p4_write_file (c_addr, u, fid);
+    SP[0] = p4_write_file (buf, len, fid);
     return;
  nullfile:
     SP[0] = EINVAL;
@@ -324,13 +346,13 @@ FCode (p4_write_file)
  */
 FCode (p4_write_line)
 {
-    char *c_addr = (char *) SP[2];
-    p4ucell u = SP[1];
-    File *fid = (File *) SP[0];
+    register char *  buf = (char *) SP[2];
+    register p4ucell len = SP[1];
+    register File *  fid = (File *) SP[0];
 
     SP += 2;
     if (_is_nullfile(fid)) goto nullfile;
-    if ((SP[0] = p4_write_file (c_addr, u, fid)) == 0)
+    if (! (SP[0] = p4_write_file (buf, len, fid)))
         putc ('\n', fid->f);
     return;
  nullfile:
@@ -345,12 +367,12 @@ FCode (p4_write_line)
  */
 FCode (p4_file_status)
 {
-    int mode = p4_file_access ((char *) SP[1], SP[0]);
+    register int mode = p4_file_access ((char *) SP[1], SP[0]);
 
     if (mode == -1)
     {
         SP[1] = 0;
-        SP[0] = errno;
+        SP[0] = PFE_io_errno;
     }else{
         SP[1] = mode;
         SP[0] = 0;
@@ -363,19 +385,18 @@ FCode (p4_file_status)
  */
 FCode (p4_flush_file)
 {
-    File *fid = (File *) SP[0];
+    register File *fid = (File *) SP[0];
 
     if (_is_nullfile(fid)) goto nullfile;
     if (BLOCK_FILE == fid)
     {
         FX (p4_save_buffers);
         SP[0] = 0;
-    }else{
-        if (fflush (fid->f))
-            SP[0] = errno;
-        else
-            SP[0] = 0;
     }
+    else if (fflush (fid->f))
+	SP[0] = PFE_io_errno;
+    else
+	SP[0] = 0;
     return;
  nullfile:
     SP[0] = EINVAL;
@@ -388,18 +409,18 @@ FCode (p4_flush_file)
  */
 FCode (p4_rename_file)
 {
-    char* oldnm;
-    char* newnm;
+    register char* oldnm;
+    register char* newnm;
 
     oldnm = p4_pocket_filename ((char *) SP[3], SP[2]);
     newnm = p4_pocket_filename ((char *) SP[1], SP[0]);
     SP += 3;
-    *SP = _P4_rename (oldnm, newnm) ? errno : 0;
+    *SP = _P4_rename (oldnm, newnm) ? PFE_io_errno : 0;
 }
 
 static FCode (p__max_files)
 {
-    FX_PUSH (PFE_set.max_files);
+    FX_PUSH (PFE.files_top - PFE.files); /* in items, div sizeof(p4_File) */
 }
 
 
