@@ -5,13 +5,13 @@
  *
  *  @see     GNU LGPL
  *  @author  Tektronix CTE              @(#) %derived_by: guidod %
- *  @version %version: bln_mpt1!5.9 %
+ *  @version %version: bln_mpt1!33.12 %
  *    (%date_modified: Tue Sep 10 13:29:33 2002 %)
  */
 /*@{*/
 #if defined(__version_control__) && defined(__GNUC__)
 static char* id __attribute__((unused)) = 
-"@(#) $Id: %full_filespec:  file-sub.c~bln_mpt1!5.9:csrc:bln_12xx!1 % $";
+"@(#) $Id: %full_filespec:  file-sub.c~bln_mpt1!33.12:csrc:bln_12xx!1 % $";
 #endif
 
 #define _P4_SOURCE 1
@@ -27,59 +27,12 @@ static char* id __attribute__((unused)) =
 #include <pfe/_missing.h>
 
 #ifdef VXWORKS
-/* FIXME: vxworks headers should be fixed!! */
+/* fixme: vxworks headers should be fixed!! */
 #define stat(_X_,_Y_) (stat((char*)(_X_),(_Y_)))
 #endif
 
-#if !defined PFE_HAVE_ACCESS
-int
-access (const char *fn, int how)
-{
-# if defined PFE_HAVE_STAT
-    struct stat st;		/* version using stat() */
-
-    if (stat (fn, &st) != 0)
-        return -1;
-    switch (how)
-    {
-     default:
-         return -1;
-     case F_OK:
-         return 0;
-     case R_OK:
-         return (st.st_mode & S_IREAD) ? 0 : -1;
-     case W_OK:
-         return (st.st_mode & S_IWRITE) ? 0 : -1;
-     case X_OK:
-         return (st.st_mode & S_IEXEC) ? 0 : -1;
-    }
-# else
-    FILE *f;			/* limited version using ANSI-C fopen() */
-
-    switch (how)
-    {
-     default:
-         return -1;
-     case F_OK:
-     case R_OK:
-         if ((f = fopen (fn, "r")) == NULL)
-             return -1;
-         fclose (f);
-         return 0;
-     case W_OK:
-         if ((f = fopen (fn, "r+")) == NULL)
-             return -1;
-         fclose (f);
-         return 0;
-     case X_OK:
-         return -1;
-    }
-# endif
-}
-#endif
-
-_export long
-fsize (FILE * f)		/* Result: file length, -1 on error */
+_export _p4_off_t
+p4_file_size (FILE * f)		/* Result: file length, -1 on error */
 {
 # if defined PFE_HAVE_FSTAT && defined PFE_HAVE_FILENO
 
@@ -92,16 +45,16 @@ fsize (FILE * f)		/* Result: file length, -1 on error */
 
 # else
 
-    long pos, len;		/* ANSI-C version using fseek()/ftell() */
+    _p4_off_t pos, len;		/* ANSI-C version using fseek()/ftell() */
     
     clearerr (f);
-    pos = ftell (f);
+    pos = _p4_ftello (f);
     if (pos == -1)
         return -1;
-    if (fseek (f, 0, SEEK_END) != 0)
+    if (_p4_fseeko (f, 0, SEEK_END) != 0)
         return -1;
-    len = ftell (f);
-    if (fseek (f, pos, SEEK_SET) != 0)
+    len = _p4_ftello (f);
+    if (_p4_fseeko (f, pos, SEEK_SET) != 0)
     { P4_fatal1 ("could not reset to start position %li", pos); }
     else
     { P4_leave1 ("success after call at file offset %li", pos); }
@@ -110,8 +63,8 @@ fsize (FILE * f)		/* Result: file length, -1 on error */
 # endif
 }
 
-_export long
-fn_size (const char *fn)		/* Result: file length, -1 on error */
+static _p4_off_t
+file_size (const char *fn)		/* Result: file length, -1 on error */
 {
 # if defined PFE_HAVE_STAT
     struct stat st;
@@ -121,19 +74,19 @@ fn_size (const char *fn)		/* Result: file length, -1 on error */
     return st.st_size;
 # else
     FILE *f;
-    long len;
-
+    _p4_off_t len;
+    
     f = fopen (fn, "r");
     if (f == NULL)
         return -1;
-    len = fsize (f);
+    len = p4_file_size (f);
     fclose (f);
     return len;
 # endif
 }
 
 _export long
-fn_copy (const char *src, const char *dst, long limit)
+p4_file_copy (const char *src, const char *dst, _p4_off_t limit)
 /*
  * Copies file, but at most limit characters.
  * Returns destination file length if successful, -1 otherwise.
@@ -168,11 +121,11 @@ fn_copy (const char *src, const char *dst, long limit)
  * Renames or moves file, returns 0 on success, -1 on error.
  */
 _export int
-fn_move (const char *src, const char *dst)
+p4_file_move (const char *src, const char *dst)
 {
     if (_P4_rename (src, dst) == 0)
         return 0;
-    if (fn_copy (src, dst, LONG_MAX) != -1)
+    if (p4_file_copy (src, dst, LONG_MAX) != -1)
     {
         return _pfe_remove (src);
     }else{
@@ -183,20 +136,20 @@ fn_move (const char *src, const char *dst)
 
 /** make file longer */
 static int
-fextend (FILE * f, long size)	
+_fextend (FILE * f, _p4_off_t size)	
 {
     long n;
     
-    if (fseek (f, 0, SEEK_END) != 0)
+    if (_p4_fseeko (f, 0, SEEK_END) != 0)
         return -1;
-    for (n = ftell (f); n < size; n++)
+    for (n = _p4_ftello (f); n < size; n++)
         if (putc (0, f) == EOF)
             return -1;
     return 0;
 }
 
 static int
-fn_extend (const char *fn, long size)
+file_extend (const char *fn, _p4_off_t size)
 {
     FILE *f;
     int result;
@@ -204,23 +157,23 @@ fn_extend (const char *fn, long size)
     f = fopen (fn, "ab");
     if (f == NULL)
         return -1;
-    result = fextend (f, size);
+    result = _fextend (f, size);
     fclose (f);
     return result;
 }
 
 #ifndef PFE_HAVE_TRUNCATE
-int
-truncate (const char *path, long length)
+static int
+truncate (const char *path, _p4_off_t length)
 {
     char tfn[L_tmpnam];
-    long len;
+    _p4_off_t len;
     
     tmpnam (tfn);
-    len = fn_copy (path, tfn, length);
+    len = p4_file_copy (path, tfn, length);
     if (len == length && _pfe_remove (path) == 0)
     {
-        return fn_move (tfn, path);
+        return p4_file_move (tfn, path);
     }else{
         _pfe_remove (tfn);
         return 0;
@@ -233,15 +186,15 @@ truncate (const char *path, long length)
  * Returns 0 if successful, -1 otherwise.
  */
 _export int
-fn_resize (const char *fn, long new_size)
+p4_file_resize (const char *fn, _p4_off_t new_size)
 {
-    long old_size;
+    _p4_off_t old_size;
     
-    old_size = fn_size (fn);
+    old_size = file_size (fn);
     if (old_size == -1)
         return -1;
     if (old_size <= new_size)
-        return fn_extend (fn, new_size);
+        return file_extend (fn, new_size);
     else
         return truncate (fn, new_size);
 }
