@@ -5,8 +5,8 @@
  *
  *  @see     GNU LGPL
  *  @author  Tektronix CTE             @(#) %derived_by: guidod %
- *  @version %version: bln_mpt1!5.25 %
- *    (%date_modified: Mon Mar 04 8:30:00 2003 %)
+ *  @version %version: bln_mpt1!33.31 %
+ *    (%date_modified: Tue Mar 18 15:24:16 2003 %)
  *
  *  @description
  *         The Optional Floating-Point Wordset is not usually
@@ -17,7 +17,7 @@
 /*@{*/
 #if defined(__version_control__) && defined(__GNUC__)
 static char* id __attribute__((unused)) = 
-"@(#) $Id: %full_filespec:  floating-ext.c~bln_mpt1!5.25:csrc:bln_12xx!1 % $";
+"@(#) $Id: %full_filespec:  floating-ext.c~bln_mpt1!33.31:csrc:bln_12xx!1 % $";
 #endif
 
 #define _P4_SOURCE 1
@@ -145,7 +145,7 @@ p4_to_float (char *p, p4cell n, double *r)
 {
 # if USE_STRTOD		/* most systems have good strtod */
 
-    char buf[80], *q;
+    unsigned char buf[80], *q;
   
     if (!*p) return 0; 
     /* strtod does crash on vxworks being empty non-null *gud*/
@@ -154,7 +154,7 @@ p4_to_float (char *p, p4cell n, double *r)
     if (tolower (buf[n - 1]) == 'e')
         buf[n++] = '0';
     buf[n] = '\0';
-    *r = strtod (buf, &q);
+    *r = strtod (buf, (char**) &q);
     if (q == NULL)
         return 1;
     while (isspace (*q))
@@ -616,6 +616,26 @@ FCode (p4_f_fetch)
     *--FP = *(double *) *SP++;
 }
 
+#if 0
+static p4xt* see_f_variable_RT (char* out, p4xt xt, p4char* nfa)
+{
+    /*else if (*P4_TO_CODE(xt) == PFX (p4_f_variable_RT)) */
+    sprintf (out, "%g FVARIABLE %.*s", 
+	     *(double *) p4_dfaligned ((p4cell) P4_TO_BODY (xt)),
+	     NFACNT(*nfa), nfa+1);
+    return 0; /* no colon */
+}
+#endif
+
+static p4xcode* p4_f_constant_RT_SEE (char* out, p4xt xt, p4char* nfa)
+{
+    /*  (*P4_TO_CODE(xt) == PFX (p4_f_constant_RT)) */
+    sprintf (out, "%g FCONSTANT %.*s", 
+	     *(double *) p4_dfaligned ((p4cell) P4_TO_BODY (xt)),
+	     NFACNT(*nfa), nfa+1);
+    return 0; /* no colon */
+}
+
 FCode_RT (p4_f_constant_RT)
 {
     FX_USE_BODY_ADDR;
@@ -629,7 +649,7 @@ FCode (p4_f_constant)
     FX (p4_d_f_align);
     FX_FCOMMA (*FP++);
 }
-P4RUNTIME1(p4_f_constant, p4_f_constant_RT);
+P4RUNTIMES1_(p4_f_constant, p4_f_constant_RT, 0,p4_f_constant_RT_SEE);
 
 FCode (p4_f_depth)
 {
@@ -648,8 +668,8 @@ FCode (p4_f_dup)
 }
 
 /* originally P4_SKIPS_FLOAT */
-p4xt* 
-p4_lit_float_SEE (p4xt* ip, char* p, p4_Semant* s)
+p4xcode*
+p4_lit_float_SEE (p4xcode* ip, char* p, p4_Semant* s)
 {
 # if PFE_ALIGNOF_DFLOAT > PFE_ALIGNOF_CELL
     if (!P4_DFALIGNED (ip))
@@ -1001,6 +1021,7 @@ static FCode(abort_float)
     FP = p4_F0;
 }
 
+# if 0
 static int decompile_floating (char* nfa, p4xt xt)
 {
     if (*P4_TO_CODE(xt) == PFX (p4_f_constant_RT))          
@@ -1019,6 +1040,7 @@ static int decompile_floating (char* nfa, p4xt xt)
     } 
     return 0;
 }
+# endif
 
 #ifndef FLOATING_INTERPRET_SLOT       /* USER-CONFIG: */
 #define FLOATING_INTERPRET_SLOT 2     /* 1 == smart-ext / 2 == floating-ext */
@@ -1028,7 +1050,7 @@ static FCode_RT(floating_deinit)
 {
     FX_USE_BODY_ADDR; 
     FX_POP_BODY_ADDR_UNUSED;
-    PFE.decompile[FLOATING_INTERPRET_SLOT] = 0;
+/*  PFE.decompile[FLOATING_INTERPRET_SLOT] = 0; */
     PFE.interpret[FLOATING_INTERPRET_SLOT] = 0;
     PFE.abort[FLOATING_INTERPRET_SLOT] = 0;
 }
@@ -1064,7 +1086,7 @@ static FCode(floating_init)
 
     PFE.interpret[FLOATING_INTERPRET_SLOT] = PFX (interpret_float);
     PFE.abort[FLOATING_INTERPRET_SLOT] = PFX(abort_float);
-    PFE.decompile[FLOATING_INTERPRET_SLOT] = decompile_floating;
+/*  PFE.decompile[FLOATING_INTERPRET_SLOT] = decompile_floating; */
     p4_forget_word ("deinit:floating:%i", FLOATING_INTERPRET_SLOT, 
 		    PFX(floating_deinit), FLOATING_INTERPRET_SLOT);
 }
