@@ -5,8 +5,8 @@
  *
  *  @see     GNU LGPL
  *  @author  Tektronix CTE              @(#) %derived_by: guidod %
- *  @version %version: bln_mpt1!5.24 %
- *    (%date_modified: Mon Apr 08 20:22:35 2002 %)
+ *  @version %version: bln_mpt1!33.25 %
+ *    (%date_modified: Wed Mar 19 17:31:24 2003 %)
  *
  *  @description
  *     All FORTH-83-Standard words are included here that are not 
@@ -16,7 +16,7 @@
 /*@{*/
 #if defined(__version_control__) && defined(__GNUC__)
 static char* id __attribute__((unused)) = 
-"@(#) $Id: %full_filespec:  forth-83-ext.c~bln_mpt1!5.24:csrc:bln_12xx!1 % $";
+"@(#) $Id: %full_filespec:  forth-83-ext.c~bln_mpt1!33.25:csrc:bln_12xx!1 % $";
 #endif
 
 #define _P4_SOURCE 1
@@ -191,6 +191,11 @@ FCode (p4_power)
 
 /** >< ( a -- a' )
  * byte-swap a word
+ *
+ * depracated: use =>"NTOHS" which does the same as this word when
+ * the local byte-order seems to have no match, and be otherwise
+ * a no-op. Note that only the two lower bytes of the top-of-cell
+ * are swapped.
  */
 FCode (p4_byte_swap)
 {
@@ -206,7 +211,14 @@ FCode (p4_byte_swap)
 }
 
 /** >MOVE< ( from-addr to-addr count -- )
- * see => MOVE , does byte-swap for each word underway
+ * see => MOVE , does byte-swap for each word underway. 
+ *
+ * depracated: this word has not been very useful lately. It does
+ * still stem from times of 16bit forth systems that wanted to
+ * interchange data blocks. It is better to use functionality
+ * based on => NTOHS or => NTOHL. Note that this word =>">MOVE<"
+ * does swap each 2byte. It is not useful for byte-swapping
+ * => WCHAR strings as the count is given in bytes, not wchar items.
  */
 FCode (p4_byte_swap_move)
 {
@@ -255,15 +267,11 @@ FCode (p4_seal)
 /** NOT ( x - ~x )
  * a => SYNONYM for => INVERT - the word => NOT is not portable as in some
  * systems it is a => SYNONYM for => 0= ... therefore try to avoid it.
- * (may change later to be a real => SYNONYM of either => INVERT or =>"0=")
- : NOT INVERT LOG.WARN" forth' NOT is not portable, use INVERT or 0=" ;
+ * (we declare it as an OBSOLETED-SYNONYM now to create a warning message
+ *  since code using NOT is inherently not portable. The forth systems
+ *  seem to be divided about 50%-50% for F83'style =>"INVERT" or a logical
+ *  NOT as =>"0=",  with a slight drift into the direction of =>"0=".)
  */
-FCode (p4_not)
-{
-    FX_COMPILE(p4_not);
-    P4_warn ("forth' NOT is not portable, use INVERT or 0= ");
-}
-P4COMPILES(p4_not, p4_invert, P4_SKIPS_NOTHING, P4_DEFAULT_STYLE);
 
 P4_LISTWORDS (forth_83) =
 {
@@ -274,8 +282,8 @@ P4_LISTWORDS (forth_83) =
     P4_FXco ("2-",		p4_two_minus),
     P4_FXco ("?TERMINAL",	p4_key_question),
     P4_SXco ("COMPILE",		p4_compile),
-    P4_SXco ("NOT",		p4_not), 
-    P4_FXco ("VOCABULARY",	p4_vocabulary),
+    P4_xOLD ("NOT",		"INVERT"),
+    P4_RTco ("VOCABULARY",	p4_vocabulary),
 
     /* FORTH-83 controlled reference words */
     P4_IXco ("-->",		p4_next_block),
@@ -287,8 +295,10 @@ P4_LISTWORDS (forth_83) =
     /* FORTH-83 uncontrolled reference words */
     P4_FXco ("!BITS",		p4_store_bits),
     P4_FXco ("@BITS",		p4_fetch_bits),
-    P4_FXco ("><",		p4_byte_swap),
-    P4_FXco (">MOVE<",		p4_byte_swap_move),
+    P4_FXco ("_like:NTOHS",	p4_byte_swap),
+    P4_xOLD ("><",		"_like:NTOHS"),
+    P4_FXco ("_like:NTOHS-MOVE", p4_byte_swap_move),
+    P4_xOLD (">MOVE<",		"_like:NTOHS-MOVE"),
     P4_FXco ("**",		p4_power),
     P4_DVaR ("DPL",		dpl),
 
