@@ -5,8 +5,8 @@
  *
  *  @see     GNU LGPL
  *  @author  Krishna Myneni        @(#) %derived_by: guidod %
- *  @version %version: 32.12 %
- *    (%date_modified: Wed Oct 16 14:54:57 2002 %)
+ *  @version %version: 33.18 %
+ *    (%date_modified: Tue Mar 18 15:42:53 2003 %)
  *
  *  @description
  *         The No-FP-Stack Floating-Point Wordset is not usually
@@ -17,7 +17,7 @@
 /*@{*/
 #if defined(__version_control__) && defined(__GNUC__)
 static char* id __attribute__((unused)) = 
-"@(#) $Id: %full_filespec:  fpnostack-ext.c~32.12:csrc:bln_mpt1!1 % $";
+"@(#) $Id: %full_filespec:  fpnostack-ext.c~33.18:csrc:bln_mpt1!1 % $";
 #endif
 
 #define _P4_SOURCE 1
@@ -148,7 +148,7 @@ p4_nofp_to_float (char *p, p4cell n, double *r)
 {
 # if USE_STRTOD		/* most systems have good strtod */
 
-    char buf[80], *q;
+    unsigned char buf[80], *q;
   
     if (!*p) return 0; 
     /* strtod does crash on vxworks being empty non-null *gud*/
@@ -157,7 +157,7 @@ p4_nofp_to_float (char *p, p4cell n, double *r)
     if (tolower (buf[n - 1]) == 'e')
         buf[n++] = '0';
     buf[n] = '\0';
-    *r = strtod (buf, &q);
+    *r = strtod (buf, (char**) &q);
     if (q == NULL)
         return 1;
     while (isspace (*q))
@@ -837,8 +837,8 @@ FCode (p4_nofp_f_dup)
 }
 
 /* originally P4_SKIPS_FLOAT */
-p4xt* 
-p4_lit_nofp_float_SEE (p4xt* ip, char* p, p4_Semant* s)
+p4xcode* 
+p4_lit_nofp_float_SEE (p4xcode* ip, char* p, p4_Semant* s)
 {
 # if PFE_ALIGNOF_DFLOAT > PFE_ALIGNOF_CELL
     if (!P4_DFALIGNED (ip))
