@@ -5,8 +5,8 @@
  *
  *  @see     GNU LGPL
  *  @author  Tektronix CTE              @(#) %derived_by: guidod %
- *  @version %version:  1.24 %
- *    (%date_modified:  Mon Feb 24 20:24:13 2003 %)
+ *  @version %version:  33.27 %
+ *    (%date_modified:  Wed Mar 19 15:29:26 2003 %)
  *  @description
  *    Implements header creation and navigation words including the
  *    ones from the forth-83 "experimental annex" targetting definition
@@ -17,7 +17,7 @@
 /*@{*/
 #if defined(__version_control__) && defined(__GNUC__)
 static char* id __attribute__((unused)) = 
-"@(#) $Id: %full_filespec:  header-ext.c~1.24:ascii:bln_mpt1!1 % $";
+"@(#) $Id: %full_filespec:  header-ext.c~33.27:ascii:bln_mpt1!1 % $";
 #endif
 
 #define _P4_SOURCE 1
@@ -242,7 +242,7 @@ FCode (p4_smudge)
         P4_warn ("do not use SMUDGE - use REVEAL or HIDE");
 
     if (LAST)
-        *NFA2FF(LAST) ^= P4xSMUDGED;
+        P4_NFA_FLAGS(LAST) ^= P4xSMUDGED; /* <-- XOR */
     else
         p4_throw (P4_ON_ARG_TYPE);
 }
@@ -255,7 +255,7 @@ FCode (p4_smudge)
 FCode (p4_hide)
 {
     if (LAST)
-        *NFA2FF(LAST) |= P4xSMUDGED;
+        P4_NFA_FLAGS(LAST) |= P4xSMUDGED;   /* <-- OR */
     else
         p4_throw (P4_ON_ARG_TYPE);
 }
@@ -275,7 +275,7 @@ FCode (p4_hide)
 FCode (p4_reveal)
 {
     if (LAST)
-        *NFA2FF(LAST) &= ~P4xSMUDGED;
+        P4_NFA_FLAGS(LAST) &= ~P4xSMUDGED;
     else
         p4_throw (P4_ON_ARG_TYPE);
 }
@@ -301,7 +301,7 @@ FCode (p4_reveal)
  */
 FCode (p4_name_flags_fetch)
 {
-    *SP = *NFA2FF(*SP);
+    *SP = P4_NFA_FLAGS(*SP);
 }
 
 /** NAME-FLAGS! ( nfa-flags nfa -- )
@@ -312,7 +312,7 @@ FCode (p4_name_flags_fetch)
  */
 FCode (p4_name_flags_store)
 {
-    *NFA2FF(SP[0]) = (p4ucell) SP[1];
+    P4_NFA_FLAGS(SP[0]) = (p4ucell) SP[1];
 }
 
 /* ------------------------------------------------------------------------ */
@@ -448,7 +448,7 @@ FCode (p4_synonym)
     FX_RUNTIME1 (p4_synonym);
     {
 	register p4char* nfa = p4_tick_nfa ();
-	if (*NFA2FF(nfa) & P4xIMMEDIATE) 
+	if (P4_NFA_xIMMEDIATE(nfa)) 
 	    FX_IMMEDIATE;
 	FX_XCOMMA (p4_name_from (nfa));
     }
@@ -493,6 +493,7 @@ P4_LISTWORDS (header) =
     P4_FXco ("$HEADER",		        p4_str_header),
     P4_xOLD ("HEADER",                  "$HEADER"),
     P4_FXco ("SMUDGE",			p4_smudge),
+    P4_FXco ("HIDE",                    p4_hide),
     P4_FXco ("REVEAL",			p4_reveal),
     P4_IXco ("RECURSIVE",		p4_reveal),
     P4_xOLD ("UNSMUDGE",                "REVEAL"),
