@@ -5,13 +5,13 @@
  *
  *  @see     GNU LGPL
  *  @author  Tektronix CTE              @(#) %derived_by: guidod %
- *  @version %version:  1.28 %
- *    (%date_modified:  Wed Sep 04 12:16:18 2002 %)
+ *  @version %version:  33.31 %
+ *    (%date_modified:  Wed Mar 19 18:05:40 2003 %)
  */
 /*@{*/
 #if defined(__version_control__) && defined(__GNUC__)
 static char* id __attribute__((unused)) = 
-"@(#) $Id: %full_filespec:  header-sub.c~1.28:ascii:bln_mpt1!1 % $";
+"@(#) $Id: %full_filespec:  header-sub.c~33.31:ascii:bln_mpt1!1 % $";
 #endif
 
 #define _P4_SOURCE 1
@@ -43,16 +43,6 @@ FCode_RT (p4_dictget_RT)
 }
 P4RUNTIME1_RT(p4_dictget);
 
-/**
- * (DICTSET) forth-thread valueset runtime, antonym of => VALUE
- */
-FCode_RT (p4_dictset_RT)
-{
-    FX_USE_BODY_ADDR;
-    *(p4cell *) ((char *) p4TH + FX_POP_BODY_ADDR[0]) = FX_POP;
-}
-P4RUNTIME1_RT(p4_dictset);
-
 /**
  * make a new dictionary entry in the word list identified by wid 
  *                   (fixme: delete the externs in other code portions)
@@ -77,11 +67,11 @@ p4_header_comma (const char *name, int len, p4_Wordl *wid)
 	    p4_throw (P4_ON_NAME_TOO_LONG);
 	}
 
-    if (REDEFINED_MSG && p4_search_wordlist (name, len, CURRENT))
+    if (REDEFINED_MSG && p4_search_wordlist (name, len, wid))
         p4_outf ("\n\"%.*s\" is redefined ", len, name);
 
     /* and now, do the p4_string_comma ... */
-#if defined PFE_WITH_FFA
+# if defined PFE_WITH_FFA
     /* for the FFA style we have to insert a flag byte before the 
      * string that might be HERE via a WORD call. However that makes
      * the string to move UP usually - so we have to compute the overall 
@@ -91,7 +81,7 @@ p4_header_comma (const char *name, int len, p4_Wordl *wid)
     LAST = DP-len -1;      /* point to count-byte before the name */
     *LAST = len;           /* set the count-byte */
     LAST[-1] = '\x80';     /* set the flag-byte before the count-byte */
-#elif defined PFE_WITH_FIG
+# elif defined PFE_WITH_FIG
     /* the FIG style variant is a bit more special - as it is trying to
      * be extra compatible with user code that expects N>LINK to actually
      * turn out to be "DUP C@ 31 AND + 1+" - i.e. the end of the name is
@@ -107,7 +97,7 @@ p4_header_comma (const char *name, int len, p4_Wordl *wid)
     LAST = DP-len -1;
     *LAST = len;
     *LAST |= '\x80';
-#else
+# else
     /* traditional way - avoid copying if using WORD. Just look for the
      * only if() in this code which will skip over the memcpy() call if
      * WORD $HEADER, was called. At the same time we do not look for any
@@ -122,7 +112,7 @@ p4_header_comma (const char *name, int len, p4_Wordl *wid)
     if (p4_ZNAMES_ALLOWED && *LAST != len) { *LAST = 0; DP[len] = 0; len++; }
     *LAST |= '\x80'; 
     DP += len; FX (p4_align); 
-#endif
+# endif
 
     /* and register in LAST and the correct (hashed) WORDLIST thread */
     hc = (wid->flag & WORDL_NOHASH) ? 0 : p4_wl_hash (LAST+1, len); 
@@ -137,7 +127,7 @@ p4_make_header (p4code cfa, char flags,
                 const char* name, int count, p4_Wordl* wid)
 {
     p4char* nfa = p4_header_comma (name, count, wid);
-    *NFA2FF(nfa) |= flags;
+    P4_NFA_FLAGS (nfa) |= flags;
     FX_RCOMMA (cfa);
 
     fprintf(stderr,"<error obsolete word used: make-header word=%.*s>", 
@@ -205,7 +195,6 @@ p4_to_body (p4xt xt)
             p4_abortq ("xt in '>BODY' out of range (not in my dict space)");
 
     if (P4_XT_VALUE(xt) == FX_GET_RT (p4_dictvar) || 
-	/* P4_XT_VALUE(xt) == FX_GET_RT (p4_dictset) || */
 	P4_XT_VALUE(xt) == FX_GET_RT (p4_dictget)) 
         return ((p4cell*)( (char*)p4TH + P4_TO_BODY(xt)[0] ));
     else if (P4_XT_VALUE(xt) == FX_GET_RT (p4_builds) ||
@@ -263,7 +252,9 @@ p4_link_to_name (p4char **l)
   /* Scan for count byte. Note: this is not reliable! */
     for (n = 0; n < NFACNTMAX+PRENFAWIDTH; n++, p--)
     {
-        if (*NFA2FF(p) & 0x80 && (unsigned)NFACNT(*p) == n)
+        /* traditional: search for CHAR of name-area with a hi-bit set
+         * and assume that it is the flags/count field for the NAME */
+        if (P4_NFA_x0x80(p) && (unsigned)P4_NFACNT(*p) == n)
             return p;
         if (! p4_isprint (*p))
             return NULL;
@@ -318,10 +309,15 @@ static void make_obsoleted_a_synonym (const p4char* p, p4xt xt)
 	      NFACNT(*p), p+1, NFACNT(*q), q+1);
 #   endif
 
-    p4_outs (" || obsolete word "); p4_dot_name(p); FX (p4_cr);
-    p4_outs (" | please use now "); p4_dot_name(q); FX (p4_cr);
-    p4_outs (" | (message reported only once per name"
-	     " - otherwise treated as SYNONYM)");
+    FX (p4_cr);
+    p4_outs (" ||  obsolete word  "); p4_dot_name(p); FX (p4_cr);
+    p4_outs (" | please change to "); p4_dot_name(q); FX (p4_cr);
+    if (q[1] != '_')
+        p4_outs (" | (message reported only once per name"
+                 " - otherwise treated as SYNONYM)");
+    else
+        p4_outs (" | (message reported only once per name"
+                 " - otherwise still implemented)");
     FX (p4_cr);
 
     P4_XT_VALUE(xt) = FX_GET_RT (p4_synonym); /* FX_GET_RUNTIME1(p4_synonym) */
@@ -353,9 +349,9 @@ p4_to_name (p4xt c)
 _export void
 p4_dot_name (const p4char *nfa)
 {
-    if (!nfa || !(*NFA2FF(nfa) & 0x80))
+    if (! nfa || ! P4_NFA_x0x80(nfa))
     {
-        p4_outs ("<\?\?\?> ");  /* avoid trigraph interpretation */
+        p4_outs ("<?""?""?> ");  /* avoid trigraph interpretation */
         return;
     }
     p4_type (nfa+1, NFACNT(*nfa));
