@@ -1,8 +1,8 @@
 #ifndef _PFE_HELP_EXT_H
-#define _PFE_HELP_EXT_H 1002653680
-/* generated 2001-1009-2054 ../../../pfe/../mk/Make-H.pl ../../../pfe/help-ext.c */
+#define _PFE_HELP_EXT_H 1063198935
+/* generated 2003-0910-1502 ../../../pfe/../mk/Make-H.pl ../../../pfe/help-ext.c */
 
-#include <pfe/incl-ext.h>
+#include <pfe/pfe-ext.h>
 
 /** 
  * -- extra words for external HELP system
