@@ -5,7 +5,7 @@
  *
  *  @see     GNU LGPL
  *  @author  Tektronix CTE              @(#) %derived_by: guidod %
- *  @version %version: bln_mpt1!1.19 %
+ *  @version %version: bln_mpt1!33.21 %
  *    (%date_modified: Mon Feb 24 20:28:15 2003 %)
  *
  *  @description
@@ -15,7 +15,7 @@
 /*@{*/
 #if defined(__version_control__) && defined(__GNUC__)
 static char* id __attribute__((unused)) = 
-"@(#) $Id: %full_filespec:  host-k12.c~bln_mpt1!1.19:csrc:bln_12xx!1 % $";
+"@(#) $Id: %full_filespec:  host-k12.c~bln_mpt1!33.21:csrc:bln_12xx!1 % $";
 #endif
  
 #define _P4_SOURCE 1
@@ -34,44 +34,6 @@ static char* id __attribute__((unused)) =
 #include <pfe/main-k12.h>
 #endif
 
-/** BOOT-SCRIPT@ ( -- s-a s-n )
- * the file that will be include on next => COLD boot
- * DO NOT USE! will vanish w/o warning in the next version!
- */
-FCode (p4_boot_script_fetch)
-{
-    if (PFE.set->include_file)
-    {
-        FX_PUSH (PFE.set->include_file);
-        FX_PUSH (strlen (PFE.set->include_file));
-    }else{
-        FX_PUSH (0);
-        FX_PUSH (0);
-    }
-}
-
-/** BOOT-SCRIPT: ( "string" -- )
- * DO NOT USE! will vanish w/o warning in the next version!
- * see => BOOT-SCRIPT@
- */
-FCode (p4_boot_script_colon)
-{
-    p4_word_parseword (' '); *DP=0; /* PARSE-WORD-NOHERE */
-    
-# ifdef _K12_SOURCE
-    { 
-        register p4_emu_t* p4 = P4_K12_EMUL(p4TH);
-
-        strncpy (p4->includes, PFE.word.ptr, PFE.word.len);
-        PFE.set->include_file = p4->includes;
-    }
-# else
-    {
-        p4_throw (P4_ON_OBSOLETED);
-    }
-#endif
-}
-
 /** OPEN-TERMINAL-LOGFILE ( s-buf s-len -- )
  * open terminal logfile named by the string-buffer
  * all further output to the terminal window is also logged into
@@ -191,8 +153,6 @@ FCode(p4_terminal_emulation_state)
 P4_LISTWORDS (host_k12) =
 {
     P4_INTO ("FORTH", 0),
-    P4_FXco ("BOOT-SCRIPT:",   p4_boot_script_colon),
-    P4_FXco ("BOOT-SCRIPT@",   p4_boot_script_fetch),
 # ifdef _K12_SOURCE
     P4_OCoN ("#K1297-G20",     _K12_SOURCE+100),
 # endif
