@@ -89,6 +89,26 @@
 
 #endif 
 
+#ifdef _K12_SOURCE
+
+#define P4_LOG_FA_ "FA."
+#define P4_LOG_SE_ "SE."
+#define P4_LOG_WA_ "WA."
+#define P4_LOG_IN_ "IN."
+#define P4_LOG_XI_ "XI."
+#define P4_LOG_NT_ " !_"
+
+#else
+
+#define P4_LOG_FA_ "<CRIT "
+#define P4_LOG_SE_ "<FAIL "
+#define P4_LOG_WA_ "<WARN "
+#define P4_LOG_IN_ "<INFO "
+#define P4_LOG_XI_ "<HINT "
+#define P4_LOG_NT_ "<NOTE "
+
+#endif
+
 /* The following Message groups shall contain informational messages with
 ** decreasing significance from 1 to 4. The messages shall be used in modules
 ** where it seems to be sane to tell the user lots of things about what the
@@ -236,17 +256,17 @@
   P4_LogDumpHex(P4_LOG_INFO, __FUNCTION__, str, adr, len, mode)
 
 #define P4_info(str) \
-  P4_LogMsg (P4_LOG_INFO, "IN.",__FUNCTION__, str)
+  P4_LogMsg (P4_LOG_INFO, P4_LOG_IN_,__FUNCTION__, str)
 #define P4_info1(str, x1) \
-  P4_LogMsg1(P4_LOG_INFO, "IN.",__FUNCTION__, str, x1)
+  P4_LogMsg1(P4_LOG_INFO, P4_LOG_IN_,__FUNCTION__, str, x1)
 #define P4_info2(str, x1, x2) \
-  P4_LogMsg2(P4_LOG_INFO, "IN.",__FUNCTION__, str, x1, x2)
+  P4_LogMsg2(P4_LOG_INFO, P4_LOG_IN_,__FUNCTION__, str, x1, x2)
 #define P4_info3(str, x1, x2, x3) \
-  P4_LogMsg3(P4_LOG_INFO, "IN.",__FUNCTION__, str, x1, x2, x3)
+  P4_LogMsg3(P4_LOG_INFO, P4_LOG_IN_,__FUNCTION__, str, x1, x2, x3)
 #define P4_info4(str, x1, x2, x3, x4) \
-  P4_LogMsg4(P4_LOG_INFO, "IN.",__FUNCTION__, str, x1, x2, x3, x4)
+  P4_LogMsg4(P4_LOG_INFO, P4_LOG_IN_,__FUNCTION__, str, x1, x2, x3, x4)
 #define P4_info5(str, x1, x2, x3, x4, x5) \
-  P4_LogMsg5(P4_LOG_INFO, "IN.",__FUNCTION__, str, x1, x2, x3, x4, x5)
+  P4_LogMsg5(P4_LOG_INFO, P4_LOG_IN_,__FUNCTION__, str, x1, x2, x3, x4, x5)
   
 #else
 
@@ -271,17 +291,17 @@
   P4_LogDumpHex(P4_LOG_WARNING, __FUNCTION__, str, adr, len, mode)
 
 #define P4_warn( str) \
-  P4_LogMsg (P4_LOG_WARN, "WA.",__FUNCTION__, str)
+  P4_LogMsg (P4_LOG_WARN, P4_LOG_WA_,__FUNCTION__, str)
 #define P4_warn1( str, x1) \
-  P4_LogMsg1(P4_LOG_WARN, "WA.",__FUNCTION__, str, x1)
+  P4_LogMsg1(P4_LOG_WARN, P4_LOG_WA_,__FUNCTION__, str, x1)
 #define P4_warn2( str, x1, x2) \
-  P4_LogMsg2(P4_LOG_WARN, "WA.",__FUNCTION__, str, x1, x2)
+  P4_LogMsg2(P4_LOG_WARN, P4_LOG_WA_,__FUNCTION__, str, x1, x2)
 #define P4_warn3( str, x1, x2, x3) \
-  P4_LogMsg3(P4_LOG_WARN, "WA.",__FUNCTION__, str, x1, x2, x3)
+  P4_LogMsg3(P4_LOG_WARN, P4_LOG_WA_,__FUNCTION__, str, x1, x2, x3)
 #define P4_warn4( str, x1, x2, x3, x4) \
-  P4_LogMsg4(P4_LOG_WARN, "WA.",__FUNCTION__, str, x1, x2, x3, x4)
+  P4_LogMsg4(P4_LOG_WARN, P4_LOG_WA_,__FUNCTION__, str, x1, x2, x3, x4)
 #define P4_warn5( str, x1, x2, x3, x4, x5) \
-  P4_LogMsg5(P4_LOG_WARN, "WA.",__FUNCTION__, str, x1, x2, x3, x4, x5)
+  P4_LogMsg5(P4_LOG_WARN, P4_LOG_WA_,__FUNCTION__, str, x1, x2, x3, x4, x5)
   
 #else
 
@@ -306,17 +326,17 @@
   P4_LogDumpHex(P4_LOG_FAIL, __FUNCTION__, str, adr, len, mode)
 
 #define P4_fail( str) \
-  P4_LogMsg (P4_LOG_FAIL, "SE.",__FUNCTION__, str)
+  P4_LogMsg (P4_LOG_FAIL, P4_LOG_SE_,__FUNCTION__, str)
 #define P4_fail1( str, x1) \
-  P4_LogMsg1(P4_LOG_FAIL, "SE.",__FUNCTION__, str, x1)
+  P4_LogMsg1(P4_LOG_FAIL, P4_LOG_SE_,__FUNCTION__, str, x1)
 #define P4_fail2( str, x1, x2) \
-  P4_LogMsg2(P4_LOG_FAIL, "SE.",__FUNCTION__, str, x1, x2)
+  P4_LogMsg2(P4_LOG_FAIL, P4_LOG_SE_,__FUNCTION__, str, x1, x2)
 #define P4_fail3( str, x1, x2, x3) \
-  P4_LogMsg3(P4_LOG_FAIL, "SE.",__FUNCTION__, str, x1, x2, x3)
+  P4_LogMsg3(P4_LOG_FAIL, P4_LOG_SE_,__FUNCTION__, str, x1, x2, x3)
 #define P4_fail4( str, x1, x2, x3, x4) \
-  P4_LogMsg4(P4_LOG_FAIL, "SE.",__FUNCTION__, str, x1, x2, x3, x4)
+  P4_LogMsg4(P4_LOG_FAIL, P4_LOG_SE_,__FUNCTION__, str, x1, x2, x3, x4)
 #define P4_fail5( str, x1, x2, x3, x4, x5) \
-  P4_LogMsg5(P4_LOG_FAIL, "SE.",__FUNCTION__, str, x1, x2, x3, x4, x5)
+  P4_LogMsg5(P4_LOG_FAIL, P4_LOG_SE_,__FUNCTION__, str, x1, x2, x3, x4, x5)
 
 #else
 
@@ -341,17 +361,17 @@
   P4_LogDumpHex(P4_LOG_FATAL, __FUNCTION__, str, adr, len, mode)
 
 #define P4_fatal(str) \
-  P4_LogMsg (P4_LOG_FATAL, "FA.",__FUNCTION__, str)
+  P4_LogMsg (P4_LOG_FATAL, P4_LOG_FA_,__FUNCTION__, str)
 #define P4_fatal1(str, x1) \
-  P4_LogMsg1(P4_LOG_FATAL, "FA.",__FUNCTION__, str, x1)
+  P4_LogMsg1(P4_LOG_FATAL, P4_LOG_FA_,__FUNCTION__, str, x1)
 #define P4_fatal2(str, x1, x2) \
-  P4_LogMsg2(P4_LOG_FATAL, "FA.",__FUNCTION__, str, x1, x2)
+  P4_LogMsg2(P4_LOG_FATAL, P4_LOG_FA_,__FUNCTION__, str, x1, x2)
 #define P4_fatal3(str, x1, x2, x3) \
-  P4_LogMsg3(P4_LOG_FATAL, "FA.",__FUNCTION__, str, x1, x2, x3)
+  P4_LogMsg3(P4_LOG_FATAL, P4_LOG_FA_,__FUNCTION__, str, x1, x2, x3)
 #define P4_fatal4(str, x1, x2, x3, x4) \
-  P4_LogMsg4(P4_LOG_FATAL, "FA.",__FUNCTION__, str, x1, x2, x3, x4)
+  P4_LogMsg4(P4_LOG_FATAL, P4_LOG_FA_,__FUNCTION__, str, x1, x2, x3, x4)
 #define P4_fatal5(str, x1, x2, x3, x4, x5) \
-  P4_LogMsg5(P4_LOG_FATAL, "FA.",__FUNCTION__, str, x1, x2, x3, x4, x5)
+  P4_LogMsg5(P4_LOG_FATAL, P4_LOG_FA_,__FUNCTION__, str, x1, x2, x3, x4, x5)
 
 #else
 
@@ -376,17 +396,17 @@
   P4_LogDumpHex(P4_LOG_MESG, __FUNCTION__, str, adr, len, mode)
 
 #define P4_mesg( str) \
-  P4_LogMsg (P4_LOG_MESG, "XI.",__FUNCTION__, str)
+  P4_LogMsg (P4_LOG_MESG, P4_LOG_XI_,__FUNCTION__, str)
 #define P4_mesg1( str, x1) \
-  P4_LogMsg1(P4_LOG_MESG, "XI.",__FUNCTION__, str, x1)
+  P4_LogMsg1(P4_LOG_MESG, P4_LOG_XI_,__FUNCTION__, str, x1)
 #define P4_mesg2( str, x1, x2) \
-  P4_LogMsg2(P4_LOG_MESG, "XI.",__FUNCTION__, str, x1, x2)
+  P4_LogMsg2(P4_LOG_MESG, P4_LOG_XI_,__FUNCTION__, str, x1, x2)
 #define P4_mesg3( str, x1, x2, x3) \
-  P4_LogMsg3(P4_LOG_MESG, "XI.",__FUNCTION__, str, x1, x2, x3)
+  P4_LogMsg3(P4_LOG_MESG, P4_LOG_XI_,__FUNCTION__, str, x1, x2, x3)
 #define P4_mesg4( str, x1, x2, x3, x4) \
-  P4_LogMsg4(P4_LOG_MESG, "XI.",__FUNCTION__, str, x1, x2, x3, x4)
+  P4_LogMsg4(P4_LOG_MESG, P4_LOG_XI_,__FUNCTION__, str, x1, x2, x3, x4)
 #define P4_mesg5( str, x1, x2, x3, x4, x5) \
-  P4_LogMsg5(P4_LOG_MESG, "XI.",__FUNCTION__, str, x1, x2, x3, x4, x5)
+  P4_LogMsg5(P4_LOG_MESG, P4_LOG_XI_,__FUNCTION__, str, x1, x2, x3, x4, x5)
 
 #else
 
@@ -407,17 +427,17 @@
   P4_LogDumpHex(P4_LOG_NOTE, __FUNCTION__, str, adr, len, mode)
 
 #define P4_note( str) \
-  P4_LogMsg (P4_LOG_NOTE, " !_",__FUNCTION__, str)
+  P4_LogMsg (P4_LOG_NOTE, P4_LOG_NT_,__FUNCTION__, str)
 #define P4_note1( str, x1) \
-  P4_LogMsg1(P4_LOG_NOTE, " !_",__FUNCTION__, str, x1)
+  P4_LogMsg1(P4_LOG_NOTE, P4_LOG_NT_,__FUNCTION__, str, x1)
 #define P4_note2( str, x1, x2) \
-  P4_LogMsg2(P4_LOG_NOTE, " !_",__FUNCTION__, str, x1, x2)
+  P4_LogMsg2(P4_LOG_NOTE, P4_LOG_NT_,__FUNCTION__, str, x1, x2)
 #define P4_note3( str, x1, x2, x3) \
-  P4_LogMsg3(P4_LOG_NOTE, " !_",__FUNCTION__, str, x1, x2, x3)
+  P4_LogMsg3(P4_LOG_NOTE, P4_LOG_NT_,__FUNCTION__, str, x1, x2, x3)
 #define P4_note4( str, x1, x2, x3, x4) \
-  P4_LogMsg4(P4_LOG_NOTE, " !_",__FUNCTION__, str, x1, x2, x3, x4)
+  P4_LogMsg4(P4_LOG_NOTE, P4_LOG_NT_,__FUNCTION__, str, x1, x2, x3, x4)
 #define P4_note5( str, x1, x2, x3, x4, x5) \
-  P4_LogMsg5(P4_LOG_NOTE, " !_",__FUNCTION__, str, x1, x2, x3, x4, x5)
+  P4_LogMsg5(P4_LOG_NOTE, P4_LOG_NT_,__FUNCTION__, str, x1, x2, x3, x4, x5)
 
 #else
 
