@@ -5,15 +5,15 @@
  *
  *  @see     GNU LGPL
  *  @author  Tektronix CTE              @(#) %derived_by: guidod %
- *  @version %version: bln_mpt1!1.13 %
- *    (%date_modified: Mon Mar 25 17:02:44 2002 %)
+ *  @version %version: bln_mpt1!1.14 %
+ *    (%date_modified: Fri Mar 14 17:00:39 2003 %)
  *
  *  @description
  *  Process command line, get memory and start up the interpret loop of PFE
  */
 /*@{*/
 
-#include "pfe-config.h"
+#include "pfe/_config.h"
 
 #if defined PFE_WITH_STATIC_REGS
 #include "main-alloc.c"
