@@ -1,20 +1,20 @@
 /**
  *
- *  Copyright (C) Tektronix, Inc. 1998 - 2001. All rights reserved.
+ *  Copyright (C) Tektronix, Inc. 1998 - 2003. All rights reserved.
  *
  *  @author Tektronix CTE               @(#) %derived_by: guidod %
- *  @version %version: bln_mpt1!5.45 %
+ *  @version %version: bln_mpt1!33.49 %
  *    (%date_modified: Tue Aug 13 14:56:19 2002 %)
  */
 /*@{ */
 #if defined(__version_control__) && defined(__GNUC__)
 static char * id __attribute__((unused)) =
-"@(#) $Id: %full_filespec: main-k12.c~bln_mpt1!5.45:csrc:bln_12xx!2 % $";
+"@(#) $Id: %full_filespec: main-k12.c~bln_mpt1!33.49:csrc:bln_12xx!2 % $";
 #endif
 
 #define _P4_SOURCE 1
 
-#include <pfe/incl-ext.h>
+#include <pfe/pfe-ext.h>
 
 #include <stddef.h> /*offsetof*/
 #include <stdlib.h>
@@ -27,7 +27,8 @@ static char * id __attribute__((unused)) =
 #include <K12/emul.h>
 #include <K12/trace.h>
 
-#include <pfe/main-sub.h>
+#include <pfe/engine-set.h>
+#include <pfe/option-set.h>
 #include <pfe/main-k12.h>
 #include <pfe/term-k12.h>
 #include <pfe/logging.h>
@@ -37,6 +38,8 @@ static char * id __attribute__((unused)) =
 #include <pfe/version-sub.h>
 #include <gemapi.h>
 
+#include <pfe/option-ext.h>
+
 #ifdef  CLOCKS_PER_SEC_BUG
 #undef  CLOCKS_PER_SEC
 #define CLOCKS_PER_SEC sysClkRateGet()
@@ -55,6 +58,8 @@ static char * id __attribute__((unused)) =
 #define MSC_MAX_TIMERS 64
 #endif
 
+#define config_blocked has.config.blocked
+
 /* definition of enumeral types, for config/query menu */
 static k12_emu_enum_t
 StatesEnum[] =
@@ -370,17 +375,65 @@ p4_emu_scriptfile (k12_emu_type_t* emul_id,
 		   u8_t* str,
 		   s8_t* addr)
 {
-    char buf [256] = "BOOT-SCRIPT: ";
-    /* NO P4_CALLER_SAVEALL necessary - no forth VM register used */
+    register status_t e;
+    p4_emu_t* p4;
 
-    if (!str || strlen(str) <= 1) return K12_GEN_OK;
-    if (mode&K12_EMU_QUERY) return K12_GEN_ILLMODE;
+    e=k12EmuLowBaseGet (emul_id, (void*)&p4);
+    if (e) return e;
 
-    strncat (buf, str, 256);
-    strncat (buf, " BOOT-SCRIPT@ INCLUDED", 256);
-    return p4_emu_command (emul_id, mode, buf, addr);
+    if (mode&K12_EMU_CONFIG)
+    {
+        if (p4->config_blocked) return _K12_EAGAIN; 
+        if (!*str || *str == ' ' || ! strcmp (str, "\"\"")) str = "";
+        p4->has.config.scriptfile =
+            p4_change_option_string ("SCRIPT-FILE", 11, str, &p4->session);
+    }
+    else if (mode&K12_EMU_QUERY)
+    {
+        if (! p4->has.config.scriptfile) 
+            p4->has.config.scriptfile = p4_lookup_option_string (
+                "SCRIPT-FILE", 11, 0, &p4->session);
+        *str = '\0';
+        if (p4->has.config.scriptfile && *p4->has.config.scriptfile)
+            strncpy (str, *p4->has.config.scriptfile, 255);
+    }
+    return K12_GEN_OK;
 }
 
+/* BEWARE: called from LEM context */
+status_t
+p4_emu_scriptpath (k12_emu_type_t* emul_id,
+		   u32_t mode,
+		   u8_t* str,
+		   s8_t* addr)
+{
+    register status_t e;
+    p4_emu_t* p4;
+
+    e=k12EmuLowBaseGet (emul_id, (void*)&p4);
+    if (e) return e;
+
+    if (mode&K12_EMU_CONFIG)
+    {
+        if (p4->config_blocked) return _K12_EAGAIN; 
+        if (!*str || *str == ' ') str = PFE_PKGDATADIR;
+        p4->has.config.scriptpath =
+            p4_change_option_string ("INC-PATH", 8, str, &p4->session);
+    }
+    else if (mode&K12_EMU_QUERY)
+    {
+        if (! p4->has.config.scriptpath) 
+            p4->has.config.scriptpath = p4->session.inc_paths;
+        /*  p4_lookup_option_string ("INC-PATH", 8, 0, &p4->session);  */
+        strcpy (str, PFE_PKGDATADIR);
+        if (p4->has.config.scriptpath && *p4->has.config.scriptpath)
+            strncpy (str, *p4->has.config.scriptpath, 255);
+    }
+
+    return K12_GEN_OK;
+}
+
+
 /* BEWARE: called from LEM context */
 status_t
 p4_emu_do_config (k12_emu_type_t* emul_id,
@@ -785,35 +838,36 @@ status_t
 emuInit (k12_emu_type_t* emul_id)
 {
     register status_t e;
-    p4_emu_t* pEmul;
+    p4_emu_t* p4;
     /* NO P4_CALLER_SAVEALL necessary - no forth VM register used */
 
 # ifdef DEBUG
     K12LogInit(0, 64, K12_LOG_DIRECT);
 # endif
 
-    e=k12EmuLowMemGet (emul_id, sizeof (p4_emu_t), (s8_t**) &pEmul);
+    e=k12EmuLowMemGet (emul_id, sizeof (p4_emu_t), (s8_t**) &p4);
     if (e) return (K12_GEN_NOMEM);
 
-    memset (pEmul, 0, sizeof (p4_emu_t));
+    memset (p4, 0, sizeof (p4_emu_t));
     /* pEmul->private.state = K12_EMU_IDLE; */ /* -> term-k12.c */
 
-    /* must be called *before* TableInd - right ?? */
-    p4_SetOptions (&pEmul->session, 0, 1, (char**) &"p4th");
+    /* must be called *before* TableInd - 'cause we want to use OPT space! */
+    p4_SetOptions (&p4->session, sizeof(p4->session) + sizeof (p4->extra), 
+                   1, (const char**) &"p4th");
 
     /* don't forget about prelinked modules, e.g. zchar-ext */
     { extern p4Words P4WORDS(internal);
-    p4_SetModules (&pEmul->session, &(P4WORDS(internal)));
+    p4_SetModules (&p4->session, &(P4WORDS(internal)));
     }
 
     /* pass table of features - menusystem may write to those vars now ! */
-    e=k12EmuLowTableInd (emul_id, &p4_emu_table, (s8_t *)pEmul);
+    e=k12EmuLowTableInd (emul_id, &p4_emu_table, (s8_t *)p4);
     if (e) return (e);
 
     K12LogDebug1(1, "p4.emuInit",
       "privat data size=%08lX\n", (u32_t)sizeof(p4_emu_t));
 
-    pEmul->thread.term = &p4_term_k12; /* the gui interface */
+    p4->thread.term = &p4_term_k12; /* the gui interface */
 
     return (K12_GEN_OK);
 }
@@ -860,25 +914,24 @@ status_t
 emuStart (k12_emu_type_t* emul_id)
 {
     register status_t e;
-    p4_emu_t* p4_emu;
+    p4_emu_t* p4;
     /* P4_CALLER_SAVEALL not necessary - it has its own thread-context */
 
-    e=k12EmuLowBaseGet (emul_id, (void*)&p4_emu);
+    e=k12EmuLowBaseGet (emul_id, (void*)&p4);
     if (e) return (e);
 
-    if (*p4_emu->includes)
-        p4_emu->session.include_file = p4_emu->includes;
-    if (!*p4_emu->incpaths)
-        strncpy (p4_emu->incpaths, PFE_PKGDATADIR, 254);
-    p4_emu->session.incpaths = p4_emu->incpaths;
+    /* did someone reset this? */
+    if (p4->session.inc_paths && *p4->session.inc_paths &&
+        !**p4->session.inc_paths) /* an empty strings as INC-PATH */
+        p4_change_option_string ("INC-PATH", 8, PFE_PKGDATADIR, &p4->session);
 
-    p4_emu->session.cpus = 1;
-    /*  p4_emu->session.cpu[0] = &p4_emu->thread; */
-    p4_emu->thread.set = &p4_emu->session;
-    p4_emu->thread.priv = &p4_emu->private;
-    p4_emu->private.emu = emul_id;
+    p4->session.cpus = 1;
+    /*  p4->session.cpu[0] = &p4->thread; */
+    p4->thread.set = &p4->session;
+    p4->thread.priv = &p4->private;
+    p4->private.emu = emul_id;
 
-    p4_emu->private.validation_req = 0;
+    p4->private.validation_req = 0;
     {
         int i = 0;
         k12_emu_event_t ev; k12_emu_msg_subhead_t* msg; u32_t len;
@@ -896,12 +949,12 @@ emuStart (k12_emu_type_t* emul_id)
                           " CLOCKS_PER_SEC = %lu",
                           msg->type, ((long) CLOCKS_PER_SEC));
                 taskDelay(CLOCKS_PER_SEC);
-                if (p4_emu->private.state == K12_EMU_WARNING)
+                if (p4->private.state == K12_EMU_WARNING)
                 {
-                    p4_emu->private.state = K12_EMU_ERROR_CASE;
+                    p4->private.state = K12_EMU_ERROR_CASE;
                     P4_debug (13, "set EMU_ERROR - go creeping startup mode");
                 } else{
-                    p4_emu->private.state = K12_EMU_WARNING;
+                    p4->private.state = K12_EMU_WARNING;
                     P4_debug (13, "set EMU_WARNING -  new timeout 1000*HZ");
                     k12EmuLowTimerStart (emul_id, 0x4e77, 1000*CLOCKS_PER_SEC);
                 }
@@ -910,9 +963,9 @@ emuStart (k12_emu_type_t* emul_id)
                 k12EmuLowTimerStop(emul_id, 0x4e77 /*K12_EMU_VALIDATION_REQ*/);
                 if (k12EmuLowEventPut(emul_id, ev, (char*) msg, len,
                                       K12_EMU_NOOPT) == K12_GEN_OK)
-                { p4_emu->private.validation_req ++; }
+                { p4->private.validation_req ++; }
 
-                return p4_Exec(&p4_emu->thread); /* outer-API (SAVEALL) */
+                return p4_Exec(& p4->thread); /* outer-API (SAVEALL) */
 
             default:
                 P4_warn2 ("UNK START MSG type->0x%x len->%u",
@@ -922,7 +975,7 @@ emuStart (k12_emu_type_t* emul_id)
                 /* config-cb to command-msg via xdat-req */
                 if (++i > 3)
                     P4_warn ("START DELAYED (and requeue message) (HZ/2)");
-                switch (p4_emu->private.state)
+                switch (p4->private.state)
                 {
                 case K12_EMU_ERROR_CASE:
                     taskDelay(CLOCKS_PER_SEC*16); break;
