@@ -1,11 +1,11 @@
 #ifndef __PFE_MAIN_K12_H
-#define __PFE_MAIN_K12_H "%full_filespec: main-k12.h~bln_mpt1!32.55:incl:bln_12xx!2 %"
+#define __PFE_MAIN_K12_H "%full_filespec: main-k12.h~bln_mpt1!33.56:incl:bln_12xx!2 %"
 /** @name main-k12.h
  *
  *  Copyright (C) Tektronix, Inc. 1998 - 2000. All rights reserved.
  *
  *  @author Tektronix CTE               @(#) %derived_by: guidod %
- *  @version %version: bln_mpt1!32.55 %
+ *  @version %version: bln_mpt1!33.56 %
  *    (%date_modified: Tue Oct 22 15:13:21 2002 %)
  */
 /*@{ */
@@ -24,13 +24,18 @@ typedef struct                  /* FIXME: Later deletion planned! */
 typedef struct
 {
     struct k12_priv private;
-    struct p4_Session session;
+    union { 
+        p4_Session old;
+        struct {
+            char blocked; /* #define config_blocked has.config.blocked */
+            char const** scriptfile;
+            char const** scriptpath; /* session.inc_paths */
+        } config;
+    } has; 
     struct p4_Thread  thread;
     _p4_msc_var_buf_t msc_vars;
-                                /* FIXME: Later deletion planned! */
-    char   includes[255];
-    char   incpaths[255];
-    char   config_blocked;
+    struct p4_Session session;
+    char   extra[1024];
 } p4_emu_t;
 
 extern k12_emu_table_t   p4_emu_table;
