@@ -5,8 +5,8 @@
  *
  *  @see     GNU LGPL
  *  @author  Tektronix CTE              @(#) %derived_by: guidod %
- *  @version %version: 1.4 %
- *    (%date_modified: Fri May 11 19:19:02 2001 %)
+ *  @version %version: bln_mpt1!1.6 %
+ *    (%date_modified: Mon Mar 25 16:46:50 2002 %)
  *
  *  @description
  *  Process command line, get memory and start up the interpret loop of PFE
@@ -15,7 +15,7 @@
 
 #if defined(__version_control__) && defined(__GNUC__)
 static char* id __attribute__((unused)) = 
-"@(#) $Id: %full_filespec: main-static.c~1.4:csrc:bln_12xx!1 % $";
+"@(#) $Id: %full_filespec: main-static.c~bln_mpt1!1.6:csrc:bln_12xx!1 % $";
 #endif
 
 #define _P4_SOURCE 1
@@ -34,10 +34,16 @@ main (int argc, char** argv)
     int i;
   
     if ((i=p4_SetOptions (&session, 0, argc, argv))) return i-1;
+# ifndef PFE_WITH_MODULES
+    {	extern p4Words P4WORDS(internal);
+    if ((i=p4_SetModules (&session, &(P4WORDS(internal))))) return i-1;
+    }
+# endif
 
     thread = (p4_Thread*) memory;
     memset (thread, 0, sizeof(p4_Thread));
-    
+
+    /* how to override the size of the dict if the user did use an option? */
     p4_SetDictMem(thread, memory+sizeof(p4_Thread));
     thread->set = &session;
 
