@@ -25,6 +25,11 @@ static char* id __attribute__((unused)) =
 #include <string.h>
 #include <errno.h>
 
+#ifdef PFE_HAVE_SYS_RESOURCE_H
+#include <sys/time.h>
+#include <sys/resource.h>
+#endif
+
 #ifdef STATIC_MAIN
 #define main static_main
  static 
@@ -49,6 +54,13 @@ main (int argc, char** argv)
     }
 # endif
 
+# ifdef PFE_HAVE_SYS_RESOURCE_H
+    {/* a pfe does not need lots of data on the real cpu return stack */
+	struct rlimit rlimits = { 64*1024, 64*1024 };
+	setrlimit (RLIMIT_STACK, &rlimits);
+    }
+# endif
+
     return p4_FreeOptions (
         p4_Exec (p4_SetThreadOf( &x.thread , &x.session )), 
         &x.session); 
