@@ -1,8 +1,8 @@
 #ifndef _PFE_MEMORY_ALLOC_EXT_H
-#define _PFE_MEMORY_ALLOC_EXT_H 1034771916
-/* generated 2002-1016-1438 ../../../pfe/../mk/Make-H.pl ../../../pfe/memory-alloc-ext.c */
+#define _PFE_MEMORY_ALLOC_EXT_H 1063198930
+/* generated 2003-0910-1502 ../../../pfe/../mk/Make-H.pl ../../../pfe/memory-alloc-ext.c */
 
-#include <pfe/incl-ext.h>
+#include <pfe/pfe-ext.h>
 
 /** 
  * -- The Optional Memory Allocation Word Set
