@@ -5,7 +5,7 @@
  *
  *  @see     GNU LGPL
  *  @author  Tektronix CTE              @(#) %derived_by: guidod %
- *  @version %version: bln_mpt1!5.57 %
+ *  @version %version: bln_mpt1!33.66 %
  *    (%date_modified: Mon Feb 24 20:03:36 2003 %)
  *
  *  @description
@@ -14,7 +14,7 @@
 /*@{*/
 #if defined(__version_control__) && defined(__GNUC__)
 static char* id __attribute__((unused)) = 
-"@(#) $Id: %full_filespec:  misc-ext.c~bln_mpt1!5.57:csrc:bln_12xx!1 % $";
+"@(#) $Id: %full_filespec:  misc-ext.c~bln_mpt1!33.66:csrc:bln_12xx!1 % $";
 #endif
 
 #define _P4_SOURCE 1
@@ -37,12 +37,13 @@ static char* id __attribute__((unused)) =
 #include <pfe/block-mix.h>
 
 #include <pfe/def-words.h>
+#include <pfe/logging.h>
 #include <pfe/_missing.h>
 
 /** COLD ( -- )
  * cold abort - reinitialize everything and go to => QUIT routine
  * ... this routine is implemented as a warm-boot in pfe.
- : WARM FENCE @ (FORGET) INCLUDE-FILE ?DUP IF COUNT INCLUDED THEN QUIT ;
+ : COLD [ ALSO ENVIRONMENT ] EMPTY SCRIPT-FILE INCLUDED QUIT ;
  */
 FCode (p4_cold)
 {
@@ -53,24 +54,42 @@ FCode (p4_cold)
     p4_forget (PFE.dict);
     PFE.atexit_running = 0;
 
-    p4_boot_system (); 
+    FX (p4_cold_system); 
+    FX (p4_boot_system); 
 #else
     PFE.atexit_running = 1;
-    p4_forget (FENCE);
+    {
+        p4char* golden = p4_search_wordlist ("EMPTY", 5, PFE.environ_wl);
+        if (golden)
+        {
+            p4xt xt = p4_name_from(golden);
+            if (*P4_TO_CODE(xt) != PFX (p4_marker_RT))
+                P4_fail ("COLD found non-MARKER named EMPTY in ENVIRONMENT,"
+                         " that is suspicious but still going to execute it");
+
+            /*do we need a CATCH-domain here? that'd be usage errors, right?*/
+            golden = PFE.dp;
+            p4_call (xt); /* runs => (FORGET) with MARKER-address */
+            if (PFE.dp == golden)
+            {
+                P4_fail ("COLD did run EMPTY but dictionary space was not"
+                         " touched, so now do FORGET>FENCE additionally");
+                p4_forget (FENCE);
+            }
+        }else{
+            p4_forget (FENCE);
+        }
+    }
     PFE.atexit_running = 0;
 #endif
 
     FX (p4_paren_abort);
-
-    if (PFE_set.include_file)
-    {
-        p4_included1 (PFE_set.include_file, strlen (PFE_set.include_file), 0);
-    }
+    FX (p4_script_files);
 
     /* If it's a turnkey-application, start it: */
     if (APPLICATION)
     {
-        p4_run_forth (APPLICATION);
+        p4_call_loop (APPLICATION);
         p4_longjmp_exit (); 
     }
     if (P4_opt.verbose)
@@ -179,20 +198,20 @@ FCode (p4_random)
         *SP = _rand_ ();
     else
     {
-# if (PFE_SIZEOF_CELL == 2 && RAND_MAX-0 == 32767) \
-  || (PFE_SIZEOF_CELL == 4 && RAND_MAX-0 == 2147483647L)
+#     if (PFE_SIZEOF_CELL == 2 && RAND_MAX-0 == 32767) \
+      || (PFE_SIZEOF_CELL == 4 && RAND_MAX-0 == 2147483647L)
         /* ansi-rand has 15-bit, and most unix-rand have 31-bit */
         *SP = p4_d_ummul (*SP, _rand_ () << 1).hi;
-# elif (PFE_SIZEOF_CELL >= 4) 
+#     elif (PFE_SIZEOF_CELL >= 4) 
         if (*(p4ucell*)SP < 32767)
         { /* many systems are 32-bit or better */
             *(p4ucell*)SP *= (p4ucell) _rand_ () & 32767;
             *(p4ucell*)SP >>= 15;
         }else
             *SP = ((p4ucell) _rand_ ()) % (*(p4ucell*)SP);
-# else
+#     else
         *SP = ((p4ucell) _rand_ ()) % (*(p4ucell*)SP);
-# endif        
+#     endif        
     }
 }
 
@@ -202,11 +221,11 @@ FCode (p4_random)
  */
 FCode (p4_srand)			
 {
-#if defined PFE_HAVE_RANDOM
+#  if defined PFE_HAVE_RANDOM
     srandom (*SP++);
-#else
+#  else
     srand (*SP++);
-#endif
+#  endif
 }
 
 /** UNDER+ ( n1 x n2 -- n1+n2 x ) TF
@@ -338,18 +357,18 @@ FCode (p4_source_line)
 {
     switch (SOURCE_ID)
     {
-     case 0:
-         if (BLK)
-         {
-             *--SP = TO_IN / 64 + 1;	/* source line from BLOCK */
-             break;
-         }
-         /* else fallthrough */
-     case -1:			/* string from EVALUATE */
-         *--SP = 0;		/* or from QUERY (0/BLK==0) */
-         break;
-     default:			/* source line from text file */
-         *--SP = SOURCE_FILE->n + 1;
+    case 0:
+	if (BLK)
+	{
+	    *--SP = TO_IN / 64 + 1;	/* source line from BLOCK */
+	    break;
+	}
+	/* else fallthrough */
+    case -1:			/* string from EVALUATE */
+	*--SP = 0;		/* or from QUERY (0/BLK==0) */
+	break;
+    default:			/* source line from text file */
+	*--SP = SOURCE_FILE->n + 1;
     }
 }
 
@@ -361,15 +380,15 @@ FCode (p4_source_name)
 {
     switch (SOURCE_ID)
     {
-     case 0:
-         if (BLK) FX_PUSH("*block#*");
-	 else FX_PUSH ("*query*"); /*correct?*/
-	 break;
-     case -1:	
-	 FX_PUSH ("*evaluate*");
-         break;
-     default:			/* source line from text file */
-         FX_PUSH (SOURCE_FILE->name);
+    case 0:
+	if (BLK) FX_PUSH("*block#*");
+	else FX_PUSH ("*query*"); /*correct?*/
+	break;
+    case -1:	
+	FX_PUSH ("*evaluate*");
+	break;
+    default:			/* source line from text file */
+	FX_PUSH (SOURCE_FILE->name);
     }
     FX_1ROOM; SP[0] = strlen((char*)(SP[1]));
 }
@@ -379,11 +398,10 @@ FCode (p4_source_name)
  */
 FCode (p4_th_pocket)			
 {			
-    int n = *SP;
-
-    SP -= 1;
-    SP[1] = (p4cell) PFE.pockets[n] + 1;
-    SP[0] = *(p4char *) PFE.pockets[n];
+    p4cell n = FX_POP;
+    p4char* str = PFE.pockets_ptr[n].buffer;
+    FX_PUSH (str + 1);
+    FX_PUSH (*str);
 }
 
 /** POCKET-PAD ( -- addr )
@@ -583,10 +601,10 @@ FCode (p4_close_all_files)
 FCode (p4_dot_memory)
 {
     p4_outf ("\nDictionary space:    %7ld Bytes, in use: %7ld Bytes\n"
-	"Stack space:         %7ld %s\n"
-	"Floating stack space:%7ld %s\n"
-	"Return stack space:  %7ld %s\n",
-           	/* the C language returns n as n*sizeof==bytes */
+	     "Stack space:         %7ld %s\n"
+	     "Floating stack space:%7ld %s\n"
+	     "Return stack space:  %7ld %s\n",
+	     /* the C language returns n as n*sizeof==bytes */
 	     (long) (PFE.dictlimit - PFE.dict),
 	     (long) (PFE.dp - PFE.dict), 
 	     (long) (PFE.s0 - PFE.stack),  /* sizeof (p4cell) */
@@ -604,9 +622,9 @@ FCode (p4_dot_memory)
  */
 FCode (p4_dot_status)
 {
-# ifndef PFE_MODULE_DIR
-# define PFE_MODULE_DIR PFE_PKGLIBDIR
-# endif
+#  ifndef PFE_MODULE_DIR
+#  define PFE_MODULE_DIR PFE_PKGLIBDIR
+#  endif
 
     FX (p4_cr);
     FX (p4_dot_version);
@@ -615,59 +633,59 @@ FCode (p4_dot_status)
     FX (p4_cr);
     p4_outf ("\nMemory overview:");
     FX (p4_dot_memory);
-    p4_outf ("\nsearch path for source files:     %s", P4_opt.incpaths);
-    p4_outf ("\nextensions for source files:      %s", P4_opt.incext);
-    p4_outf ("\nsearch path for block files:      %s", P4_opt.blkpaths);
-    p4_outf ("\nextensions for block files:       %s", P4_opt.blkext);
+    p4_outf ("\nsearch path for source files:     %s", *P4_opt.inc_paths);
+    p4_outf ("\nextensions for source files:      %s", *P4_opt.inc_ext);
+    p4_outf ("\nsearch path for block files:      %s", *P4_opt.blk_paths);
+    p4_outf ("\nextensions for block files:       %s", *P4_opt.blk_ext);
     p4_outf ("\nsearching help files in:          %s", PFE_PKGHELPDIR);
     p4_outf ("\nsearching pfe shared modules in:  %s", PFE_MODULE_DIR);
     FX (p4_cr);
-    p4_outf ("\nmaximum number of open files:     %u", P4_opt.max_files);
-    p4_outf ("\nmaximum simultaneous S\" pockets   %u", P4_opt.pockets);
+/*  p4_outf ("\nmaximum number of open files:     %u", P4_opt.max_files); */
+/*  p4_outf ("\nmaximum simultaneous S\" pockets   %u", P4_opt.pockets);  */
     p4_outf ("\ndictionary threads configured     %u", 1<<LD_THREADS);
     p4_outf ("\nmaximum wordlists in search order %u", P4_opt.wordlists);
     FX (p4_cr);
     p4_outf ("\nText screen size:                 %dx%d", PFE.rows, PFE.cols);
 
-#define flag(X) ((X) ? "ON " : "OFF")
+#  define flag(X) ((X) ? "ON " : "OFF")
     p4_outf ("\n      CASELESS %s", flag (LOWER_CASE));
     p4_outf ("\nUPPER-CASE-IS  %s", flag (UPPER_CASE));
-#ifdef P4_REGTH
+#  ifdef P4_REGTH
     p4_outs ("           REGTH="P4_REGTH);
-#elif defined PFE_WITH_STATIC_REGS
+#  elif defined PFE_WITH_STATIC_REGS
     p4_outs ("           (static regVM)");
-#else
+#  else
     p4_outs ("           (static regTH)");
-#endif
+#  endif
     p4_outf ("\nLOWER-CASE-FN  %s", flag (LOWER_CASE_FN));
-#ifdef P4_REGSP
+#  ifdef P4_REGSP
     p4_outs ("           REGSP="P4_REGSP);
-#endif
+#  endif
     p4_outf ("\nRESET-ORDER-IS %s", flag (RESET_ORDER));
-#ifdef P4_REGIP
+#  ifdef P4_REGIP
     p4_outs ("           REGIP="P4_REGIP);
-#elif defined PFE_SBR_CALL_ARG_THREADING
+#  elif defined PFE_SBR_CALL_ARG_THREADING
     p4_outs ("           (sbr-call-arg-threading)");
-#elif defined PFE_SBR_CALL_THREADING
+#  elif defined PFE_SBR_CALL_THREADING
     p4_outs ("           (sbr-call-threading)");
-#endif
+#  endif
     p4_outf ("\nREDEFINED-MSG  %s", flag (REDEFINED_MSG));
-#ifdef P4_REGRP
+#  ifdef P4_REGRP
     p4_outs ("           REGRP="P4_REGRP);
-#endif
+#  endif
     p4_outf ("\nFLOAT-INPUT    %s", flag (FLOAT_INPUT));
-#ifdef P4_REGLP
+#  ifdef P4_REGLP
     p4_outs ("           REGLP="P4_REGLP);
-#elif defined PFE_REGFP
+#  elif defined PFE_REGFP
     p4_outs ("           REGFP="P4_REGFP);
-#endif
-#undef flag
+#  endif
+#  undef flag
     p4_outf ("\nPRECISION      %d", PRECISION);
-#ifdef P4_REGW
+#  ifdef P4_REGW
     p4_outs ("            REGW="P4_REGW);
-#elif defined PFE_CALL_THREADING && !defined PFE_SBR_CALL_THREADING
+#  elif defined PFE_CALL_THREADING && !defined PFE_SBR_CALL_THREADING
     p4_outs ("            (call-threading)");
-#endif
+#  endif
     FX (p4_space);
 }
 
@@ -767,11 +785,17 @@ FCode (p4_standard_io)
     static const p4Word paren_expect_w = { "", PFX (p4_paren_expect) };
     static const p4Word paren_key_w =    { "", PFX (p4_paren_key) };
     static const p4Word paren_type_w =   { "", PFX (p4_paren_type) };
-
+#  ifndef __GNUC__
     static const p4Word* paren_emit_xt =   & paren_emit_w;
     static const p4Word* paren_expect_xt = & paren_expect_w;
     static const p4Word* paren_key_xt =    & paren_key_w;
     static const p4Word* paren_type_xt =   & paren_type_w;
+#  else /* the gcc can grok this: */
+    static p4_ExecToken paren_emit_xt =   { .word = (p4Word*) & paren_emit_w };
+    static p4_ExecToken paren_expect_xt = { .word = (p4Word*) &paren_expect_w};
+    static p4_ExecToken paren_key_xt =    { .word = (p4Word*) & paren_key_w };
+    static p4_ExecToken paren_type_xt =   { .word = (p4Word*) & paren_type_w };
+#  endif
 
     PFE.emit =   &paren_emit_xt;
     PFE.expect = &paren_expect_xt;
@@ -794,28 +818,37 @@ FCode (p4_standard_io)
 /* Function keys on the commandline                                     */
 /************************************************************************/
 
-void
-accept_executes_xt (int n)
+static void
+p4_fkey_call_execution (int n)
 {
     if (PFE.fkey_xt[n])
         p4_call (PFE.fkey_xt[n]);
 }
 
 static void
-p4_store_execution (p4xt xt, int key)
+p4_fkey_store_execution (p4xt xt, int key)
 {
     if (key < P4_KEY_k1 || P4_KEY_k0 < key)
         p4_throw (P4_ON_ARG_TYPE);
     PFE.fkey_xt[key - P4_KEY_k1] = xt;
 }
 
+/*data*/ void (*p4_fkey_default_executes[10]) (int) =
+{
+    p4_fkey_call_execution, p4_fkey_call_execution, 
+    p4_fkey_call_execution, p4_fkey_call_execution, 
+    p4_fkey_call_execution, p4_fkey_call_execution,
+    p4_fkey_call_execution, p4_fkey_call_execution, 
+    p4_fkey_call_execution, p4_fkey_call_execution,
+};
+
 /** ((EXECUTES)) ( n -- )
  * compiled by => EXECUTES
  */
 FCode_XE (p4_executes_execution)
 {
     FX_USE_CODE_ADDR;
-    p4_store_execution ((p4xt)(*IP++), *SP++);
+    p4_fkey_store_execution ((p4xt)(*IP++), *SP++);
     FX_USE_CODE_EXIT;
 }
 
@@ -830,7 +863,7 @@ FCode (p4_executes)
         FX_COMPILE (p4_executes);
         FX (p4_bracket_compile);
     }else{
-        p4_store_execution (p4_tick_cfa (FX_VOID), FX_POP);
+        p4_fkey_store_execution (p4_tick_cfa (FX_VOID), FX_POP);
     }
 }
 P4COMPILES (p4_executes, p4_executes_execution,
@@ -885,8 +918,8 @@ FCode (p4_edit_blockfile)
     p4_word_parseword (' '); *DP=0; /* PARSE-WORD-NOHERE */
     if (! PFE.word.len) { return; }
 
-    wordpad = p4_pocket_expanded_filename (PFE.word.ptr, PFE.word.len,
-					   PFE_set.blkpaths, PFE_set.blkext);
+    wordpad = p4_pocket_expanded_filename (
+        PFE.word.ptr, PFE.word.len, *PFE_set.blk_paths, *PFE_set.blk_ext);
     {
 	extern void* p4_loadm_once (const p4char* nm, int l);
 	register p4char* name;
@@ -938,8 +971,8 @@ FCode (p4_expand_fn)
     int len = SP[1];
     char* buf;
 
-    buf = p4_pocket_expanded_filename (nm, len, 
-				       P4_opt.incpaths, P4_opt.incext);
+    buf = p4_pocket_expanded_filename (
+        nm, len, *P4_opt.inc_paths, *P4_opt.inc_ext);
     strcpy (fn, buf);
     SP++;
     SP[1] = (p4cell) fn;
@@ -1348,7 +1381,7 @@ P4_LISTWORDS (misc) =
     P4_FXco ("ACCESS-ARRAY",	p4_access_array),
 
     P4_FXco (".STATUS",		p4_dot_status),
-    P4_FNYM ("SHOW-STATUS",	".STATUS"),
+    P4_xOLD ("SHOW-STATUS",	".STATUS"),
 
     /* NOTE: the newer "TO"-implementation is able to set DVaLs */
     P4_DVaL ("UPPER-CASE?",	wordl_flag), /* will be bool-VaL */
@@ -1364,7 +1397,7 @@ P4_LISTWORDS (misc) =
     P4_FXco ("TH'POCKET",	p4_th_pocket),
     P4_FXco ("POCKET-PAD",	p4_pocket_pad),
     P4_OCoN ("/CELL",		sizeof (p4cell)),
-    P4_FNYM ("WSIZE",		"/CELL"),
+    P4_xOLD ("WSIZE",		"/CELL"),
     P4_FXco ("W@",		p4_w_fetch),
     P4_FXco ("W!",		p4_w_store),
     P4_FXco ("W+!",		p4_w_plus_store),
@@ -1449,7 +1482,7 @@ P4_LISTWORDS (misc) =
     P4_INTO ("ENVIRONMENT", 0 ),
     P4_OCoN ("RAND_MAX",	RAND_MAX),
 };
-P4_COUNTWORDS (misc, "Misc.Compatibility words");
+P4_COUNTWORDS (misc, "Compatibility Miscellaneous words");
 
 /*@}*/
 /* 
