@@ -1,8 +1,8 @@
 #ifndef _PFE_POSIX_EXT_H
-#define _PFE_POSIX_EXT_H 1002653677
-/* generated 2001-1009-2054 ../../../pfe/../mk/Make-H.pl ../../../pfe/posix-ext.c */
+#define _PFE_POSIX_EXT_H 1063198931
+/* generated 2003-0910-1502 ../../../pfe/../mk/Make-H.pl ../../../pfe/posix-ext.c */
 
-#include <pfe/incl-ext.h>
+#include <pfe/pfe-ext.h>
 
 /** 
  * -- Words making sense in POSIX-like systems only.
@@ -11,8 +11,8 @@
  *
  *  @see     GNU LGPL
  *  @author  Tektronix CTE                %derived_by: guidod %
- *  @version %version: 5.19 %
- *    (%date_modified: Tue Jul 31 13:27:33 2001 %)
+ *  @version %version: bln_mpt1!5.23 %
+ *    (%date_modified: Mon Feb 24 20:15:33 2003 %)
  *
  *  @description
  *              This file exports a set of system words for 
@@ -34,6 +34,22 @@ extern "C" {
  */
 extern P4_CODE (p4_ignore_line);
 
+/** NTOHS ( w -- w' )
+ * if current host-encoding is bigendian, this is a NOOP
+ * otherwise byteswap the lower 16-bit bits of the topofstack.
+ * see =>'W@' and =>'W!'
+ * (on some platforms, the upper bits are erased, on others not)
+ */
+extern P4_CODE (p4_ntohs);
+
+/** NTOHL ( l -- l' )
+ * if current host-encoding is bigendian, this is a NOOP
+ * otherwise byteswap the lower 32-bit bits of the topofstack.
+ * see =>'L@' and =>'L!' (being usually just =>'@' and =>'!' )
+ * (on some platforms, the upper bits are erased, on others not)
+ */
+extern P4_CODE (p4_ntohl);
+
 /** 
  * helper function - both arg pointers MUST be given
  */
