@@ -5,8 +5,8 @@
  *
  *  @see     GNU LGPL
  *  @author  Tektronix CTE             @(#) %derived_by: guidod %
- *  @version %version: bln_mpt1!5.14 %
- *    (%date_modified: Mon Mar 25 14:27:20 2002 %)
+ *  @version %version: bln_mpt1!33.15 %
+ *    (%date_modified: Wed Mar 19 16:30:51 2003 %)
  *
  *  @description
  *    	The Search Order Word Set as defined by the Standard.
@@ -20,7 +20,7 @@
 /*@{*/
 #if defined(__version_control__) && defined(__GNUC__)
 static char* id __attribute__((unused)) = 
-"@(#) $Id: %full_filespec: search-order-ext.c~bln_mpt1!5.14:csrc:bln_12xx!1 % $";
+"@(#) $Id: %full_filespec: search-order-ext.c~bln_mpt1!33.15:csrc:bln_12xx!1 % $";
 #endif
 
 #define _P4_SOURCE 1
@@ -81,7 +81,7 @@ FCode (p4_search_wordlist)
         SP[0] = 0;
     }else{
         SP += 1;
-        SP[0] = *_FFA(nfa) & P4xIMMEDIATE ? 1 : -1;
+        SP[0] = P4_NFA_xIMMEDIATE(nfa) ? P4_POSITIVE : P4_NEGATIVE;
         SP[1] = (p4cell) p4_name_from (nfa);
     }
 }
