@@ -5,8 +5,8 @@
  *
  *  @see     GNU LGPL
  *  @author  Tektronix CTE         @(#) %derived_by: guidod %
- *  @version %version: bln_mpt1!5.27 %
- *    (%date_modified: Mon Apr 08 18:28:49 2002 %)
+ *  @version %version: bln_mpt1!5.30 %
+ *    (%date_modified: Mon Feb 03 11:57:09 2003 %)
  *
  *  @description
  *        These builtin words are modelled after common shell commands,
@@ -16,7 +16,7 @@
 /*@{*/
 #if defined(__version_control__) && defined(__GNUC__)
 static char * id __attribute__((unused)) = 
-"@(#) $Id: %full_filespec:  shell-os-ext.c~bln_mpt1!5.27:csrc:bln_12xx!1 % $";
+"@(#) $Id: %full_filespec:  shell-os-ext.c~bln_mpt1!5.30:csrc:bln_12xx!1 % $";
 #endif
                   
 #define _P4_SOURCE 1
@@ -337,7 +337,7 @@ touch (const char *s)
     int result;
 
 #ifdef PFE_HAVE_ACCESS
-    if (access (s, F_OK) == 0)
+    if (_P4_access (s, F_OK) == 0)
         return utime (s, NULL);
 #endif
     result = open (s, O_WRONLY | O_CREAT, RWALL);
@@ -350,7 +350,7 @@ touch (const char *s)
 static int
 cp (const char *src, const char *dst)
 {
-    return fn_copy (src, dst, LONG_MAX) == -1;
+    return p4_file_copy (src, dst, P4_OFF_T_MAX) == -1;
 }
 
 #ifndef NO_SYSTEM
@@ -496,7 +496,6 @@ P4_LISTWORDS (shell) =
     P4_INTO ("EXTENSIONS", 0),
 #ifdef PFE_HAVE_PID
     P4_FXco ("$PID",		p4_getpid),
-    P4_xOLD ("$$",		"$PID"),
 #endif
 #ifdef PFE_HAVE_UID
     P4_FXco ("$UID",		p4_getuid),
@@ -516,7 +515,6 @@ P4_LISTWORDS (shell) =
     P4_SXco ("RM",		p4_remove),
     P4_SXco ("TOUCH",		p4_touch),
     P4_FXco ("CHDIR",		p4_chdir),
-    P4_xOLD ("CD",		"CHDIR"),
     P4_SXco ("RMDIR",		p4_rmdir),
     P4_SXco ("MKDIR",		p4_md),
 #ifdef PFE_HAVE_LINK
