@@ -5,7 +5,7 @@
  *
  *  @see     GNU LGPL
  *  @author  Tektronix CTE            @(#) %derived_by: guidod %
- *  @version %version: bln_mpt1!5.21 %
+ *  @version %version: bln_mpt1!33.24 %
  *    (%date_modified: Tue Jun 04 13:19:30 2002 %)
  *
  *  @description
@@ -104,6 +104,16 @@ typedef struct			/* all we need to know about a signal */
     p4xt hdl;			/* a forth word to handle the signal */
 } Siginfo;
 
+/**
+ * on a lot of platforms, you will see warning messages like
+ * "function declaration is not a prototype". This is due to a change
+ * in semantics for C99: <sys/signal.h> contains a declaration like
+ *   #define SIG_DFL (void(*)())0
+ * but that is wrong in the world of -fstrict-prototype where it should read
+ *   #define SIG_DFL (void(*)(void))0
+ * so actually, this can not be helped. You have to live with these warning
+ * messages.
+ */
 #ifdef PFE_OLD_STRINGIZE
 # ifdef PFE_HAVE_SYS_SIGLIST
 # define SIG(NM,CL,MSG)		{ NM, CL, "NM", SIG_DFL }
@@ -493,6 +503,10 @@ p4_install_signal_handlers (void)
 	}
      cont:;
     }
+
+    if (PFE_set.stdio) 
+        return;
+    /* else */
 #ifdef SIGTSTP
     if (signal (SIGTSTP, SIG_IGN) == SIG_DFL)
     {
