@@ -5,8 +5,8 @@
  *
  *  @see     GNU LGPL
  *  @author  Tektronix CTE              @(#) %derived_by: guidod %
- *  @version %version:  1.14 %
- *    (%date_modified:  Tue Aug 13 12:50:19 2002 %)
+ *  @version %version:  32.15 %
+ *    (%date_modified:  Wed Mar 19 15:38:17 2003 %)
  *
  *  @description
  *      Smart Outer Interpreter allows to register executions tokens
@@ -17,7 +17,7 @@
 /*@{*/
 #if defined(__version_control__) && defined(__GNUC__)
 static char* id __attribute__((unused)) = 
-"@(#) $Id: %full_filespec:   smart-go-ext.c~1.14:csrc:bln_mpt1!1 % $";
+"@(#) $Id: %full_filespec:   smart-go-ext.c~32.15:csrc:bln_mpt1!1 % $";
 #endif
 
 #define _P4_SOURCE 1
@@ -35,7 +35,7 @@ _p4_smart_interpret_char (char c)
     
     wd[sizeof(wd)-2] = c;
     nfa = p4_find (wd, sizeof(wd)-1);
-    if (!nfa || !(*_FFA(nfa)|P4xIMMEDIATE)) 
+    if (! nfa || ! P4_NFA_xIMMEDIATE(nfa))
 	return 0; /* must be immediate */
     xt = p4_name_from (nfa);
     if (P4_XT_VALUE(xt) != FX_GET_RT (p4_defer))
@@ -66,7 +66,7 @@ _p4_smart_interpret_init (char c, char const * nm, int l)
     
     wd[sizeof(wd)-2] = c;
     if (! (nfa = p4_find (nm, l))) return 0;
-    if (! (*NFA2FF(nfa)|P4xIMMEDIATE)) return 0;
+    if (! (P4_NFA_xIMMEDIATE(nfa))) return 0;
 
     p4_header_comma (wd, sizeof(wd)-1, CURRENT); FX_IMMEDIATE;
     FX_RUNTIME1 (p4_defer);
