@@ -1,10 +1,10 @@
 /** 
  * -- Terminal Driver for K12xx-2 Emulation System
  *
- *  Copyright (C) Tektronix, Inc. 1998 - 2001. All rights reserved.
+ *  Copyright (C) Tektronix, Inc. 1998 - 2003. All rights reserved.
  *
  *  @author Tektronix CTE             @(#)  %derived_by: guidod %
- *  @version %version: bln_mpt1!5.30 %
+ *  @version %version: bln_mpt1!33.32 %
  *    (%date_modified: Wed Aug 28 09:57:32 2002 %)
  *
  *  @description
@@ -18,11 +18,11 @@
 /*@{*/
 #if defined(__version_control__) && defined(__GNUC__)
 static char* id __attribute__((unused)) = 
-"@(#) $Id: %full_filespec: term-k12.c~bln_mpt1!5.30:csrc:bln_12xx!2 % $ ";
+"@(#) $Id: %full_filespec: term-k12.c~bln_mpt1!33.32:csrc:bln_12xx!2 % $ ";
 #endif
 
 #define _P4_SOURCE 1
-#include <pfe/incl-sub.h>
+#include <pfe/pfe-sub.h>
 #include <pfe/term-sub.h>
 
 #include <ctype.h>
@@ -31,7 +31,7 @@ static char* id __attribute__((unused)) =
 #include <unistd.h>
 
 #include <pfe/option-ext.h>
-#include <pfe/incl-sup.h>
+#include <pfe/pfe-sup.h>
 
 #if HAVE_TQLIB_H
 #include <tqlib.h>
@@ -104,7 +104,8 @@ static void c_tput (int);
 
 
 
-int logPrintf(void *pEmul, char *fmt, ...)
+static int 
+logPrintf(void *pEmul, char *fmt, ...)
 {
     va_list argptr;
     int ret;
@@ -121,7 +122,8 @@ int logPrintf(void *pEmul, char *fmt, ...)
 static char hexdigit[] = "0123456789ABCDEF";
 
 #define LOGSTRING_BUFFER 600
-void k12LogString (int mask, char* hail, char* p, int size)
+static void 
+k12LogString (int mask, char* hail, char* p, int size)
 {
     int  i, j=0;
     char v[LOGSTRING_BUFFER]; 
@@ -163,7 +165,7 @@ void k12LogString (int mask, char* hail, char* p, int size)
     
 }  
 
-k12_status_t
+static k12_status_t
 write_link (k12_emu_type_t* emu, k12_emu_event_t link, int type,
             s8_t* buf, u32_t n)
 {
@@ -265,7 +267,7 @@ p4_TX_task (k12_priv* p)
 
 /* ************************************************ */
 
-char const *
+static char const *
 term_k12_rawkey_string [P4_NUM_KEYS]  = /* what function keys send */
 {
     /* Terminal Application sends VT100 key sequences (hopefully) */
@@ -282,7 +284,8 @@ term_k12_rawkey_string [P4_NUM_KEYS]  = /* what function keys send */
     NULL,       NULL,       NULL,       NULL, 
 };
 
-static char const *term_k12_control_string[] = /* vt100 sequences. */
+static char const *
+term_k12_control_string[] = /* vt100 sequences. */
 {
     "\033[%d;%dH",                /* cm - cursor move */
     "\033[H",                     /* ho - home position */
