@@ -1,13 +1,13 @@
 #ifndef __PFE_TERM_K12_H__
-#define __PFE_TERM_K12_H__ "%full_filespec: term-k12.h~bln_mpt1!5.11:incl:bln_12xx!3 %"
+#define __PFE_TERM_K12_H__ "%full_filespec: term-k12.h~bln_mpt1!5.12:incl:bln_12xx!3 %"
 /**
  *
  *  Copyright (C) Tektronix, Inc. 1998 - 2000. All rights reserved.
  *
- *  @(#)                            RCS: %filespec: term-k12.h~bln_mpt1!5.11 %
+ *  @(#)                            RCS: %filespec: term-k12.h~bln_mpt1!5.12 %
  *  @author Tektronix CTE                %derived_by: guidod %
- *  @version %version: bln_mpt1!5.11 %
- *    (%date_modified: Tue Aug 27 17:20:35 2002 %)
+ *  @version %version: bln_mpt1!5.12 %
+ *    (%date_modified: Tue Mar 18 15:23:08 2003 %)
  *
  *  @description
  *        The structure of the K12XX Terminal Driver is sometimes
@@ -61,12 +61,12 @@ struct k12_priv
     unsigned char    frm_putback;
     
     unsigned char bufidx;
-    char          buffer[256];
+    unsigned char buffer[256];
     int nxch;
     
     unsigned char answering;
     unsigned char answeridx;
-    char          answerbuf[K12_ANSWERBUF_SIZE];
+    unsigned char answerbuf[K12_ANSWERBUF_SIZE];
     
     int row, col; /* position of cursor as tracked */
     
