@@ -5,8 +5,8 @@
  *
  *  @see     GNU LGPL
  *  @author  Tektronix CTE              @(#) %derived_by: guidod %
- *  @version %version: bln_mpt1!5.16 %
- *    (%date_modified: Tue Sep 10 12:31:47 2002 %)
+ *  @version %version: bln_mpt1!33.22 %
+ *    (%date_modified: Wed Mar 19 16:53:56 2003 %)
  *
  *  @description
  *                      Terminal driver for UNIX-like systems using
@@ -19,7 +19,7 @@
 /*@{*/
 #if defined(__version_control__) && defined(__GNUC__)
 static char* id __attribute__((unused)) = 
-"@(#) $Id: %full_filespec:  term-lib.c~bln_mpt1!5.16:csrc:bln_12xx!1 % $";
+"@(#) $Id: %full_filespec:  term-lib.c~bln_mpt1!33.22:csrc:bln_12xx!1 % $";
 #endif
 
 #define _P4_SOURCE 1
@@ -42,6 +42,16 @@ static char* id __attribute__((unused)) =
 #include <pfe/_nonansi.h>
 #include <pfe/_missing.h>
 
+/* sun manpages say "int putchar(int)" but their tputs is not quite like it
+ * with being int "tputs(char *str, int affcnt, int (*putc)(char));". The
+ * linux and hpux manges use "...., int affcnt, int (*putc)(int)));" instead.
+ */
+# if defined unix && defined sun
+# define t_putchar_ ((int (*)(char)) t_putchar)
+# else
+# define t_putchar_ t_putchar
+# endif
+
 #if ! defined PFE_HAVE_FCNTL && defined F_GETFL && defined F_SETFL
 #define PFE_HAVE_FCNTL 1 /* should have been done by configure... */
 #endif
@@ -71,6 +81,8 @@ int P4_fcntl_F_SETFL(int fd, int arg)
 }
 #endif
 
+/* ...................................................................... */
+
 /*-
  * Table of contents
  *
@@ -225,26 +237,26 @@ c_interrupt_key (char ch)
  * it somewhere else than ^U, just #define this to nothing in term.h.
  */
 {
-  struct termios tty;
-  int old;
+    struct termios tty;
+    int old;
 
-  if (!isatty (0))
-    return -1;
-  if (tcgetattr (STDIN_FILENO, &tty) != 0)
-    return -1;
-  old = tty.c_cc[VINTR];
-  if (ch)
+    if (!isatty (0))
+	return -1;
+    if (tcgetattr (STDIN_FILENO, &tty) != 0)
+	return -1;
+    old = tty.c_cc[VINTR];
+    if (ch)
     {
-      tty.c_iflag |= BRKINT;
-      tty.c_cc[VINTR] = 0xFF;
+	tty.c_iflag |= BRKINT;
+	tty.c_cc[VINTR] = 0xFF;
     }
-  else
+    else
     {
-      tty.c_iflag &= ~BRKINT;
-      tty.c_cc[VINTR] = ch;
+	tty.c_iflag &= ~BRKINT;
+	tty.c_cc[VINTR] = ch;
     }
-  tcsetattr (0, TCSAFLUSH, &tty);
-  return old;
+    tcsetattr (0, TCSAFLUSH, &tty);
+    return old;
 }
 
 #define	C_IFLAGS_OFF	(ICRNL | IGNBRK | IGNCR | INLCR | \
@@ -272,24 +284,24 @@ c_interrupt_key (char ch)
 static void
 tty_interactive (void)
 {
-  /* struct termios tty = tty_system; */
-  struct termios tty; memcpy(&tty, &tty_system, sizeof(tty));
+    /* struct termios tty = tty_system; */
+    struct termios tty; memcpy(&tty, &tty_system, sizeof(tty));
 
-  if (! isatty (STDIN_FILENO)) return;
+    if (! isatty (STDIN_FILENO)) return;
 
-  tty.c_iflag &= ~C_IFLAGS_OFF, tty.c_iflag |= C_IFLAGS_ON;
-  tty.c_oflag &= ~C_OFLAGS_OFF, tty.c_oflag |= C_OFLAGS_ON;
-  tty.c_lflag &= ~C_LFLAGS_OFF, tty.c_lflag |= C_LFLAGS_ON;
-  tty.c_cc[VMIN] = 1;
-  tty.c_cc[VTIME] = 0;
-  tty.c_cc[VINTR] = INTR_KEY;
-  tty.c_cc[VQUIT] = QUIT_KEY;
-#if defined PFE_HAVE_TERMIOS_H
-  tty.c_cc[VSUSP] = SUSP_KEY;
-  tty.c_cc[VSTART] = '\xFF';
-  tty.c_cc[VSTOP] = '\xFF';
-#endif
-  tcsetattr (STDIN_FILENO, TCSAFLUSH, &tty);
+    tty.c_iflag &= ~C_IFLAGS_OFF, tty.c_iflag |= C_IFLAGS_ON;
+    tty.c_oflag &= ~C_OFLAGS_OFF, tty.c_oflag |= C_OFLAGS_ON;
+    tty.c_lflag &= ~C_LFLAGS_OFF, tty.c_lflag |= C_LFLAGS_ON;
+    tty.c_cc[VMIN] = 1;
+    tty.c_cc[VTIME] = 0;
+    tty.c_cc[VINTR] = INTR_KEY;
+    tty.c_cc[VQUIT] = QUIT_KEY;
+#  if defined PFE_HAVE_TERMIOS_H
+    tty.c_cc[VSUSP] = SUSP_KEY;
+    tty.c_cc[VSTART] = '\xFF';
+    tty.c_cc[VSTOP] = '\xFF';
+#  endif
+    tcsetattr (STDIN_FILENO, TCSAFLUSH, &tty);
 }
 
 #elif defined PFE_HAVE_SGTTY_H
@@ -302,9 +314,9 @@ tty_interactive (void)
 
 static struct
 {
-  struct sgttyb sg;
-  struct tchars tc;
-  int lc;			/* local mode word */
+    struct sgttyb sg;
+    struct tchars tc;
+    int lc;			/* local mode word */
 }
 tty_system;
 
@@ -328,17 +340,17 @@ c_interrupt_key (char ch)
  * it somewhere else than ^U, just #define this to nothing in term.h.
  */
 {
-  struct tchars tc;
-  int old;
+    struct tchars tc;
+    int old;
 
-  if (!isatty (0))
-    return -1;
-  if (ioctl (STDIN_FILENO, TIOCGETC, &tc) != 0)
-    return -1;
-  old = tc.t_intrc;
-  tc.t_intrc = ch == 0 ? -1 : ch;
-  ioctl (STDIN_FILENO, TIOCSETC, &tc);
-  return old == -1 ? 0 : old;
+    if (!isatty (0))
+	return -1;
+    if (ioctl (STDIN_FILENO, TIOCGETC, &tc) != 0)
+	return -1;
+    old = tc.t_intrc;
+    tc.t_intrc = ch == 0 ? -1 : ch;
+    ioctl (STDIN_FILENO, TIOCSETC, &tc);
+    return old == -1 ? 0 : old;
 }
 
 #define	C_FLAGS_OFF	(LCASE | ECHO | RAW)
@@ -348,22 +360,22 @@ c_interrupt_key (char ch)
 static void
 tty_interactive (void)
 {
-  struct sgttyb sg = tty_system.sg;
-  struct tchars tc = tty_system.tc;
-  int flags;
+    struct sgttyb sg = tty_system.sg;
+    struct tchars tc = tty_system.tc;
+    int flags;
 
-  if (! isatty (STDIN_FILENO)) return;
-
-  sg.sg_flags &= ~C_FLAGS_OFF;
-  sg.sg_flags |=  C_FLAGS_ON;
-  tc.t_intrc = INTR_KEY;
-  tc.t_quitc = QUIT_KEY;
-  tc.t_startc = -1;
-  tc.t_stopc = -1;
-  ioctl (STDIN_FILENO, TIOCSETP, &sg);
-  ioctl (STDIN_FILENO, TIOCSETC, &tc);
-  flags = L_FLAGS_ON;
-  ioctl (STDIN_FILENO, TIOCLBIS, &flags);
+    if (! isatty (STDIN_FILENO)) return;
+    
+    sg.sg_flags &= ~C_FLAGS_OFF;
+    sg.sg_flags |=  C_FLAGS_ON;
+    tc.t_intrc = INTR_KEY;
+    tc.t_quitc = QUIT_KEY;
+    tc.t_startc = -1;
+    tc.t_stopc = -1;
+    ioctl (STDIN_FILENO, TIOCSETP, &sg);
+    ioctl (STDIN_FILENO, TIOCSETC, &tc);
+    flags = L_FLAGS_ON;
+    ioctl (STDIN_FILENO, TIOCLBIS, &flags);
 }
 
 #else
@@ -381,14 +393,14 @@ static int tty_system = 0; /* not reentrant */
 static int
 c_interrupt_key (char ch)
 {
-  return 0;
+    return 0;
 }
 
 static void
 tty_interactive (void)
 {
-  ioctl (0, FIOSETOPTIONS, ioctl (0, FIOGETOPTIONS, 0) & ~OPT_LINE);
-  ioctl (0, FIOSETOPTIONS, ioctl (0, FIOGETOPTIONS, 0) & ~OPT_ECHO);
+    ioctl (0, FIOSETOPTIONS, ioctl (0, FIOGETOPTIONS, 0) & ~OPT_LINE);
+    ioctl (0, FIOSETOPTIONS, ioctl (0, FIOGETOPTIONS, 0) & ~OPT_ECHO);
 }
 
 #else /* VxWorks */
@@ -444,30 +456,30 @@ tty_interactive (void)
  */
 enum
 {
-  cursor_address,
-  cursor_home,
-  cursor_left,
-  cursor_right,
-  cursor_up,
-  cursor_down,
-  clear_screen,
-  clr_eos,
-  clr_eol,
-  bell,
-  delete_character,
-  delete_line,
-  scroll_forward,
-  scroll_reverse,
-  enter_standout_mode,
-  exit_standout_mode,
-  enter_underline_mode,
-  exit_underline_mode,
-  enter_bold_mode,
-  enter_reverse_mode,
-  enter_blink_mode,
-  exit_attribute_mode,
-  keypad_xmit,
-  keypad_local
+    cursor_address,
+    cursor_home,
+    cursor_left,
+    cursor_right,
+    cursor_up,
+    cursor_down,
+    clear_screen,
+    clr_eos,
+    clr_eol,
+    bell,
+    delete_character,
+    delete_line,
+    scroll_forward,
+    scroll_reverse,
+    enter_standout_mode,
+    exit_standout_mode,
+    enter_underline_mode,
+    exit_underline_mode,
+    enter_bold_mode,
+    enter_reverse_mode,
+    enter_blink_mode,
+    exit_attribute_mode,
+    keypad_xmit,
+    keypad_local
 };
 
 #endif
@@ -482,28 +494,28 @@ enum
 #ifdef USE_TERMCAP
 static char tckeycode[][3] =
 {
-  "k1", "k2", "k3", "k4", "k5",	/* keys in same order as enum keycode */
-  "k6", "k7", "k8", "k9", "k0",	/* from term.h */
-  "F1", "F2", "F3", "F4", "F5",
-  "F6", "F7", "F8", "F9", "FA",
-  "kl", "kr", "ku", "kd",	/* result is just what has to be exported */
-  "kh", "kH", "kN", "kP",	/* via variable rawkey_string */
-  "kb", "kD", "kM", "kI",
-  "kA", "kE", "kL", "kC"
+    "k1", "k2", "k3", "k4", "k5", /* keys in same order as enum keycode */
+    "k6", "k7", "k8", "k9", "k0", /* from term.h */
+    "F1", "F2", "F3", "F4", "F5",
+    "F6", "F7", "F8", "F9", "FA",
+    "kl", "kr", "ku", "kd",	/* result is just what has to be exported */
+    "kh", "kH", "kN", "kP",	/* via variable rawkey_string */
+    "kb", "kD", "kM", "kI",
+    "kA", "kE", "kL", "kC"
 };
 #endif /* USE_TERMCAP */
 
 #if defined USE_TERMCAP || defined USE_TERMINFO
 static char tcctlcode[][3] =
 {
-  "cm", "ho",
-  "le", "nd", "up", "do",
-  "cl", "cd", "ce", "bl",
-  "dc", "dl",
-  "sf", "sr",
-  "so", "se", "us", "ue",
-  "md", "mr", "mb", "me",
-  "ks", "ke"
+    "cm", "ho",
+    "le", "nd", "up", "do",
+    "cl", "cd", "ce", "bl",
+    "dc", "dl",
+    "sf", "sr",
+    "so", "se", "us", "ue",
+    "md", "mr", "mb", "me",
+    "ks", "ke"
 };
 #endif /* USE_TERMCAP || USE_TERMINFO */
 
@@ -521,13 +533,13 @@ extern char const * p4_vt100_rawkeys[];
 
 
 #define query_database() 1	/* nothing to query */
-#define t_putc(C) putchar (C)
+#define t_putchar(C) putchar (C)
 #define tputs(S,P,F) fputs (S, stdout)
 
 static void
 t_puts (int cap, int n)
 {
-  fputs (PFE.control_string[cap], stdout);
+    fputs (PFE.control_string[cap], stdout);
 }
 
 static char *
@@ -551,26 +563,26 @@ p4_term_struct p4_term_ios =
 p4_term_struct p4_term_dumbterm =
 #endif
 {
-  "dumbterm",
-  p4_dumbterm_controls,
-  p4_dumbterm_rawkeys,
-  INTO(init) 		c_prepare_terminal, 
-  INTO(fini) 		c_cleanup_terminal,
-  INTO(tput)		c_tput,
-
-  INTO(tty_interrupt_key) c_interrupt_key,
-  INTO(interactive_terminal) c_interactive_terminal,
-  INTO(system_terminal)   c_system_terminal,
-  INTO(query_winsize)     c_query_winsize,
-
-  INTO(c_keypressed)	c_keypressed,
-  INTO(c_getkey)	c_getkey,
-  INTO(c_putc_noflush)  c_putc_noflush,
-  INTO(c_put_flush)	c_put_flush,
-  INTO(c_putc)		c_putc,
-  INTO(c_puts)		c_puts,
-  INTO(c_gotoxy)	c_gotoxy,
-  INTO(c_wherexy)	c_wherexy
+    "dumbterm",
+    p4_dumbterm_controls,
+    p4_dumbterm_rawkeys,
+    INTO(init) 		c_prepare_terminal, 
+    INTO(fini) 		c_cleanup_terminal,
+    INTO(tput)		c_tput,
+    
+    INTO(tty_interrupt_key) c_interrupt_key,
+    INTO(interactive_terminal) c_interactive_terminal,
+    INTO(system_terminal)   c_system_terminal,
+    INTO(query_winsize)     c_query_winsize,
+    
+    INTO(c_keypressed)	c_keypressed,
+    INTO(c_getkey)	c_getkey,
+    INTO(c_putc_noflush)  c_putc_noflush,
+    INTO(c_put_flush)	c_put_flush,
+    INTO(c_putc)		c_putc,
+    INTO(c_puts)		c_puts,
+    INTO(c_gotoxy)	c_gotoxy,
+    INTO(c_wherexy)	c_wherexy
 
 };
 
@@ -580,26 +592,26 @@ p4_term_struct p4_term_ios =
 p4_term_struct p4_term_vt100 =
 #endif
 {
-  "vt100",
-  p4_vt100_controls,
-  p4_vt100_rawkeys,
-  INTO(init) 		c_prepare_terminal, 
-  INTO(fini) 		c_cleanup_terminal,
-  INTO(tput)		c_tput,
-
-  INTO(tty_interrupt_key) c_interrupt_key,
-  INTO(interactive_terminal) c_interactive_terminal,
-  INTO(system_terminal)   c_system_terminal,
-  INTO(query_winsize)     c_query_winsize,
-
-  INTO(c_keypressed)	c_keypressed,
-  INTO(c_getkey)	c_getkey,
-  INTO(c_putc_noflush)  c_putc_noflush,
-  INTO(c_put_flush)	c_put_flush,
-  INTO(c_putc)		c_putc,
-  INTO(c_puts)		c_puts,
-  INTO(c_gotoxy)	c_gotoxy,
-  INTO(c_wherexy)	c_wherexy
+    "vt100",
+    p4_vt100_controls,
+    p4_vt100_rawkeys,
+    INTO(init)			c_prepare_terminal, 
+    INTO(fini)			c_cleanup_terminal,
+    INTO(tput)			c_tput,
+    
+    INTO(tty_interrupt_key)	c_interrupt_key,
+    INTO(interactive_terminal)	c_interactive_terminal,
+    INTO(system_terminal)	c_system_terminal,
+    INTO(query_winsize)		c_query_winsize,
+    
+    INTO(c_keypressed)		c_keypressed,
+    INTO(c_getkey)		c_getkey,
+    INTO(c_putc_noflush)	c_putc_noflush,
+    INTO(c_put_flush)		c_put_flush,
+    INTO(c_putc)		c_putc,
+    INTO(c_puts)		c_puts,
+    INTO(c_gotoxy)		c_gotoxy,
+    INTO(c_wherexy)		c_wherexy
 
 };
 
@@ -620,100 +632,109 @@ p4_term_struct p4_term_vt100 =
 extern "C"
 {
 #endif
-  int tgetent (char *, char *);
-  int tgetnum (char *);
-  int tgetflag (char *);
-  char *tgetstr (char *, char **);
-  int tputs (char *, int, int (*)(int));
-  char *tgoto (char *, int, int);
+    int tgetent (char *, char *);
+    int tgetnum (char *);
+    int tgetflag (char *);
+    char *tgetstr (char *, char **);
+    int tputs (char *, int, int (*)(int));
+    char *tgoto (char *, int, int);
 #ifdef __cplusplus
 }
 #endif
 
 #endif
 
+/* The termcap function have been invented before "const" came into
+ * usage. Almost no system declares them with "const char*" in places
+ * where they are apropriate. Since PFE is usually compiled with
+ * non-writable strings, this gives us a series of warnings we do
+ * not really want to see. Hence, here we re-#define them sending
+ * the const string literals as plain "char*" to the real functions.
+ */
+#define _tgetstr(A,B) tgetstr((char*)(A),(B))
+#define _tgetnum(A)   tgetnum((char*)(A))
+
 #define __using_termcap 1
 
 static char const * termcap_control_string[DIM (tcctlcode)];
 static char const * termcap_rawkey_string[P4_NUM_KEYS];
 
-static int
-query_database (void)
 /*
  * Get the strings needed out of termcap/terminfo.
- * Store them for later use in control_string[] and rawkey_string[].
  */
+static int
+query_database (void)
 {
-  char *ttype = getenv ("TERM");
-  char tcent[2048];
-  static char tcbuf[2048];
-  static char erase[] = "\b";
-  char *tctop = tcbuf;
-  int i;
-
-  if (ttype == NULL || tgetent (tcent, ttype) <= 0)
-    return 0;
+    char *ttype = getenv ("TERM");
+    char tcent[2048];
+    static char tcbuf[2048];
+    static char erase[] = "\b";
+    char *tctop = tcbuf;
+    int i;
     
-  PFE.term->name = ttype;
+    if (ttype == NULL || tgetent (tcent, ttype) <= 0)
+	return 0;
+    
+    PFE.term->name = ttype;
 
-#ifdef PFE_HAVE_TERMCAP_H
-  {
-    char *pc = tgetstr ("pc", &tctop);
-    if (pc != NULL)
-      PC = *pc;
-    else
-      PC = 0;
-  }
-#endif
-
-  PFE.rows = tgetnum ("li");
-  PFE.cols = tgetnum ("co");
-
-  /* Read all termcap strings we need, */
-  for (i = 0; i < P4_NUM_KEYS; i++)
-    PFE.rawkey_string[i] = tgetstr (tckeycode[i], &tctop);
-
-  /* another chance for F10: */
-  if (PFE.rawkey_string [P4_KEY_k0 - P4_KEY_k1] == NULL)
-    PFE.rawkey_string [P4_KEY_k0 - P4_KEY_k1] = tgetstr ("k;", &tctop);
-  /* better believe stty which is the erase character: */
-  if (tty_erasechar)
+#  ifdef PFE_HAVE_TERMCAP_H
     {
-      erase[0] = tty_erasechar;
-      PFE.rawkey_string [P4_KEY_kb - P4_KEY_k1] = erase;
+	char *pc = _tgetstr ("pc", &tctop);
+	if (pc != NULL)
+	    PC = *pc;
+	else
+	    PC = 0;
     }
-  for (i = 0; i < DIM (tcctlcode); i++)
-    PFE.control_string[i] = tgetstr (tcctlcode[i], &tctop);
-  if (PFE.control_string [cursor_left] == NULL)
-    PFE.control_string [cursor_left] = "\b";
+#  endif
 
-#if defined PFE_HAVE_OSPEED
-  {
-    char *pc = tgetstr ("pc", &tctop);
-    /* these are defined inside the termcap-library: */
-    ospeed = tty_ospeed;
-    PC = pc ? *pc : 0;
-    BC = PFE.control_string[cursor_left];
-    UP = PFE.control_string[cursor_up];
-  }
-#endif
-  return 1;
+    PFE.rows = _tgetnum ("li");
+    PFE.cols = _tgetnum ("co");
+
+    /* Read all termcap strings we need, */
+    for (i = 0; i < P4_NUM_KEYS; i++)
+	PFE.rawkey_string[i] = _tgetstr (tckeycode[i], &tctop);
+    
+    /* another chance for F10: */
+    if (PFE.rawkey_string [P4_KEY_k0 - P4_KEY_k1] == NULL)
+	PFE.rawkey_string [P4_KEY_k0 - P4_KEY_k1] = _tgetstr ("k;", &tctop);
+    /* better believe stty which is the erase character: */
+    if (tty_erasechar)
+    {
+	erase[0] = tty_erasechar;
+	PFE.rawkey_string [P4_KEY_kb - P4_KEY_k1] = erase;
+    }
+    for (i = 0; i < DIM (tcctlcode); i++)
+	PFE.control_string[i] = _tgetstr (tcctlcode[i], &tctop);
+    if (PFE.control_string [cursor_left] == NULL)
+	PFE.control_string [cursor_left] = "\b";
+
+#  if defined PFE_HAVE_OSPEED
+    {
+	char *pc = _tgetstr ("pc", &tctop);
+	/* these are defined inside the termcap-library: */
+	ospeed = tty_ospeed;
+	PC = pc ? *pc : 0;
+	BC = PFE.control_string[cursor_left];
+	UP = PFE.control_string[cursor_up];
+    }
+#  endif
+    return 1;
 }
 
 static int			/* utility function for tputs(): */
-t_putc (int c)			/* putchar() is a macro, we need a function */
+t_putchar (int c)		/* putchar() is a macro, we need a function */
 {
-  return putchar (c);
+    return putchar (c);
 }
 
 static void
 t_puts (int tcidx, int n)	/* issue termcap string to terminal */
 {
-  if (!PFE.control_string[tcidx])
-    /* no harm if feature not available */
-    return;
-  tputs (PFE.control_string[tcidx], n, t_putc);
-  fflush (stdout);
+    if (!PFE.control_string[tcidx])
+	/* no harm if feature not available */
+	return;
+    tputs (PFE.control_string[tcidx], n, t_putchar_);
+    fflush (stdout);
 }
 
 #define tparm(CAP,X,Y) tgoto (PFE.control_string [CAP], Y, X)
@@ -726,26 +747,26 @@ t_puts (int tcidx, int n)	/* issue termcap string to terminal */
 
 p4_term_struct p4_term_ios =
 {
-  "termcap",
-  termcap_control_string,
-  termcap_rawkey_string,
-  INTO(init) 		c_prepare_terminal, 
-  INTO(fini) 		c_cleanup_terminal,
-  INTO(tput)		c_tput,
+    "termcap",
+    termcap_control_string,
+    termcap_rawkey_string,
+    INTO(init)			c_prepare_terminal, 
+    INTO(fini)			c_cleanup_terminal,
+    INTO(tput)			c_tput,
 
-  INTO(tty_interrupt_key) c_interrupt_key,
-  INTO(interactive_terminal) c_interactive_terminal,
-  INTO(system_terminal)   c_system_terminal,
-  INTO(query_winsize)     c_query_winsize,
+    INTO(tty_interrupt_key)	c_interrupt_key,
+    INTO(interactive_terminal)	c_interactive_terminal,
+    INTO(system_terminal)	c_system_terminal,
+    INTO(query_winsize)		c_query_winsize,
 
-  INTO(c_keypressed)	c_keypressed,
-  INTO(c_getkey)	c_getkey,
-  INTO(c_putc_noflush)  c_putc_noflush,
-  INTO(c_put_flush)	c_put_flush,
-  INTO(c_putc)		c_putc,
-  INTO(c_puts)		c_puts,
-  INTO(c_gotoxy)	c_gotoxy,
-  INTO(c_wherexy)	c_wherexy
+    INTO(c_keypressed)		c_keypressed,
+    INTO(c_getkey)		c_getkey,
+    INTO(c_putc_noflush)	c_putc_noflush,
+    INTO(c_put_flush)		c_put_flush,
+    INTO(c_putc)		c_putc,
+    INTO(c_puts)		c_puts,
+    INTO(c_gotoxy)		c_gotoxy,
+    INTO(c_wherexy)		c_wherexy
 
 };
 
@@ -773,75 +794,75 @@ static char const * terminfo_rawkey_string[P4_NUM_KEYS];
 static int
 query_database (void)
 {
-  int errret;
-  static char erase[] = "\b";
+    int errret;
+    static char erase[] = "\b";
 
-  setupterm (NULL, STDOUT_FILENO, &errret);
-  if (errret != 1)
-    return 0;
+    setupterm (NULL, STDOUT_FILENO, &errret);
+    if (errret != 1)
+	return 0;
 
-#define KINIT(key, ti_capability) \
-  PFE.rawkey_string [P4CAT (P4_KEY_,key) - P4_KEY_k1] = ti_capability
+#  define KINIT(key, ti_capability) \
+    PFE.rawkey_string [P4CAT (P4_KEY_,key) - P4_KEY_k1] = ti_capability
 
-  KINIT (k1, key_f1);		/* function keys F1 through F10 */
-  KINIT (k2, key_f2);
-  KINIT (k3, key_f3);
-  KINIT (k4, key_f4);
-  KINIT (k5, key_f5);
-  KINIT (k6, key_f6);
-  KINIT (k7, key_f7);
-  KINIT (k8, key_f8);
-  KINIT (k9, key_f9);
-  KINIT (k0, key_f10);
+    KINIT (k1, key_f1);		/* function keys F1 through F10 */
+    KINIT (k2, key_f2);
+    KINIT (k3, key_f3);
+    KINIT (k4, key_f4);
+    KINIT (k5, key_f5);
+    KINIT (k6, key_f6);
+    KINIT (k7, key_f7);
+    KINIT (k8, key_f8);
+    KINIT (k9, key_f9);
+    KINIT (k0, key_f10);
 
-  KINIT (kl, key_left);		/* arrow key left */
-  KINIT (kr, key_right);	/* arrow key right */
-  KINIT (ku, key_up);		/* arrow key up */
-  KINIT (kd, key_down);		/* arrow key down */
+    KINIT (kl, key_left);	/* arrow key left */
+    KINIT (kr, key_right);	/* arrow key right */
+    KINIT (ku, key_up);		/* arrow key up */
+    KINIT (kd, key_down);	/* arrow key down */
 
-  KINIT (kh, key_home);		/* home key */
-#ifdef key_end
-  KINIT (kH, key_end);		/* home down key */
-#else /* on HPUX9 */
-  KINIT (kH, key_ll);           /* the same, 'lower left' */
-#endif
-  KINIT (kN, key_npage);	/* next page key */
-  KINIT (kP, key_ppage);	/* previous page key */
+    KINIT (kh, key_home);	/* home key */
+#  ifdef key_end
+    KINIT (kH, key_end);	/* home down key */
+#  else /* on HPUX9 */
+    KINIT (kH, key_ll);         /* the same, 'lower left' */
+#  endif
+    KINIT (kN, key_npage);	/* next page key */
+    KINIT (kP, key_ppage);	/* previous page key */
+    
+    KINIT (kb, key_backspace);	/* backspace key */
+    KINIT (kD, key_dc);		/* delete character key */
+    KINIT (kM, key_eic);	/* exit insert mode key */
+    KINIT (kI, key_ic);		/* insert character key */
+    
+    KINIT (kA, key_il);		/* insert line key */
+    KINIT (kE, key_eol);	/* clear to end of line key */
+    KINIT (kL, key_dl);		/* delete line key */
+    KINIT (kC, key_clear);	/* clear screen key */
 
-  KINIT (kb, key_backspace);	/* backspace key */
-  KINIT (kD, key_dc);		/* delete character key */
-  KINIT (kM, key_eic);		/* exit insert mode key */
-  KINIT (kI, key_ic);		/* insert character key */
-
-  KINIT (kA, key_il);		/* insert line key */
-  KINIT (kE, key_eol);		/* clear to end of line key */
-  KINIT (kL, key_dl);		/* delete line key */
-  KINIT (kC, key_clear);	/* clear screen key */
-
-#undef KINIT
-  /* better believe stty which is the erase character: */
-  if (tty_erasechar)
+#  undef KINIT
+    /* better believe stty which is the erase character: */
+    if (tty_erasechar)
     {
-      erase[0] = tty_erasechar;
-      PFE.rawkey_string [P4_KEY_kb - P4_KEY_k1] = erase;
+	erase[0] = tty_erasechar;
+	PFE.rawkey_string [P4_KEY_kb - P4_KEY_k1] = erase;
     }
 
-  if (cursor_left == NULL)
-      cursor_left = strdup ("\b"); /* fixmee: memoryleak on nonunix systems */
-  return 1;
+    if (cursor_left == NULL)
+	cursor_left = "\b";     /* is it safe? w/o a strdup ? */
+    return 1;
 }
 
-static int			/* utility function for tputs(): */
-t_putc (char c)			/* putchar() is a macro, we need a function */
+static int		/* utility function for tputs(): */
+t_putchar (int c)	/* putchar() is a macro, we need a function */
 {
-  return putchar (c);
+    return putchar (c);
 }
 
-static void			/* output capability with affected lines cnt */
+static void		/* output capability with affected lines cnt */
 t_puts (char *s, int n)
 {
-  tputs (s, n, t_putc);
-  fflush (stdout);
+    tputs (s, n, t_putchar_);
+    fflush (stdout);
 }
 
 #ifdef __GNUC__
@@ -852,26 +873,26 @@ t_puts (char *s, int n)
 
 p4_term_struct p4_term_ios =
 {
-  "terminfo",
-  terminfo_control_string,
-  terminfo_rawkey_string,
-  INTO(init) 		c_prepare_terminal, 
-  INTO(fini) 		c_cleanup_terminal,
-  INTO(tput)		c_tput,
+    "terminfo",
+    terminfo_control_string,
+    terminfo_rawkey_string,
+    INTO(init)			c_prepare_terminal, 
+    INTO(fini)			c_cleanup_terminal,
+    INTO(tput)			c_tput,
 
-  INTO(tty_interrupt_key) c_interrupt_key,
-  INTO(interactive_terminal) c_interactive_terminal,
-  INTO(system_terminal)   c_system_terminal,
-  INTO(query_winsize)     c_query_winsize,
+    INTO(tty_interrupt_key)	c_interrupt_key,
+    INTO(interactive_terminal)	c_interactive_terminal,
+    INTO(system_terminal)	c_system_terminal,
+    INTO(query_winsize)		c_query_winsize,
 
-  INTO(c_keypressed)	c_keypressed,
-  INTO(c_getkey)	c_getkey,
-  INTO(c_putc_noflush)  c_putc_noflush,
-  INTO(c_put_flush)	c_put_flush,
-  INTO(c_putc)		c_putc,
-  INTO(c_puts)		c_puts,
-  INTO(c_gotoxy)	c_gotoxy,
-  INTO(c_wherexy)	c_wherexy
+    INTO(c_keypressed)		c_keypressed,
+    INTO(c_getkey)		c_getkey,
+    INTO(c_putc_noflush)	c_putc_noflush,
+    INTO(c_put_flush)		c_put_flush,
+    INTO(c_putc)		c_putc,
+    INTO(c_puts)		c_puts,
+    INTO(c_gotoxy)		c_gotoxy,
+    INTO(c_wherexy)		c_wherexy
 };
 
 #else
@@ -906,14 +927,14 @@ c_prepare_terminal (void)		/* Call only once at startup. */
 static void
 c_cleanup_terminal (void)
 {
-  return; /* nothing to do here */
+    return; /* nothing to do here */
 }
 
 static void			/* set terminal to the sort of */
 c_interactive_terminal (void)	/* `cbreak' mode used by p4th */
 {
-  tty_interactive ();
-  t_puts (keypad_xmit, 0);
+    tty_interactive ();
+    t_puts (keypad_xmit, 0);
 }
 
 static void			/* resets terminal state to */
@@ -937,14 +958,14 @@ c_system_terminal (void)		/* as it was before */
 static void
 c_query_winsize (void)
 {
-  struct winsize size;
+    struct winsize size;
 
-  if (ioctl (1, TIOCGWINSZ, (char *) &size) >= 0)
+    if (ioctl (1, TIOCGWINSZ, (char *) &size) >= 0)
     {
-      PFE.rows = size.ws_row;
-      PFE.cols = size.ws_col;
-      PFE.xmax = size.ws_xpixel;
-      PFE.ymax = size.ws_ypixel;
+	PFE.rows = size.ws_row;
+	PFE.cols = size.ws_col;
+	PFE.xmax = size.ws_xpixel;
+	PFE.ymax = size.ws_ypixel;
     }
 }
 #else
@@ -978,32 +999,36 @@ nextch (void)
  * Read a single character from standard input.
  */
 {
-  unsigned char c;
+    unsigned char c;
 
-  if (nxch != NOCH)
+    if (nxch != NOCH)
     {
-      c = (unsigned char) nxch;
-      nxch = NOCH;
-      return c;
+	c = (unsigned char) nxch;
+	nxch = NOCH;
+	return c;
     }
-  else
-    for (;;)
-      switch (read (0, (void *) &c, 1))
+    else
+    {
+	for (;;)
 	{
-	case -1:
-	  switch (errno)
+	    switch (read (0, (void *) &c, 1))
 	    {
+	    case -1:
+		switch (errno)
+		{
+		default:
+		    return -1;
+		case EAGAIN:
+		case EINTR:
+		    continue;
+		}
+	    case 0:
+		return -1;
 	    default:
-	      return -1;
-	    case EAGAIN:
-	    case EINTR:
-	      continue;
+		return c;
 	    }
-	case 0:
-	  return -1;
-	default:
-	  return c;
 	}
+    }
 }
 
 static int
@@ -1013,30 +1038,30 @@ c_keypressed (void)
  * Returns: 1 if char available, 0 otherwise
  */
 {
-  unsigned char c;		/* place to read the character */
-  int result;
+    unsigned char c;		/* place to read the character */
+    int result;
 
-  fflush (stdout);
-  if (nxch != NOCH)
-    return 1;			/* char from previos keypressed() */
-  no_waitchar (STDIN_FILENO);
-  result = read (0, (void *) &c, 1);
-  waitchar (STDIN_FILENO);
-  if (result != 1)
-    return 0;
-  nxch = c;
-  return 1;
+    fflush (stdout);
+    if (nxch != NOCH)
+	return 1;		/* char from previos keypressed() */
+    no_waitchar (STDIN_FILENO);
+    result = read (0, (void *) &c, 1);
+    waitchar (STDIN_FILENO);
+    if (result != 1)
+	return 0;
+    nxch = c;
+    return 1;
 }
 
 static int
 c_getkey (void)
 {
-  fflush (stdout);
+    fflush (stdout);
 
-  if (PFE.wait_for_stdin)
-      PFE.wait_for_stdin ();
+    if (PFE.wait_for_stdin)
+	PFE.wait_for_stdin ();
 
-  return nextch ();
+    return nextch ();
 }
 
 /************************************************************************/
@@ -1048,95 +1073,95 @@ static int row, col;		/* position of curser as tracked */
 static void			/* output character and */
 c_putc_noflush (char c)		/* trace the cursor position */
 {
-  putchar (c);
-  switch (c)
+    putchar (c);
+    switch (c)
     {
     case '\a':			/* bell, no change of cursor position */
-      break;
+	break;
     case '\b':			/* backspace, move cursor left */
-      if (col > 0)
-	col--;
-      break;
+	if (col > 0)
+	    col--;
+	break;
     case '\r':			/* carriage return, ->column 0 */
-      col = 0;
-      break;
+	col = 0;
+	break;
     default:			/* ordinary character: */
-      if (col < PFE.cols - 1)	/* at right edge of screen? */
+	if (col < PFE.cols - 1)	/* at right edge of screen? */
 	{
-	  col++;		/* no: increment column */
-	  break;
+	    col++;		/* no: increment column */
+	    break;
 	}			/* yes: like line feed */
     case '\n':			/* line feed */
-      col = 0;
-      if (row < PFE.rows - 1)	/* if not at bottom of screen: */
-	row++;			/* increment row */
+	col = 0;
+	if (row < PFE.rows - 1)	/* if not at bottom of screen: */
+	    row++;		/* increment row */
     }				/* otherwise terminal is supposed to scroll */
 }
 
 static void
 c_put_flush (void)
 {
-  fflush (stdout);
+    fflush (stdout);
 }
 
 static void
 c_putc (char c)
 {
-  c_putc_noflush (c);
-  fflush (stdout);
+    c_putc_noflush (c);
+    fflush (stdout);
 }
 
 static void
 c_puts (const char *s)
 {
-  while (*s)
-    c_putc_noflush (*s++);
-  fflush (stdout);
+    while (*s)
+	c_putc_noflush (*s++);
+    fflush (stdout);
 }
 
 static void
 c_gotoxy (int x, int y)
 {
-  tputs (tparm (cursor_address, y, x), 1, t_putc);
-  fflush (stdout);
-  col = x;
-  row = y;
+    tputs (tparm (cursor_address, y, x), 1, t_putchar_);
+    fflush (stdout);
+    col = x;
+    row = y;
 }
 
 static void
 c_wherexy (int *x, int *y)
 {
-  *x = col;
-  *y = row;
+    *x = col;
+    *y = row;
 }
 
 static void 
 c_tput (int attr)
 {
-  switch (attr)
-  {
-  case P4_TERM_GOLEFT:		t_puts (cursor_left,  	0); --col; break;
-  case P4_TERM_GORIGHT:		t_puts (cursor_right, 	0); ++col; break;
-  case P4_TERM_GOUP:		t_puts (cursor_up,	0); --row; break;
-  case P4_TERM_GODOWN:		t_puts (cursor_down,	0); ++row; break;
-
-  case P4_TERM_CLRSCR:		t_puts (clear_screen, PFE.rows); /*->HOME*/
-  case P4_TERM_HOME:		t_puts (cursor_home, 1); 
-                                        	   row = col = 0;  break;
-  case P4_TERM_CLREOL:		t_puts (clr_eol, 1); 		   break;
-  case P4_TERM_CLRDOWN:		t_puts (clr_eos, PFE.rows - row);  break;
-  case P4_TERM_BELL:		t_puts (bell, 0); 		   break;
-  
-  case P4_TERM_NORMAL:		t_puts (exit_attribute_mode,	0); break;
-  case P4_TERM_BOLD_ON:		t_puts (enter_standout_mode,	0); break;
-  case P4_TERM_BOLD_OFF:	t_puts (exit_standout_mode,	0); break;
-  case P4_TERM_UNDERLINE_ON:	t_puts (enter_underline_mode,	0); break;
-  case P4_TERM_UNDERLINE_OFF:	t_puts (exit_underline_mode,	0); break;
-  case P4_TERM_BRIGHT:		t_puts (enter_bold_mode,	0); break;
-  case P4_TERM_REVERSE:		t_puts (enter_reverse_mode,	0); break;
-  case P4_TERM_BLINKING:	t_puts (enter_blink_mode,	0); break;
-  default: break;
-  }
+    switch (attr)
+    {
+    case P4_TERM_GOLEFT:	t_puts (cursor_left,  	0); --col; break;
+    case P4_TERM_GORIGHT:	t_puts (cursor_right, 	0); ++col; break;
+    case P4_TERM_GOUP:		t_puts (cursor_up,	0); --row; break;
+    case P4_TERM_GODOWN:	t_puts (cursor_down,	0); ++row; break;
+	
+    case P4_TERM_CLRSCR:	t_puts (clear_screen, PFE.rows); /*->HOME*/
+    case P4_TERM_HOME:		t_puts (cursor_home, 1); row = col = 0;  break;
+    case P4_TERM_CLREOL:	t_puts (clr_eol, 1); 		   break;
+    case P4_TERM_CLRDOWN:	t_puts (clr_eos, PFE.rows - row);  break;
+    case P4_TERM_BELL:		t_puts (bell, 0); 		   break;
+	
+    case P4_TERM_NORMAL:	t_puts (exit_attribute_mode,	0); break;
+    case P4_TERM_BOLD_ON:	t_puts (enter_standout_mode,	0); break;
+    case P4_TERM_BOLD_OFF:	t_puts (exit_standout_mode,	0); break;
+    case P4_TERM_UNDERLINE_ON:	t_puts (enter_underline_mode,	0); break;
+    case P4_TERM_UNDERLINE_OFF:	t_puts (exit_underline_mode,	0); break;
+    case P4_TERM_BRIGHT:	t_puts (enter_bold_mode,	0); break;
+    case P4_TERM_REVERSE:	t_puts (enter_reverse_mode,	0); break;
+    case P4_TERM_BLINKING:	t_puts (enter_blink_mode,	0); break;
+    default: 
+	break;
+    }
 }
 
  /*@}*/
