@@ -1,11 +1,11 @@
 /** 
  * -- terminal driver for win32 wincon.h API 
  *
- *  Copyright (C) Guido Draheim, 2001
+ *  Copyright (C) Guido Draheim, 2001 - 2003
  *
  *  @see     GNU LGPL
  *  @author  Guido Draheim            @(#) %derived_by: guidod %
- *  @version %version: bln_mpt1!1.28 %
+ *  @version %version: bln_mpt1!1.29 %
  *    (%date_modified: Tue Aug 13 15:38:46 2002 %)
  *
  *  @description
@@ -19,7 +19,7 @@
 /*@{*/
 #if defined(__version_control__) && defined(__GNUC__)
 static char* id __attribute__((unused)) = 
-"@(#) $Id: %full_filespec:  term-wincon.c~bln_mpt1!1.28:csrc:bln_12xx!1 % $";
+"@(#) $Id: %full_filespec:  term-wincon.c~bln_mpt1!1.29:csrc:bln_12xx!1 % $";
 #endif
 
 #ifndef _REENTRANT
@@ -34,7 +34,7 @@ static char* id __attribute__((unused)) =
  * there are far too many comments around.
  */
 
-#include <pfe/incl-sub.h>
+#include <pfe/pfe-sub.h>
 #include <pfe/term-sub.h>
 /* include <wincon.h> */
 #include <windows.h> 
