@@ -225,8 +225,9 @@ FCode (p4_andif)
     FX_COMPILE (p4_andif);
     FX (p4_ahead);
 }
-FCode (p4_andif_execution)
+FCode_XE (p4_andif_execution)
 {
+    FX_USE_CODE_ADDR;
     if (! *SP)
     {
         FX_BRANCH;
@@ -234,6 +235,7 @@ FCode (p4_andif_execution)
         IP++;
         FX_DROP;
     }
+    FX_USE_CODE_EXIT;
 }
 P4COMPILES (p4_andif, p4_andif_execution,
     P4_SKIPS_OFFSET, P4_IF_STYLE);
@@ -249,8 +251,9 @@ FCode (p4_orif)
     FX_COMPILE (p4_orif);
     FX (p4_ahead);
 }
-FCode (p4_orif_execution)
+FCode_XE (p4_orif_execution)
 {
+    FX_USE_CODE_ADDR
     if (*SP)
     {
         FX_BRANCH;
@@ -742,13 +745,13 @@ FCode (p4_tick_th)
     FX_COMPILE (p4_tick_th);
     FX_XCOMMA (xt);
 }
-FCode (p4_tick_th_execution)
-{
+FCode_XE (p4_tick_th_execution)
+{   FX_USE_CODE_ADDR {
     p4cell cells = sizeof(p4cell) * FX_POP;
     p4xt   xt = (p4xt) P4_POP(IP);
     p4_call (xt);
     *SP += cells;
-}
+}}
 P4COMPILES(p4_tick_th, p4_tick_th_execution,
     P4_SKIPS_TO_TOKEN, P4_DEFAULT_STYLE);
  
