@@ -5,8 +5,8 @@
  *
  *  @see     GNU LGPL
  *  @author  Tektronix CTE              @(#) %derived_by: guidod %
- *  @version %version: bln_mpt1!5.18 %
- *    (%date_modified: Wed Jul 17 14:03:04 2002 %)
+ *  @version %version: bln_mpt1!33.19 %
+ *    (%date_modified: Wed Mar 19 16:32:26 2003 %)
  *
  *  @description
  *      The ANS Forth defines some "Programming Tools", words to
@@ -21,7 +21,7 @@
 /*@{*/
 #if defined(__version_control__) && defined(__GNUC__)
 static char* id __attribute__((unused)) = 
-"@(#) $Id: %full_filespec:  tools-ext.c~bln_mpt1!5.18:csrc:bln_12xx!1 % $";
+"@(#) $Id: %full_filespec:  tools-ext.c~bln_mpt1!33.19:csrc:bln_12xx!1 % $";
 #endif
 
 #define _P4_SOURCE 1
@@ -278,7 +278,7 @@ FCode (p4_cs_roll)
 FCode (p4_forget)
 {
     if (LAST) FX (p4_reveal);
-    p4_forget (_FFA (p4_tick_nfa (FX_VOID)));
+    p4_forget (P4_NFA2START (p4_tick_nfa (FX_VOID)));
 }
 
 /* ----------------------------------------------------------------------- */
