@@ -1,8 +1,8 @@
 #ifndef _PFE_TOOLS_SUB_H
-#define _PFE_TOOLS_SUB_H 1002653678
-/* generated 2001-1009-2054 ../../../pfe/../mk/Make-H.pl ../../../pfe/tools-sub.c */
+#define _PFE_TOOLS_SUB_H 1063198931
+/* generated 2003-0910-1502 ../../../pfe/../mk/Make-H.pl ../../../pfe/tools-sub.c */
 
-#include <pfe/incl-sub.h>
+#include <pfe/pfe-sub.h>
 
 /** 
  * -- implementation words for TOOLS-EXT / TOOLS-MIX
