@@ -5,8 +5,8 @@
  *
  *  @see     GNU LGPL
  *  @author  Tektronix CTE              @(#) %derived_by: guidod %
- *  @version %version: bln_mpt1!1.58 %
- *    (%date_modified: Tue Feb 25 13:22:45 2003 %)
+ *  @version %version: bln_mpt1!33.60 %
+ *    (%date_modified: Wed Mar 19 17:15:49 2003 %)
  *
  *  @description
  *              This wordset adds some additional primitives that
@@ -18,7 +18,7 @@
 /*@{*/
 #if defined(__version_control__) && defined(__GNUC__)
 static char* id __attribute__((unused)) = 
-"@(#) $Id: %full_filespec:  useful-ext.c~bln_mpt1!1.58:csrc:bln_12xx!1 % $";
+"@(#) $Id: %full_filespec:  useful-ext.c~bln_mpt1!33.60:csrc:bln_12xx!1 % $";
 #endif
  
 #define _P4_SOURCE 1
@@ -38,19 +38,28 @@ static char* id __attribute__((unused)) =
 void p4_to_compile (p4xt xt)
 {
     if (!xt) return;
-    if (STATE && !(*_FFA(p4_to_name (xt)) & P4xIMMEDIATE))
+    if (STATE && ! P4_NFA_xIMMEDIATE(p4_to_name (xt)))
         FX_XCOMMA (xt);
     else
         p4_call (xt);
 }
 
-/** >COMPILE ( xt -- )
+/** "_for:COMPILE," ( xt -- )
  *  does the work of => POSTPONE on the execution token that 
  *  you got from somewhere else - so it checks if the name
  *  (that correspond to the execution-token argument) is
  *  actually immediate, so it has to be executed to compile
  *  something, e.g. => IF or => THEN - see also => POSTPONE ,
  *  => COMPILE , => [COMPILE] , => INTERPRET
+ *
+ *  warning: do not use this word anymore, it is an error to
+ *  compile a token where the immediate-bit must be checked.
+ *  The immediate-bit is a pure header information not present
+ *  with headerless words as such. Furthermore, this function
+ *  is subject to POSTPONE problems as well.
+ *
+ *  Newer code should use =>"COMPILE," when trying to simulate
+ *  a behavior similar to => POSTPONE.
  */
 FCode (p4_to_compile)
 {
@@ -473,6 +482,14 @@ P4COMPILES2(p4_make, p4_make_to_execution, p4_make_to_local_execution,
 
 /**@}*/
 
+static P4_CODE_RUN(p4_offset_RT_SEE)
+{
+    strcat (p, p4_str_dot (*P4_TO_BODY (xt), p+200, BASE));
+    strcat (p, "OFFSET: ");
+    strncat (p, nfa+1, NFACNT(*nfa));
+    return 0;
+}
+
 /** OFFSET-RT ( value -- value+offset )
  *  this runtime will add the body-value to the value at top-of-stack.
  *  used heavily in structure access words, compiled by => /FIELD
@@ -499,7 +516,7 @@ FCode (p4_offset_constant)
     FX_RUNTIME1 (p4_offset_constant);
     FX_UCOMMA (*SP); FX_DROP;
 }
-P4RUNTIME1(p4_offset_constant, p4_offset_RT);
+P4RUNTIMES1_(p4_offset_constant, p4_offset_RT, 0, p4_offset_RT_SEE);
 
 /** +FIELD ( offset "name" -- offset )
  * created a new name with an => OFFSET-RT runtime using the given offset. 
@@ -586,8 +603,8 @@ FCode (p4_bracket_not)
 p4char*
 p4_nextlowerNFA(void* adr)
 {
-    p4char* nfa = 0;
-    register Wordl* wl;
+    register p4char* nfa = 0;
+    register p4_Wordl* wl;
 
     for (wl = VOC_LINK; wl; wl = wl->prev)
     {
@@ -597,7 +614,7 @@ p4_nextlowerNFA(void* adr)
         {
             for (n = wl->thread[i]; n; )
             {
-                if (nfa < NFA2FF(n) && NFA2FF(n) < (p4char*) adr)
+                if (nfa < P4_NFA2START(n) && P4_NFA2START(n) < (p4char*) adr)
                     nfa = n;
                 n = *p4_name_to_link(n);
             }
@@ -609,8 +626,8 @@ p4_nextlowerNFA(void* adr)
 p4char*
 p4_nexthigherNFA(void* adr)
 {
-    p4char* nfa = PFE.dp;
-    register Wordl* wl;
+    register p4char* nfa = PFE.dp;
+    register p4_Wordl* wl;
 
     for (wl = VOC_LINK; wl; wl = wl->prev)
     {
@@ -620,7 +637,7 @@ p4_nexthigherNFA(void* adr)
         {
             for (n = wl->thread[i]; n; )
             {
-                if (NFA2FF(n) < nfa && NFA2FF(n) > (p4char*) adr)
+                if (P4_NFA2START(n) < nfa && P4_NFA2START(n) > (p4char*) adr)
                     nfa = n;
                 n = *p4_name_to_link(n);
             }
@@ -649,13 +666,13 @@ FCode(p4_replace_in)
     n  = FX_POP;
     fr = FX_POP;
     to = FX_POP;
-    if (!n) return;
+    if (! n) return;
     for ( ; xt < ex-1; xt++)
     {
         if (*xt == fr) 
         {
             --n;
-            if (!n) { *xt = to; return; }
+            if (! n) { *xt = to; return; }
             if (n < 0) *xt = to; 
         }
     }
@@ -723,6 +740,52 @@ P4COMPILES (p4_x_quote, p4_c_quote_execution,
             P4_SKIPS_STRING, P4_DEFAULT_STYLE);
 
 
+/* ------------------------------------------------------------------- */
+/** EVALUATE-WITH ( i*x addr len xt[i*x--j*x] -- j*x ) 
+ * added to be visible on the forth command line on request by MLG,
+ * he has explained the usage before a lot, you can get an idea from:
+    : EVALUATE ['] INTERPRET EVALUATE-WITH ;
+ * The word is used internally in PFE for the loadlist evaluation of
+ * the binary modules: where previously each loadercode had its own
+ * CREATE-execution we do now call the original forthish CREATE-word
+ * like, so bootstrapping a => VARIABLE will now call VARIABLE itself
+ * and of course we need to set up the TIB-area to point to the name
+ * of the variable that shall be created in the forth dictionary:
+ : LOAD-WORD ( arg-value str-ptr str-len loader-code -- )
+      CASE
+        #LOAD-VARIABLE OF ['] VARIABLE EVALUATE-WITH ENDOF
+        ....
+      ENDCASE
+      CLEARSTACK
+ ;
+ */
+FCode(p4_evaluate_with)
+{
+    /* compare with p4_evaluate() in engine-sub !! */
+    p4xt xt = (void*) SP[0];
+    p4cell n = SP[1];
+    p4char* p = (void*) SP[2];
+    FX_3DROP;
+
+#  if !defined P4_RP_IN_VM
+    Iframe saved;
+    p4_link_saved_input (&saved);
+#  else
+    RP = (p4xcode **) p4_save_input (RP);
+#  endif
+    SOURCE_ID = -1;
+    BLK = 0;
+    TIB = p;                /* leave that warning for a while... */
+    NUMBER_TIB = n;
+    TO_IN = 0;
+    p4_call(xt);           /* <-- the only real difference over p4_evaluate */
+#  if defined P4_RP_IN_VM
+    RP = (p4xcode **) p4_restore_input (RP);
+#  else
+    p4_unlink_saved_input (&saved);
+#  endif
+}
+
 /* ------------------------------------------------------------------- */
 
 /** [VOCABULARY] ( "name" -- )
@@ -735,7 +798,7 @@ FCode (p4_bracket_vocabulary)
     extern FCode (p4_vocabulary);
 
     FX (p4_vocabulary);
-    *_FFA(LAST) |= P4xIMMEDIATE;
+    P4_NFA_FLAGS(LAST) |= P4xIMMEDIATE;
 }
 
 /** [POSSIBLY] ( [name] -- ?? )
@@ -870,7 +933,8 @@ FCode (p4_bracket_execute)
 P4_LISTWORDS (useful) =
 {
     P4_INTO ("EXTENSIONS", 0),
-    P4_FXco (">COMPILE",		p4_to_compile),
+    P4_FXco ("_like:COMPILE,",		p4_to_compile),
+    P4_xOLD (">COMPILE",		"_like:COMPILE,"),
     P4_IXco ("($",			p4_prefix_begin),
     P4_IXco (")",			p4_prefix_end),
     P4_FXco ("PFE-PRINTF",		p4_printf),
@@ -901,6 +965,7 @@ P4_LISTWORDS (useful) =
     P4_OCoN ("#WITH-NO-FFA",		WITH_NO_FFA+100),
 # endif
     P4_SXco ("X\"",			p4_x_quote),
+    P4_FXco ("EVALUATE-WITH",           p4_evaluate_with),
     P4_IXco ("[POSSIBLY]",		p4_bracket_possibly),
     P4_FXco ("[VOCABULARY]",		p4_bracket_vocabulary),
     P4_IXco ("[DEF]",			p4_bracket_def),
