@@ -1,11 +1,11 @@
 /** 
  * -- Version File
  *
- *  Copyright (C) Tektronix, Inc. 1998 - 2002.  All rights reserved.
+ *  Copyright (C) Tektronix, Inc. 1998 - 2003.  All rights reserved.
  *
  *  @see     GNU LGPL
  *  @author  Tektronix CTE              @(#) %derived_by: guidod %
- *  @version %version: bln_mpt1!6.8 %
+ *  @version %version: bln_mpt1!33.19 %
  *    (%date_modified: Tue Jul 23 16:17:26 2002 %)
  *
  *  @description
@@ -16,12 +16,12 @@
 /*@{*/
 #if defined(__version_control__) && defined(__GNUC__)
 static char* id __attribute__((unused)) = 
-"@(#) $Id: %full_filespec:  version-sub.c~bln_mpt1!6.8:csrc:bln_12xx!1 % $";
+"@(#) $Id: %full_filespec:  version-sub.c~bln_mpt1!33.19:csrc:bln_12xx!1 % $";
 #endif
 
 #define _P4_SOURCE 1
 
-#include <pfe/incl-sub.h>
+#include <pfe/pfe-sub.h>
 #include <pfe/def-macro.h>
 
 #ifdef HAVE__VERSION_H
@@ -53,7 +53,7 @@ static char* id __attribute__((unused)) =
 #endif
 
 #ifndef PFE_VERSION
-#define PFE_VERSION "32.x"
+#define PFE_VERSION "33.x"
 #endif
 
 _export const char* p4_version_string(void)
@@ -66,7 +66,7 @@ _export const char* p4_copyright_string(void)
 {
     return
 	"\nCopyright (C) Dirk Uwe Zoller 1993 - 1995."
-	"\nCopyright (C) Tektronix, Inc. 1998 - 2002.";
+	"\nCopyright (C) Tektronix, Inc. 1998 - 2003.";
 }
 
 _export const char* p4_license_string (void)
