@@ -1,17 +1,17 @@
 #ifndef _PFE_VERSION_SUB_H
-#define _PFE_VERSION_SUB_H 1034771920
-/* generated 2002-1016-1438 ../../../pfe/../mk/Make-H.pl ../../../pfe/version-sub.c */
+#define _PFE_VERSION_SUB_H 1063198933
+/* generated 2003-0910-1502 ../../../pfe/../mk/Make-H.pl ../../../pfe/version-sub.c */
 
-#include <pfe/incl-sub.h>
+#include <pfe/pfe-sub.h>
 
 /** 
  * -- Version File
  *
- *  Copyright (C) Tektronix, Inc. 1998 - 2002.  All rights reserved.
+ *  Copyright (C) Tektronix, Inc. 1998 - 2003.  All rights reserved.
  *
  *  @see     GNU LGPL
  *  @author  Tektronix CTE              @(#) %derived_by: guidod %
- *  @version %version: bln_mpt1!6.8 %
+ *  @version %version: bln_mpt1!33.19 %
  *    (%date_modified: Tue Jul 23 16:17:26 2002 %)
  *
  *  @description
