@@ -69,7 +69,7 @@ FCode_XE (p4_z_quote_XT)
     P4_VAR(char*,IP) += skip;
     FX_USE_CODE_EXIT;
 }}
-p4xt* p4_z_quote_SEE(p4xt* ip, char* p, p4_Semant* s)
+p4xcode* p4_z_quote_SEE(p4xcode* ip, char* p, p4_Semant* s)
 {
     int skip = *P4_VAR(short*,ip)++;
     sprintf (p, "%.*s %.*s\" ",
