@@ -1,4 +1,5 @@
 #! /bin/sh
+testcase="coretest"
 
 echo "
 /is redefined/d
@@ -14,7 +15,7 @@ echo "
 # actually ASCII chars...
 {N;N;N;s/YOU SHOULD SEE THE STANDARD GRAPHIC CHARACTERS://;}
 s|!\"\#\$%&'()\*+,\-\.\/0123456789:;<=>?@||
-s/ABCDEFGHIJKLMNOPQRSTUVWXYZ\[\\\]\^\_\`//
+s/ABCDEFGHIJKLMNOPQRSTUVWXYZ\[\\\\\]\^\_\`//
 s/abcdefghijklmnopqrstuvwxyz{|}\~//
 {p;d;}
 :onespacedigits
@@ -37,10 +38,10 @@ s/0  1  2  3  4  5  //
 {N;N;s/YOU SHOULD SEE TWO SEPARATE LINES://;}
 s/LINE 1.*\n.*LINE 2//
 {p;d;}
-" >coretest.sed
+" >$testcase.sed
 
-sed -n -f coretest.sed $* >coretest.tmp
-cnt=`cat coretest.tmp | wc -w`
+sed -n -f $testcase.sed $* >$testcase.tmp
+cnt=`cat $testcase.tmp | wc -w`
 test "0" -eq "$cnt" || echo "$* : $cnt BAD lines"
 test "0" -eq "$cnt"
 exit
