@@ -1,19 +1,19 @@
 #! /bin/sh
+testcase="wordsets"
 
 echo "
 /checking .*/D
 / ^/D
-//D
 s/ CODE *missing //
 s/ ;CODE *missing //
 s/ ASSEMBLER *missing //
 s/ EDITOR *missing //
 s/ missing//
 p
-" >wordsets.sed
+" >$testcase.sed
 
-sed -n -f wordsets.sed $* >wordsets.tmp
-cnt=`cat wordsets.tmp | wc -w`
+sed -n -f $testcase.sed $* >$testcase.tmp
+cnt=`cat $testcase.tmp | wc -w`
 test "0" -eq "$cnt" || echo "$* : $cnt BAD lines"
 test "0" -eq "$cnt"
 exit
